@@ -1,12 +1,12 @@
 # --
 # Kernel/Config/Defaults.pm - Default Config file for OTRS kernel
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: Defaults.pm,v 1.272 2007/07/26 14:15:30 martin Exp $
+# $Id: Defaults.pm,v 1.272.2.8 2008/05/28 08:03:42 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 #
 #  Note:
@@ -23,7 +23,7 @@ package Kernel::Config::Defaults;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.272 $';
+$VERSION = '$Revision: 1.272.2.8 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub LoadDefaults {
@@ -140,12 +140,14 @@ sub LoadDefaults {
 #            bb => 'Bavarian',
             ar_SA => 'Arabic (Saudi Arabia)',
             bg => 'Bulgarian (&#x0411;&#x044a;&#x043b;&#x0433;&#x0430;&#x0440;&#x0441;&#x043a;&#x0438;)',
+            ct => 'Catal&agrave;',
             cz => 'Czech (&#x010c;esky)',
             da => 'Dansk',
             de => 'Deutsch',
             en => 'English',
             el => 'Greek (&#x0395;&#x03bb;&#x03bb;&#x03b7;&#x03bd;&#x03b9;&#x03ba;&#x03ac;)',
             es => 'Espa&ntilde;ol',
+            et => 'Eesti',
             fa => 'Persian (&#x0641;&#x0627;&#x0631;&#x0633;&#x0649;)',
             fr => 'Fran&ccedil;ais',
             fi => 'Suomi',
@@ -159,12 +161,13 @@ sub LoadDefaults {
             ru => 'Russian (&#x0420;&#x0443;&#x0441;&#x0441;&#x043a;&#x0438;&#x0439;)',
             sk_SK => 'Slovak (Sloven&#x010d;ina)',
             sv => 'Svenska',
+            tr => 'T&uuml;rk&ccedil;e',
+            vi_VN => 'Vietnam (Vi&#x0246;t Nam)',
             zh_CN => 'Chinese (Sim.) (&#x7b80;&#x4f53;&#x4e2d;&#x6587;)',
 #            th => 'Thai (&#x0e44;&#x0e17;&#x0e22;)',
 #            ro => 'Rom&acirc;n&auml;',
 #            hr => 'Croatian',
 #            sl => 'Slovenian (Sloven&#x0161;&#x010d;ina)',
-#            tr => 'T&uuml;rk&ccedil;e',
 #            uk => 'Ukrainian (&#x0423;&#x043a;&#x0440;&#x0430;&#x0457;&#x043d;&#x0441;&#x044c;&#x043a;&#x0430;)',
 #            jp => 'Japanese (&#x65e5;&#x672c;&#x8a9e;)',
     };
@@ -259,6 +262,8 @@ sub LoadDefaults {
 
     # system log cache size for admin system log (default 4k)
     # Note: use bin/CleanUp.pl before you change this
+    # Note: this configuration is not useable in SysConfig
+    #       for more information see FAQ# 4200111 and FAQ# 4200110
 #    $Self->{'LogSystemCacheSize'} = 4*1024;
 
     # --------------------------------------------------- #
@@ -334,6 +339,10 @@ sub LoadDefaults {
     # is not in use.
 #    $Self->{'AuthModule::LDAP::UserLowerCase'} = 0;
 
+    # In case you need to use OTRS in iso-charset, you can define this
+    # by using this option (converts utf-8 data from LDAP to iso).
+    #    $Self->{'AuthModule::LDAP::Charset'} = 'iso-8859-1';
+
     # Net::LDAP new params (if needed - for more info see perldoc Net::LDAP)
 #    $Self->{'AuthModule::LDAP::Params'} = {
 #        port => 389,
@@ -595,7 +604,7 @@ sub LoadDefaults {
     $Self->{SessionUseCookieAfterBrowserClose} = 0;
 
     # SessionDir
-    # directory for all sessen id informations (just needed if
+    # directory for all sessen id information (just needed if
     # $Self->{SessionModule}='Kernel::System::AuthSession::FS)
     $Self->{SessionDir} = '<OTRS_CONFIG_Home>/var/sessions';
 
@@ -1253,6 +1262,10 @@ Your OTRS Notification Master
         CustomerCompanyKey => 'customer_id',
         CustomerCompanyValid => 'valid_id',
         CustomerCompanyListFields => ['customer_id', 'name'],
+        CustomerCompanySearchFields => ['customer_id', 'name'],
+        CustomerCompanySearchPrefix => '',
+        CustomerCompanySearchSuffix => '*',
+        CustomerCompanySearchListLimit => 250,
         Map => [
             # var, frontend, storage, shown (1=always,2=lite), required, storage-type, http-link, readonly
             [ 'CustomerID',              'CustomerID',  'customer_id',  0, 1, 'var', '', 0 ],
@@ -2166,12 +2179,12 @@ This software is part of the OTRS project (http://otrs.org/).
 
 This software comes with ABSOLUTELY NO WARRANTY. For details, see
 the enclosed file COPYING for license information (GPL). If you
-did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 
 =cut
 
 =head1 VERSION
 
-$Revision: 1.272 $ $Date: 2007/07/26 14:15:30 $
+$Revision: 1.272.2.8 $ $Date: 2008/05/28 08:03:42 $
 
 =cut
