@@ -1,8 +1,8 @@
 # --
 # Kernel/Language.pm - provides multi language support
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Language.pm,v 1.41 2006/10/09 17:38:03 mh Exp $
+# $Id: Language.pm,v 1.46 2007/08/16 12:41:31 sb Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,7 +17,7 @@ use Kernel::System::Time;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '$Revision: 1.41 $';
+$VERSION = '$Revision: 1.46 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -41,7 +41,7 @@ create a language object
     use Kernel::Config;
     use Kernel::System::Log;
     use Kernel::System::Main;
-    use Kernel::Langauge;
+    use Kernel::Language;
 
     my $ConfigObject = Kernel::Config->new();
     my $LogObject    = Kernel::System::Log->new(
@@ -53,7 +53,7 @@ create a language object
         LogObject => $LogObject,
     );
 
-    my $LangaugeObject = Kernel::Langauge->new(
+    my $LanguageObject = Kernel::Language->new(
         MainObject => $MainObject,
         ConfigObject => $ConfigObject,
         LogObject => $LogObject,
@@ -162,9 +162,9 @@ sub new {
 
 =item Get()
 
-Translate a words.
+Translate a string.
 
-  my $Text = $LanguageObject->Get('Hello');
+    my $Text = $LanguageObject->Get('Hello');
 
 =cut
 
@@ -188,8 +188,8 @@ sub Get {
         # Debug
         if ($Self->{Debug} > 3) {
             $Self->{LogObject}->Log(
-              Priority => 'Debug',
-              Message => "->Get('$What') = ('$Self->{Translation}->{$What}').",
+                Priority => 'Debug',
+                Message => "->Get('$What') = ('$Self->{Translation}->{$What}').",
             );
         }
         # charset convert from source translation into shown charset
@@ -227,6 +227,11 @@ sub Get {
                 Message => "->Get('$What') Is not translated!!!",
             );
         }
+
+        if ($Self->{ConfigObject}->Get('LanguageDebug')) {
+            print STDERR "No translation available for '$What'\n";
+        }
+
         foreach (0..3) {
             if (defined $Dyn[$_]) {
                 if ($Dyn[$_] =~ /Time\((.*)\)/) {
@@ -249,7 +254,7 @@ sub Get {
 
 Get date format in used language formate (based on translation file).
 
-  my $Date = $LanguageObject->FormatTimeString('2005-12-12 12:12:12', 'DateFormat');
+    my $Date = $LanguageObject->FormatTimeString('2005-12-12 12:12:12', 'DateFormat');
 
 =cut
 
@@ -304,7 +309,7 @@ sub FormatTimeString {
 Returns the recommended charset for frontend (based on translation
 file or from DefaultCharset (from Kernel/Config.pm) is utf-8).
 
-  my $Charset = $LanguageObject->GetRecommendedCharset().
+    my $Charset = $LanguageObject->GetRecommendedCharset().
 
 =cut
 
@@ -328,7 +333,7 @@ sub GetRecommendedCharset {
 
 Returns an array of possible charsets (based on translation file).
 
-  my @Charsets = $LanguageObject->GetPossibleCharsets().
+    my @Charsets = $LanguageObject->GetPossibleCharsets().
 
 =cut
 
@@ -431,11 +436,11 @@ sub Time {
 Converts charset from a source string (if no To is given, the the
 GetRecommendedCharset() will be used).
 
-  my $Text = $LanguageObject->CharsetConvert(
-      Text => $String,
-      From => 'iso-8859-15',
-      To => 'utf-8',
-  );
+    my $Text = $LanguageObject->CharsetConvert(
+        Text => $String,
+        From => 'iso-8859-15',
+        To => 'utf-8',
+    );
 
 =cut
 
@@ -456,6 +461,8 @@ sub CharsetConvert {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -468,6 +475,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.41 $ $Date: 2006/10/09 17:38:03 $
+$Revision: 1.46 $ $Date: 2007/08/16 12:41:31 $
 
 =cut
