@@ -1,19 +1,19 @@
 # --
 # Kernel/Language/bb.pm - provides bavarian language translation
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: bb.pm,v 1.25.2.1 2007/09/13 14:01:40 mh Exp $
+# $Id: bb.pm,v 1.25.2.4 2008/05/28 08:03:42 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 package Kernel::Language::bb;
 
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.25.2.1 $';
+$VERSION = '$Revision: 1.25.2.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub Data {
@@ -320,11 +320,11 @@ sub Data {
         'Select your default spelling dictionary.' => 'Standard Rechtschreib-Wrterbuch auswhlen.',
         'Max. shown Tickets a page in Overview.' => 'Maximale Anzahl angezeigter Tickets pro Seite in der bersicht.',
         'Can\'t update password, passwords doesn\'t match! Please try it again!' => 'Passwrter sind nicht identisch! Bitte erneut versuchen!',
-        'Can\'t update password, invalid characters!' => 'Passwort konnte nicht aktuallisiert werden, Zeichen unglig.',
-        'Can\'t update password, need min. 8 characters!' => 'Passwort konnte nicht aktuallisiert werden, bentige min. 8 Zeichen.',
-        'Can\'t update password, need 2 lower and 2 upper characters!' => 'Passwort konnte nicht aktuallisiert werden, bentige min. einen grogeschriebener und einen kleingeschriebener Buchstaben.',
-        'Can\'t update password, need min. 1 digit!' => 'Passwort konnte nicht aktuallisiert werden, Passwort muss mit eine Zahl enthalten!',
-        'Can\'t update password, need min. 2 characters!' => 'Passwort konnte nicht aktuallisiert werden, Passwort muss zwei Buchstaben enthalten!',
+        'Can\'t update password, invalid characters!' => 'Passwort konnte nicht aktualisiert werden, Zeichen unglig.',
+        'Can\'t update password, need min. 8 characters!' => 'Passwort konnte nicht aktualisiert werden, bentige min. 8 Zeichen.',
+        'Can\'t update password, need 2 lower and 2 upper characters!' => 'Passwort konnte nicht aktualisiert werden, bentige min. einen grogeschriebener und einen kleingeschriebener Buchstaben.',
+        'Can\'t update password, need min. 1 digit!' => 'Passwort konnte nicht aktualisiert werden, Passwort muss mit eine Zahl enthalten!',
+        'Can\'t update password, need min. 2 characters!' => 'Passwort konnte nicht aktualisiert werden, Passwort muss zwei Buchstaben enthalten!',
 
         # Template: AAAStats
         'Stat' => 'Statistik',
@@ -611,8 +611,11 @@ sub Data {
         # Template: AdminCustomerUserServiceChangeForm
         'Customer Users <-> Services Management' => 'Kundanbenutzer <-> Services Verwaltung',
         'Select the customeruser:service relations.' => 'Auswahl der Kundanbenutzer:Service Beziehungen.',
+        'Allocate services to CustomerUser' => '',
+        'Allocate CustomerUser to service' => '',
 
         # Template: AdminCustomerUserServiceForm
+        'Edit default services.' => '',
 
         # Template: AdminEmail
         'Message sent to' => 'Nachricht gesendet an',
@@ -1060,7 +1063,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => 'Konfiguration exportieren',
-        'Informations about the Stat' => 'Informationen ber die Statistik',
+        'Information about the Stat' => 'Informationen ber die Statistik',
         'Exchange Axis' => 'Achsen vertauschen',
         'Configurable params of static stat' => 'Konfigurierbare Parameter der statischen Statistik',
         'No element selected.' => 'Es wurde kein Element ausgewhlt.',
@@ -1400,7 +1403,7 @@ sub Data {
         'Year' => 'Jahr',
         'A message must be spell checked!' => 'Eine Nachricht muss auf Rechtschreibung berprft werden!',
         'X-axis' => 'X-Achse',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Die E-Mail mit der Ticketnummer "<OTRS_TICKET>" ist an "<OTRS_BOUNCE_TO>" gebounced. Kontaktieren Sie diese Adresse fr weitere Nachfragen.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'Die E-Mail mit der Ticketnummer "<OTRS_TICKET>" ist an "<OTRS_BOUNCE_TO>" gebounced. Kontaktieren Sie diese Adresse fr weitere Nachfragen.',
         'A message should have a body!' => 'Eine Nachricht sollte einen Body haben!',
         'All Agents' => 'Alle Agenten',
         'Keywords' => 'Schlsselwrter',
