@@ -6,11 +6,11 @@
 #              Vadim Buzek
 #              Petr Ocasek
 # --
-# $Id: cz.pm,v 1.47 2007/06/28 23:58:32 martin Exp $
+# $Id: cz.pm,v 1.47.2.2 2008/05/28 08:03:42 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::cz;
@@ -18,7 +18,7 @@ package Kernel::Language::cz;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.47 $';
+$VERSION = '$Revision: 1.47.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub Data {
@@ -612,6 +612,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
+        # Template: AdminCustomerUserServiceChangeForm
+        'Customer Users <-> Services Management' => '',
+        'Select the customeruser:service relations.' => '',
+        'Allocate services to CustomerUser' => '',
+        'Allocate CustomerUser to service' => '',
+
+        # Template: AdminCustomerUserServiceForm
+        'Edit default services.' => '',
+
         # Template: AdminEmail
         'Message sent to' => 'Zprva odeslna',
         'Recipents' => 'Adresti',
@@ -1059,7 +1068,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => '',
-        'Informations about the Stat' => '',
+        'Information about the Stat' => '',
         'Exchange Axis' => '',
         'Configurable params of static stat' => '',
         'No element selected.' => '',
@@ -1395,7 +1404,7 @@ sub Data {
         'Admin-Email' => 'Email administrtora',
         'Stat#' => '',
         'A message must be spell checked!' => 'Zprva mus bt pravopisn zkontrolovan!',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'V email s slem ticketu "<OTRS_TICKET>" je odesln zpt na "<OTRS_BOUNCE_TO>". Kontaktujte tuto adresu pro dal infromace.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'V email s slem ticketu "<OTRS_TICKET>" je odesln zpt na "<OTRS_BOUNCE_TO>". Kontaktujte tuto adresu pro dal infromace.',
         'Mail Account Management' => '',
         'ArticleID' => 'ID poloky',
         'A message should have a body!' => 'Zprva by mla mt tlo!',
