@@ -4,11 +4,11 @@
 # Copyright (C) 2005 Alterado por Glaucia C. Messina (glauglauu@yahoo.com)
 # Copyright (C) 2007 Fabricio Luiz Machado <soprobr gmail.com>
 # --
-# $Id: pt_BR.pm,v 1.56 2007/06/28 23:58:33 martin Exp $
+# $Id: pt_BR.pm,v 1.56.2.2 2008/05/28 08:03:42 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::pt_BR;
@@ -16,7 +16,7 @@ package Kernel::Language::pt_BR;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.56 $';
+$VERSION = '$Revision: 1.56.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub Data {
@@ -610,6 +610,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
+        # Template: AdminCustomerUserServiceChangeForm
+        'Customer Users <-> Services Management' => '',
+        'Select the customeruser:service relations.' => '',
+        'Allocate services to CustomerUser' => '',
+        'Allocate CustomerUser to service' => '',
+
+        # Template: AdminCustomerUserServiceForm
+        'Edit default services.' => '',
+
         # Template: AdminEmail
         'Message sent to' => 'Mensagem enviada para',
         'Recipents' => 'Destinatrios',
@@ -1057,7 +1066,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => 'Exportar Configurao',
-        'Informations about the Stat' => 'Informaes sobre a Estatstica',
+        'Information about the Stat' => 'Informaes sobre a Estatstica',
         'Exchange Axis' => 'Trocar Eixo',
         'Configurable params of static stat' => 'Parmetros configurveis da estatstica esttica',
         'No element selected.' => 'Nenhum elemento selecionado.',
@@ -1392,7 +1401,7 @@ sub Data {
         'Options of the ticket data (e. g. OTRS_TICKET_Number, OTRS_TICKET_ID, OTRS_TICKET_Queue, OTRS_TICKET_State)' => 'Opes de dados do chamado (ex.: OTRS_TICKET_Number, OTRS_TICKET_ID, OTRS_TICKET_Queue, OTRS_TICKET_State;)',
         'A message must be spell checked!' => 'A mensagem necessita ser verificada ortograficamente!',
         'Options of the current customer user data (e. g. OTRS_CUSTOMER_DATA_USERFIRSTNAME)' => 'Opes de dados do usurio do cliente atual (ex.: OTRS_CUSTOMER_DATA_USERFIRSTNAME)',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => 'Seu email com o nmero de chamado "<OTRS_TICKET>" foi devolvido para "<OTRS_BOUNCE_TO>". Contate este endereo para mais informaes.',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => 'Seu email com o nmero de chamado "<OTRS_TICKET>" foi devolvido para "<OTRS_BOUNCE_TO>". Contate este endereo para mais informaes.',
         'ArticleID' => 'Id.do artigo',
         'A message should have a body!' => 'A mensagem deve conter um texto!',
         'All Agents' => 'Todos os Atendentes',
