@@ -1,12 +1,12 @@
 # --
 # Kernel/Language/sk_SK.pm - provides sk_SK language translation
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: sk_SK.pm,v 1.22 2007/06/28 23:58:33 martin Exp $
+# $Id: sk_SK.pm,v 1.22.2.2 2008/05/28 08:03:42 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Language::sk_SK;
@@ -14,7 +14,7 @@ package Kernel::Language::sk_SK;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.22 $';
+$VERSION = '$Revision: 1.22.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub Data {
@@ -608,6 +608,15 @@ sub Data {
 
         # Template: AdminCustomerUserGroupForm
 
+        # Template: AdminCustomerUserServiceChangeForm
+        'Customer Users <-> Services Management' => '',
+        'Select the customeruser:service relations.' => '',
+        'Allocate services to CustomerUser' => '',
+        'Allocate CustomerUser to service' => '',
+
+        # Template: AdminCustomerUserServiceForm
+        'Edit default services.' => '',
+
         # Template: AdminEmail
         'Message sent to' => '',
         'Recipents' => '',
@@ -1055,7 +1064,7 @@ sub Data {
 
         # Template: AgentStatsView
         'Export Config' => '',
-        'Informations about the Stat' => '',
+        'Information about the Stat' => '',
         'Exchange Axis' => '',
         'Configurable params of static stat' => '',
         'No element selected.' => '',
@@ -1476,7 +1485,7 @@ sub Data {
         'Riadenie radov' => 'Sub-Queue of',
         'Potrebujete asov konto!' => 'Close ticket',
         'Send me a notification if a ticket is moved into one of My Queues"."' => 'Poli mi oznmenie =>  ak je poiadavka premiestnen do jednho z mojich radov.',
-        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations.' => '',
+        'Your email with ticket number "<OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information.' => '',
         'priloi' => 'Pending Date',
         'zobrazen poiadavky' => 'Page',
         'Reintalova' => 'PGP Management',
@@ -1510,7 +1519,7 @@ sub Data {
         'Uloi' => 'Group Management',
         'login klientskho uvatea' => '(e. g. U5150)',
         'km' => 'Change priority of ticket',
-        'informova odosielatea.' => 'Your email with ticket number <OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further informations."',
+        'informova odosielatea.' => 'Your email with ticket number <OTRS_TICKET>" is bounced to "<OTRS_BOUNCE_TO>". Contact this address for further information."',
         'nata nastavenia' => 'Subgroup',
         'OTRS DB Password' => 'OTRS DB heslo',
         'Hlavika' => 'Value',
