@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AdminResponse.pm - provides admin std response module
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AdminResponse.pm,v 1.18 2006/11/02 12:20:51 tr Exp $
+# $Id: AdminResponse.pm,v 1.22 2007/01/30 14:31:37 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,9 +14,10 @@ package Kernel::Modules::AdminResponse;
 use strict;
 use Kernel::System::StdResponse;
 use Kernel::System::StdAttachment;
+use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.18 $';
+$VERSION = '$Revision: 1.22 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -38,10 +39,9 @@ sub new {
             $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
         }
     }
-
-    # lib object
     $Self->{StdResponseObject} = Kernel::System::StdResponse->new(%Param);
     $Self->{StdAttachmentObject} = Kernel::System::StdAttachment->new(%Param);
+    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
 
     return $Self;
 }
@@ -63,9 +63,9 @@ sub Run {
     my %AttachmentData = $Self->{StdAttachmentObject}->GetAllStdAttachments(Valid => 1);
     my %SelectedAttachmentData = ();
     if ($GetParam{ID}) {
-      %SelectedAttachmentData = $Self->{StdAttachmentObject}->StdAttachmentsByResponseID(
-        ID => $GetParam{ID},
-      );
+        %SelectedAttachmentData = $Self->{StdAttachmentObject}->StdAttachmentsByResponseID(
+            ID => $GetParam{ID},
+        );
     }
 
     # get data 2 form
@@ -149,11 +149,7 @@ sub _Mask {
     # build ValidID string
     $Param{'ValidOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
         Data => {
-          $Self->{DBObject}->GetTableData(
-            What => 'id, name',
-            Table => 'valid',
-            Valid => 0,
-          )
+            $Self->{ValidObject}->ValidList(),
         },
         Name => 'ValidID',
         SelectedID => $Param{ValidID},
@@ -162,12 +158,12 @@ sub _Mask {
     # build ResponseOption string
     $Param{'ResponseOption'} = $Self->{LayoutObject}->OptionStrgHashRef(
         Data => {
-          $Self->{DBObject}->GetTableData(
-            What => 'id, name, id',
-            Valid => 0,
-            Clamp => 1,
-            Table => 'standard_response',
-          )
+            $Self->{DBObject}->GetTableData(
+                What => 'id, name, id',
+                Valid => 0,
+                Clamp => 1,
+                Table => 'standard_response',
+            )
         },
         Name => 'ID',
         Size => 15,
@@ -177,14 +173,14 @@ sub _Mask {
     my %SecondDataTmp = %{$Param{Attachments}};
     my %DataTmp = %{$Param{SelectedAttachments}};
     $Param{AttachmentOption} .= "<SELECT NAME=\"IDs\" SIZE=3 multiple>\n";
-    foreach my $ID (sort keys %SecondDataTmp){
-       $Param{AttachmentOption} .= "<OPTION ";
-       foreach (sort keys %DataTmp){
-         if ($_ eq $ID) {
-               $Param{AttachmentOption} .= 'selected';
-         }
-       }
-      $Param{AttachmentOption} .= " VALUE=\"$ID\">$SecondDataTmp{$ID}</OPTION>\n";
+    foreach my $ID (sort keys %SecondDataTmp) {
+        $Param{AttachmentOption} .= "<OPTION ";
+        foreach (sort keys %DataTmp) {
+            if ($_ eq $ID) {
+                $Param{AttachmentOption} .= 'selected';
+            }
+        }
+        $Param{AttachmentOption} .= " VALUE=\"$ID\">$SecondDataTmp{$ID}</OPTION>\n";
     }
     $Param{AttachmentOption} .= "</SELECT>\n";
 
