@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AdminService.pm - admin frontend to manage services
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AdminService.pm,v 1.6 2007/06/13 10:36:46 mh Exp $
+# $Id: AdminService.pm,v 1.6.2.2 2008/03/25 13:27:05 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AdminService;
@@ -16,7 +16,7 @@ use Kernel::System::Service;
 use Kernel::System::Valid;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.6 $';
+$VERSION = '$Revision: 1.6.2.2 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -90,6 +90,7 @@ sub Run {
             Sort => 'TreeView',
             DisabledBranch => $ServiceData{Name},
             Translation => 0,
+            Max => 200,
         );
         # generate ValidOptionStrg
         my %ValidList = $Self->{ValidObject}->ValidList();
@@ -153,6 +154,14 @@ sub Run {
         # output header
         my $Output = $Self->{LayoutObject}->Header();
         $Output .= $Self->{LayoutObject}->NavigationBar();
+        # check if service is enabled to use it here
+        if ( !$Self->{ConfigObject}->Get('Ticket::Service') ) {
+            $Output .= $Self->{LayoutObject}->Notify(
+                Priority => 'Error',
+                Data     => '$Text{"You need to activate %s first to use it!", "Service"}',
+                Link => '$Env{"Baselink"}Action=AdminSysConfig&Subaction=Edit&SysConfigGroup=Ticket&SysConfigSubGroup=Core::Ticket#Ticket::Service"',
+            );
+        }
         # output overview
         $Self->{LayoutObject}->Block(
             Name => 'Overview',
