@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AgentTicketEmail.pm - to compose initial email to customer
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketEmail.pm,v 1.43 2007/09/03 22:10:33 martin Exp $
+# $Id: AgentTicketEmail.pm,v 1.43.2.6 2008/04/17 06:44:08 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AgentTicketEmail;
@@ -20,7 +20,7 @@ use Kernel::System::State;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.43 $';
+$VERSION = '$Revision: 1.43.2.6 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -484,8 +484,13 @@ sub Run {
         # check some values
         foreach (qw(To Cc Bcc)) {
             if ($GetParam{$_}) {
-                foreach my $Email (Mail::Address->parse($GetParam{$_})) {
-                    if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
+                EMAIL:
+                for my $Email ( Mail::Address->parse( $GetParam{$_} ) ) {
+                    # skip check if the email address is not fully RFC 2822 compilant
+                    next EMAIL if !$Email->host();
+                    next EMAIL if !$Email->user();
+
+                    if ( !$Self->{CheckItemObject}->CheckEmail( Address => $Email->address() ) ) {
                         $Error{"$_ invalid"} .= $Self->{CheckItemObject}->CheckError();
                     }
                 }
@@ -541,6 +546,17 @@ sub Run {
         }
 
         if (%Error) {
+
+            # get services
+            my $Services = $Self->_GetServices(
+                CustomerUserID => $CustomerUser || '',
+                QueueID => $NewQueueID || 1,
+            );
+            # reset previous ServiceID to reset SLA-List if no service is selected
+            if ( !$Services->{$GetParam{ServiceID}} ) {
+                $GetParam{ServiceID} = '';
+            }
+
             # header
             $Output .= $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -555,10 +571,7 @@ sub Run {
                 NextState => $NextState,
                 Priorities => $Self->_GetPriorities(QueueID => $NewQueueID || 1),
                 Types => $Self->_GetTypes(QueueID => $NewQueueID || 1),
-                Services => $Self->_GetServices(
-                    CustomerUserID => $CustomerUser || '',
-                    QueueID => $NewQueueID || 1,
-                ),
+                Services => $Services,
                 SLAs => $Self->_GetSLAs(QueueID => $NewQueueID || 1, %GetParam),
                 CustomerID => $Self->{LayoutObject}->Ascii2Html(Text => $CustomerID),
                 CustomerUser => $CustomerUser,
@@ -586,13 +599,15 @@ sub Run {
                 if ($CustomerData{UserCustomerID}) {
                     push (@CustomerIDs, $CustomerData{UserCustomerID});
                 }
-                @TicketIDs = $Self->{TicketObject}->TicketSearch(
-                    Result => 'ARRAY',
-                    Limit => $Self->{Config}->{ShownCustomerTickets},
-                    CustomerID => \@CustomerIDs,
-                    UserID => $Self->{UserID},
-                    Permission => 'ro',
-                );
+                if ( @CustomerIDs ) {
+                    @TicketIDs = $Self->{TicketObject}->TicketSearch(
+                        Result => 'ARRAY',
+                        Limit => $Self->{Config}->{ShownCustomerTickets},
+                        CustomerID => \@CustomerIDs,
+                        UserID => $Self->{UserID},
+                        Permission => 'ro',
+                    );
+                }
             }
             foreach my $TicketID (@TicketIDs) {
                 my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(TicketID => $TicketID);
@@ -605,7 +620,17 @@ sub Run {
                     ReturnSubType => '-',
                     UserID => $Self->{UserID},
                 );
+
                 my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+                # ticket title
+                if ( $Self->{ConfigObject}->Get('Ticket::Frontend::Title') ) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'Title',
+                        Data => { %Param, %Article },
+                    );
+                }
+
                 # run ticket menu modules
                 if (ref($Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule')) eq 'HASH') {
                     my %Menus = %{$Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule')};
@@ -1008,23 +1033,27 @@ sub _GetTos {
             Result => 'HASH',
             Cached => 1,
         );
-        foreach (keys %Tos) {
-            if ($UserGroups{$Self->{QueueObject}->GetQueueGroupID(QueueID => $_)}) {
-                $NewTos{$_} = $Tos{$_};
-            }
-        }
+
         # build selection string
-        foreach (keys %NewTos) {
-            my %QueueData = $Self->{QueueObject}->QueueGet(ID => $_);
-            my $Srting = $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionString') || '<Realname> <<Email>> - Queue: <Queue>';
-            $Srting =~ s/<Queue>/$QueueData{Name}/g;
-            $Srting =~ s/<QueueComment>/$QueueData{Comment}/g;
-            if ($Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionType') ne 'Queue') {
-                my %SystemAddressData = $Self->{SystemAddress}->SystemAddressGet(ID => $NewTos{$_});
-                $Srting =~ s/<Realname>/$SystemAddressData{Realname}/g;
-                $Srting =~ s/<Email>/$SystemAddressData{Name}/g;
+        for my $QueueID ( keys %Tos ) {
+            my %QueueData = $Self->{QueueObject}->QueueGet( ID => $QueueID, Cache => 1 );
+
+            # permission check, can we create new tickets in queue
+            next if !$UserGroups{ $QueueData{GroupID} };
+
+            my $String = $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionString')
+                || '<Realname> <<Email>> - Queue: <Queue>';
+            $String =~ s/<Queue>/$QueueData{Name}/g;
+            $String =~ s/<QueueComment>/$QueueData{Comment}/g;
+            if ( $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionType') ne 'Queue' )
+            {
+                my %SystemAddressData = $Self->{SystemAddress}->SystemAddressGet(
+                    ID => $Tos{$QueueID},
+                );
+                $String =~ s/<Realname>/$SystemAddressData{Realname}/g;
+                $String =~ s/<Email>/$SystemAddressData{Name}/g;
             }
-            $NewTos{$_} = $Srting;
+            $NewTos{$QueueID} = $String;
         }
     }
     # adde empty selection
@@ -1132,6 +1161,7 @@ sub _MaskEmailNew {
             Sort => 'TreeView',
             Translation => 0,
             OnChange => "document.compose.ExpandCustomerName.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'TicketService',
@@ -1145,6 +1175,7 @@ sub _MaskEmailNew {
             Sort => 'AlphanumericValue',
             Translation => 0,
             OnChange => "document.compose.ExpandCustomerName.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'TicketSLA',
