@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketHistory.pm - ticket history
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketHistory.pm,v 1.5 2006/08/29 17:17:24 martin Exp $
+# $Id: AgentTicketHistory.pm,v 1.7 2007/01/20 18:04:49 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,10 +14,9 @@ package Kernel::Modules::AgentTicketHistory;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.5 $';
+$VERSION = '$Revision: 1.7 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -32,23 +31,24 @@ sub new {
 
     # check needed Opjects
     foreach (qw(DBObject TicketObject LayoutObject LogObject UserObject ConfigObject)) {
-        die "Got no $_!" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
-
     return $Self;
 }
-# --
+
 sub Run {
     my $Self = shift;
     my %Param = @_;
     my $Output;
     # check needed stuff
     if (!$Self->{TicketID}) {
-      # error page
-      return $Self->{LayoutObject}->ErrorScreen(
-          Message => "Can't show history, no TicketID is given!",
-          Comment => 'Please contact the admin.',
-      );
+        # error page
+        return $Self->{LayoutObject}->ErrorScreen(
+            Message => "Can't show history, no TicketID is given!",
+            Comment => 'Please contact the admin.',
+        );
     }
     # check permissions
     if (!$Self->{TicketObject}->Permission(
@@ -115,6 +115,5 @@ sub Run {
 
     return $Output;
 }
-# --
 
-1;
+1;
\ No newline at end of file
