@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AgentTicketNote.pm - to add notes to a ticket
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketNote.pm,v 1.34.2.1 2007/10/26 14:20:36 mh Exp $
+# $Id: AgentTicketNote.pm,v 1.34.2.4 2008/03/25 13:27:05 ub Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AgentTicketNote;
@@ -16,7 +16,7 @@ use Kernel::System::State;
 use Kernel::System::Web::UploadCache;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.34.2.1 $';
+$VERSION = '$Revision: 1.34.2.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -200,7 +200,7 @@ sub Run {
 
         if (!$Ticket{ $FreeTimePrefix }) {
 
-            for my $Type (qw(Optional Used Year Month Day Hour Minute)) {
+            for my $Type (qw(Used Year Month Day Hour Minute)) {
                 delete $GetParam{ $FreeTimePrefix . $Type };
             }
 
@@ -716,6 +716,7 @@ sub _Mask {
             Sort => 'TreeView',
             Translation => 0,
             OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'Service',
@@ -737,6 +738,7 @@ sub _Mask {
             Sort => 'AlphanumericValue',
             Translation => 0,
             OnChange => "document.compose.Expand.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'SLA',
@@ -948,7 +950,7 @@ sub _Mask {
             my $GID = $Self->{QueueObject}->GetQueueGroupID(QueueID => $Ticket{QueueID});
             my %MemberList = $Self->{GroupObject}->GroupMemberList(
                 GroupID => $GID,
-                Type => 'rw',
+                Type => 'note',
                 Result => 'HASH',
                 Cached => 1,
             );
