@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AgentTicketPhone.pm - to handle phone calls
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketPhone.pm,v 1.45 2007/07/26 17:00:42 martin Exp $
+# $Id: AgentTicketPhone.pm,v 1.46.2.8 2008/04/17 06:44:08 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AgentTicketPhone;
@@ -17,10 +17,11 @@ use Kernel::System::CustomerUser;
 use Kernel::System::CheckItem;
 use Kernel::System::Web::UploadCache;
 use Kernel::System::State;
+use Kernel::System::LinkObject;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.45 $';
+$VERSION = '$Revision: 1.46.2.8 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -65,7 +66,7 @@ sub Run {
     my %Param = @_;
     # get params
     my %GetParam = ();
-    foreach (qw(AttachmentUpload ArticleID PriorityID NewUserID
+    foreach (qw(AttachmentUpload LinkTicketID ArticleID PriorityID NewUserID
         From Subject Body NextStateID TimeUnits
         Year Month Day Hour Minute
         NewResponsibleID ResponsibleAll OwnerAll TypeID ServiceID SLAID
@@ -129,6 +130,24 @@ sub Run {
                 TicketNumber => $Article{TicketNumber},
                 Subject => $Article{Subject} || '',
             );
+
+            # get attachments
+            my %ArticleIndex = $Self->{TicketObject}->ArticleAttachmentIndex(
+                ArticleID => $GetParam{ArticleID},
+                UserID => $Self->{UserID},
+            );
+            for my $Index ( keys %ArticleIndex ) {
+                my %Attachment = $Self->{TicketObject}->ArticleAttachment(
+                    ArticleID => $GetParam{ArticleID},
+                    FileID => $Index,
+                    UserID => $Self->{UserID},
+                );
+                $Self->{UploadCachObject}->FormIDAddFile(
+                    FormID => $Self->{FormID},
+                    %Attachment,
+                );
+            }
+
             # check if original content isn't text/plain or text/html, don't use it
             if ($Article{'ContentType'}) {
                 if ($Article{'ContentType'} =~ /text\/html/i) {
@@ -225,6 +244,10 @@ sub Run {
                 %ArticleFreeDefault,
             },
         );
+
+        # get all attachments meta data
+        my @Attachments = $Self->{UploadCachObject}->FormIDGetAllFilesMeta( FormID => $Self->{FormID} );
+
         # html output
         $Output .= $Self->_MaskPhoneNew(
             QueueID => $Self->{QueueID},
@@ -244,6 +267,8 @@ sub Run {
             CustomerID => $Article{CustomerID},
             CustomerUser => $Article{CustomerUserID},
             CustomerData => \%CustomerData,
+            Attachments => \@Attachments,
+            LinkTicketID => $GetParam{LinkTicketID} || '',
             %TicketFreeTextHTML,
             %TicketFreeTimeHTML,
             %ArticleFreeTextHTML,
@@ -466,10 +491,14 @@ sub Run {
                 );
             }
         }
+        # check email address
+        EMAIL:
+        for my $Email ( Mail::Address->parse( $GetParam{From} ) ) {
+            # skip check if the email address is not fully RFC 2822 compilant
+            next EMAIL if !$Email->host();
+            next EMAIL if !$Email->user();
 
-        # check some values
-        foreach my $Email (Mail::Address->parse($GetParam{From})) {
-            if (!$Self->{CheckItemObject}->CheckEmail(Address => $Email->address())) {
+            if ( !$Self->{CheckItemObject}->CheckEmail( Address => $Email->address() ) ) {
                 $Error{"From invalid"} .= $Self->{CheckItemObject}->CheckError();
             }
         }
@@ -486,6 +515,17 @@ sub Run {
             $Error{"Service invalid"} = 'invalid';
         }
         if (%Error) {
+
+            # get services
+            my $Services = $Self->_GetServices(
+                CustomerUserID => $CustomerUser || '',
+                QueueID => $NewQueueID || 1,
+            );
+            # reset previous ServiceID to reset SLA-List if no service is selected
+            if ( !$Services->{$GetParam{ServiceID}} ) {
+                $GetParam{ServiceID} = '';
+            }
+
             # header
             my $Output = $Self->{LayoutObject}->Header();
             $Output .= $Self->{LayoutObject}->NavigationBar();
@@ -501,10 +541,7 @@ sub Run {
                 NextState => $NextState,
                 Priorities => $Self->_GetPriorities(QueueID => $NewQueueID || 1),
                 Types => $Self->_GetTypes(QueueID => $NewQueueID || 1),
-                Services => $Self->_GetServices(
-                    CustomerUserID => $CustomerUser || '',
-                    QueueID => $NewQueueID || 1,
-                ),
+                Services => $Services,
                 SLAs => $Self->_GetSLAs(QueueID => $NewQueueID || 1, %GetParam),
                 CustomerID => $Self->{LayoutObject}->Ascii2Html(Text => $CustomerID),
                 CustomerUser => $CustomerUser,
@@ -530,14 +567,15 @@ sub Run {
                     push (@CustomerIDs, $CustomerData{UserCustomerID});
                 }
 
-                @TicketIDs = $Self->{TicketObject}->TicketSearch(
-                    Result => 'ARRAY',
-                    Limit => $Self->{Config}->{ShownCustomerTickets},
-                    CustomerID => \@CustomerIDs,
-
-                    UserID => $Self->{UserID},
-                    Permission => 'ro',
-                );
+                if ( @CustomerIDs ) {
+                    @TicketIDs = $Self->{TicketObject}->TicketSearch(
+                        Result => 'ARRAY',
+                        Limit => $Self->{Config}->{ShownCustomerTickets},
+                        CustomerID => \@CustomerIDs,
+                        UserID => $Self->{UserID},
+                        Permission => 'ro',
+                    );
+                }
             }
             foreach my $TicketID (@TicketIDs) {
                 my %Article = $Self->{TicketObject}->ArticleLastCustomerArticle(TicketID => $TicketID);
@@ -551,6 +589,15 @@ sub Run {
                     UserID => $Self->{UserID},
                 );
                 my %AclAction = $Self->{TicketObject}->TicketAclActionData();
+
+                # ticket title
+                if ( $Self->{ConfigObject}->Get('Ticket::Frontend::Title') ) {
+                    $Self->{LayoutObject}->Block(
+                        Name => 'Title',
+                        Data => { %Param, %Article },
+                    );
+                }
+
                 # run ticket menu modules
                 if (ref($Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule')) eq 'HASH') {
                     my %Menus = %{$Self->{ConfigObject}->Get('Ticket::Frontend::PreMenuModule')};
@@ -605,7 +652,6 @@ sub Run {
                         %AclAction,
                         %Article,
                         Age => $Self->{LayoutObject}->CustomerAge(Age => $Article{Age}, Space => ' ') || '',
-                        TicketOverTime => $Self->{LayoutObject}->CustomerAge(Age => $Article{TicketOverTime}, Space => ' ') || '',
                     }
                 );
             }
@@ -767,6 +813,18 @@ sub Run {
             }
             # remove pre submited attachments
             $Self->{UploadCachObject}->FormIDRemove(FormID => $Self->{FormID});
+            # link tickets
+            if ( $GetParam{LinkTicketID} && $Self->{Config}->{SplitLinkType} ) {
+                my $LinkObject = Kernel::System::LinkObject->new(%{ $Self });
+                $LinkObject->LoadBackend(Module => 'Ticket');
+                $LinkObject->LinkObject(
+                    LinkType => $Self->{Config}->{SplitLinkType},
+                    LinkID1 => $GetParam{LinkTicketID},
+                    LinkObject1 => 'Ticket',
+                    LinkID2 => $TicketID,
+                    LinkObject2 => 'Ticket',
+                );
+            }
             # should i set an unlock?
             my %StateData = $Self->{StateObject}->StateGet(ID => $GetParam{NextStateID});
             if ($StateData{TypeName} =~ /^close/i) {
@@ -956,23 +1014,26 @@ sub _GetTos {
             Result => 'HASH',
             Cached => 1,
         );
-        foreach (keys %Tos) {
-            if ($UserGroups{$Self->{QueueObject}->GetQueueGroupID(QueueID => $_)}) {
-                $NewTos{$_} = $Tos{$_};
-            }
-        }
+
         # build selection string
-        foreach (keys %NewTos) {
-            my %QueueData = $Self->{QueueObject}->QueueGet(ID => $_);
-            my $Srting = $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionString') || '<Realname> <<Email>> - Queue: <Queue>';
-            $Srting =~ s/<Queue>/$QueueData{Name}/g;
-            $Srting =~ s/<QueueComment>/$QueueData{Comment}/g;
-            if ($Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionType') ne 'Queue') {
-                my %SystemAddressData = $Self->{SystemAddress}->SystemAddressGet(ID => $NewTos{$_});
-                $Srting =~ s/<Realname>/$SystemAddressData{Realname}/g;
-                $Srting =~ s/<Email>/$SystemAddressData{Name}/g;
+        for my $QueueID ( keys %Tos ) {
+            my %QueueData = $Self->{QueueObject}->QueueGet( ID => $QueueID, Cache => 1 );
+
+            # permission check, can we create new tickets in queue
+            next if !$UserGroups{ $QueueData{GroupID} };
+
+            my $String = $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionString')
+                || '<Realname> <<Email>> - Queue: <Queue>';
+            $String =~ s/<Queue>/$QueueData{Name}/g;
+            $String =~ s/<QueueComment>/$QueueData{Comment}/g;
+            if ( $Self->{ConfigObject}->Get('Ticket::Frontend::NewQueueSelectionType') ne 'Queue' ) {
+                my %SystemAddressData = $Self->{SystemAddress}->SystemAddressGet(
+                    ID => $Tos{ $QueueID },
+                );
+                $String =~ s/<Realname>/$SystemAddressData{Realname}/g;
+                $String =~ s/<Email>/$SystemAddressData{Name}/g;
             }
-            $NewTos{$_} = $Srting;
+            $NewTos{ $QueueID } = $String;
         }
     }
     # adde empty selection
@@ -1080,6 +1141,7 @@ sub _MaskPhoneNew {
             Sort => 'TreeView',
             Translation => 0,
             OnChange => "document.compose.ExpandCustomerName.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'TicketService',
@@ -1093,6 +1155,7 @@ sub _MaskPhoneNew {
             Sort => 'AlphanumericValue',
             Translation => 0,
             OnChange => "document.compose.ExpandCustomerName.value='3'; document.compose.submit(); return false;",
+            Max => 200,
         );
         $Self->{LayoutObject}->Block(
             Name => 'TicketSLA',
