@@ -1,12 +1,12 @@
 # --
 # Kernel/Modules/AgentTicketPhoneOutbound.pm - to handle phone calls
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: AgentTicketPhoneOutbound.pm,v 1.12 2007/03/14 12:55:00 martin Exp $
+# $Id: AgentTicketPhoneOutbound.pm,v 1.12.2.1 2008/02/18 16:36:36 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::Modules::AgentTicketPhoneOutbound;
@@ -20,7 +20,7 @@ use Kernel::System::State;
 use Mail::Address;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.12 $';
+$VERSION = '$Revision: 1.12.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -94,7 +94,7 @@ sub Run {
             )) {
                 # show lock state
                 $Self->{LayoutObject}->Block(
-                    Name => 'TicketLocked',
+                    Name => 'PropertiesLock',
                     Data => {
                         %Param,
                         TicketID => $Self->{TicketID},
