@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentTicketQueue.pm - the queue view of all tickets
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentTicketQueue.pm,v 1.20 2006/09/29 13:06:25 mh Exp $
+# $Id: AgentTicketQueue.pm,v 1.36 2007/06/28 22:13:12 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -17,10 +17,9 @@ use Kernel::System::Lock;
 use Kernel::System::CustomerUser;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.20 $';
+$VERSION = '$Revision: 1.36 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -39,40 +38,33 @@ sub new {
             $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
         }
     }
-    # --
+
     # some new objects
-    # --
     $Self->{CustomerUserObject} = Kernel::System::CustomerUser->new(%Param);
     $Self->{StateObject} = Kernel::System::State->new(%Param);
     $Self->{LockObject} = Kernel::System::Lock->new(%Param);
 
-    # --
     # get config data
-    # --
-    $Self->{ViewableSenderTypes} = $Self->{ConfigObject}->Get('Ticket::ViewableSenderTypes')
-           || die 'No Config entry "Ticket::ViewableSenderTypes"!';
+    $Self->{ViewableSenderTypes} = $Self->{ConfigObject}->Get('Ticket::ViewableSenderTypes') ||
+        $Self->{LayoutObject}->FatalError(Message => 'No Config entry "Ticket::ViewableSenderTypes"!');
     $Self->{CustomQueue} = $Self->{ConfigObject}->Get('Ticket::CustomQueue') || '???';
     # default viewable tickets a page
     $Self->{ViewableTickets} = $Self->{UserQueueViewShowTickets} ||
         $Self->{ConfigObject}->Get('PreferencesGroups')->{QueueViewShownTickets}->{DataSelected} || 15;
-
-    # --
     # get params
-    # --
     $Self->{ViewAll} = $Self->{ParamObject}->GetParam(Param => 'ViewAll') || 0;
     $Self->{Start} = $Self->{ParamObject}->GetParam(Param => 'Start') || 1;
     # viewable tickets a page
-    $Self->{Limit} =  $Self->{ViewableTickets} + $Self->{Start} - 1;
+    $Self->{Limit} = $Self->{ViewableTickets} + $Self->{Start} - 1;
     # sure is sure!
     $Self->{MaxLimit} = $Self->{ConfigObject}->Get('Ticket::Frontend::QueueMaxShown') || 1200;
     if ($Self->{Limit} > $Self->{MaxLimit}) {
         $Self->{Limit} = $Self->{MaxLimit};
     }
-    # --
+
     # all static variables
-    # --
     my @ViewableStateIDs = $Self->{StateObject}->StateGetStatesByType(
-        Type   => 'Viewable',
+        Type => 'Viewable',
         Result => 'ID',
     );
     $Self->{ViewableStateIDs} = \@ViewableStateIDs;
@@ -111,53 +103,65 @@ sub Run {
     # build NavigationBar
     $Output .= $Self->{LayoutObject}->NavigationBar();
     # to get the output faster!
-    print $Output; $Output = '';
-    # --
+    $Self->{LayoutObject}->Print(Output => \$Output); $Output = '';
+
     # check old tickets, show it and return if needed
-    # --
     my $NoEscalationGroup = $Self->{ConfigObject}->Get('Ticket::Frontend::NoEscalationGroup') || '';
     if ($Self->{UserID} eq '1' ||
-        ($Self->{"UserIsGroup[$NoEscalationGroup]"} && $Self->{"UserIsGroup[$NoEscalationGroup]"} eq 'Yes')) {
+        ($Self->{"UserIsGroup[$NoEscalationGroup]"} && $Self->{"UserIsGroup[$NoEscalationGroup]"} eq 'Yes')
+    ) {
         # do not show escalated tickets
     }
     else {
-        if (my @ViewableTickets = $Self->{TicketObject}->GetOverTimeTickets(UserID=> $Self->{UserID})) {
-            # show over time ticket's
-            $Self->{LayoutObject}->Block(
-                Name => 'EscalationNav',
-                Data => {
-                    Message => 'Please answer this ticket(s) to get back to the normal queue view!',
-                },
-            );
-            print $Self->{LayoutObject}->Output(
-                TemplateFile => 'AgentTicketQueue',
-                Data => { %Param },
-            );
-            my $Counter = 0;
-            foreach (@ViewableTickets) {
-                $Counter++;
-                print $Self->ShowTicket(TicketID => $_, Counter => $Counter);
-            }
-            # get page footer
-            return $Self->{LayoutObject}->Footer();
-        }
+#        if (my @ViewableTickets = $Self->{TicketObject}->GetOverTimeTickets(UserID=> $Self->{UserID})) {
+#            # show over time ticket's
+#            $Self->{LayoutObject}->Block(
+#                Name => 'EscalationNav',
+#                Data => {
+#                    Message => 'Please answer this ticket(s) to get back to the normal queue view!',
+#                },
+#            );
+#            $Self->{LayoutObject}->Print(
+#                Output => \$Self->{LayoutObject}->Output(
+#                    TemplateFile => 'AgentTicketQueue',
+#                    Data => {
+#                        %Param,
+#                    },
+#                ),
+#            );
+#            my $Counter = 0;
+#            foreach (@ViewableTickets) {
+#                $Counter++;
+#                $Self->{LayoutObject}->Print(
+#                    Output => \$Self->ShowTicket(
+#                        TicketID => $_,
+#                        Counter => $Counter,
+#                    ),
+#                );
+#            }
+#            # get page footer
+#            return $Self->{LayoutObject}->Footer();
+#        }
     }
-    # --
+
     # build queue view ...
-    # --
     my @ViewableQueueIDs = ();
     if ($Self->{QueueID} == 0) {
         @ViewableQueueIDs = $Self->{QueueObject}->GetAllCustomQueues(
-            UserID => $Self->{UserID}
+            UserID => $Self->{UserID},
         );
     }
     else {
         @ViewableQueueIDs = ($Self->{QueueID});
     }
     $Self->BuildQueueView(QueueIDs => \@ViewableQueueIDs);
-    print $Self->{LayoutObject}->Output(
-        TemplateFile => 'AgentTicketQueue',
-        Data => { %Param },
+    $Self->{LayoutObject}->Print(
+        Output => \$Self->{LayoutObject}->Output(
+            TemplateFile => 'AgentTicketQueue',
+            Data => {
+                %Param,
+            },
+        ),
     );
     # get user groups
     my $Type = 'rw';
@@ -170,53 +174,51 @@ sub Run {
         Result => 'ID',
         Cached => 1,
     );
-    # --
     # get data (viewable tickets...)
-    # --
     my @ViewableTickets = ();
     my $SortBy = $Self->{ConfigObject}->Get('Ticket::Frontend::QueueSortBy::Default') || 'Age';
     my %SortOptions = (
-        Owner            => 'st.user_id',
-        CustomerID       => 'st.customer_id',
-        State            => 'st.ticket_state_id',
-        Ticket           => 'st.tn',
-        Title            => 'st.title',
-        Queue            => 'sq.name',
-        Priority         => 'st.ticket_priority_id',
-        Age              => 'st.create_time_unix',
-        TicketFreeTime1  => 'st.freetime1',
-        TicketFreeTime2  => 'st.freetime2',
-        TicketFreeKey1   => 'st.freekey1',
-        TicketFreeText1  => 'st.freetext1',
-        TicketFreeKey2   => 'st.freekey2',
-        TicketFreeText2  => 'st.freetext2',
-        TicketFreeKey3   => 'st.freekey3',
-        TicketFreeText3  => 'st.freetext3',
-        TicketFreeKey4   => 'st.freekey4',
-        TicketFreeText4  => 'st.freetext4',
-        TicketFreeKey5   => 'st.freekey5',
-        TicketFreeText5  => 'st.freetext5',
-        TicketFreeKey6   => 'st.freekey6',
-        TicketFreeText6  => 'st.freetext6',
-        TicketFreeKey7   => 'st.freekey7',
-        TicketFreeText7  => 'st.freetext7',
-        TicketFreeKey8   => 'st.freekey8',
-        TicketFreeText8  => 'st.freetext8',
-        TicketFreeKey9   => 'st.freekey9',
-        TicketFreeText9  => 'st.freetext9',
-        TicketFreeKey10  => 'st.freekey10',
+        Owner => 'st.user_id',
+        CustomerID => 'st.customer_id',
+        State => 'st.ticket_state_id',
+        Ticket => 'st.tn',
+        Title => 'st.title',
+        Queue => 'sq.name',
+        Priority => 'st.ticket_priority_id',
+        Age => 'st.create_time_unix',
+        TicketFreeTime1 => 'st.freetime1',
+        TicketFreeTime2 => 'st.freetime2',
+        TicketFreeKey1 => 'st.freekey1',
+        TicketFreeText1 => 'st.freetext1',
+        TicketFreeKey2 => 'st.freekey2',
+        TicketFreeText2 => 'st.freetext2',
+        TicketFreeKey3 => 'st.freekey3',
+        TicketFreeText3 => 'st.freetext3',
+        TicketFreeKey4 => 'st.freekey4',
+        TicketFreeText4 => 'st.freetext4',
+        TicketFreeKey5 => 'st.freekey5',
+        TicketFreeText5 => 'st.freetext5',
+        TicketFreeKey6 => 'st.freekey6',
+        TicketFreeText6 => 'st.freetext6',
+        TicketFreeKey7 => 'st.freekey7',
+        TicketFreeText7 => 'st.freetext7',
+        TicketFreeKey8 => 'st.freekey8',
+        TicketFreeText8 => 'st.freetext8',
+        TicketFreeKey9 => 'st.freekey9',
+        TicketFreeText9 => 'st.freetext9',
+        TicketFreeKey10 => 'st.freekey10',
         TicketFreeText10 => 'st.freetext10',
-        TicketFreeKey11  => 'st.freekey11',
+        TicketFreeKey11 => 'st.freekey11',
         TicketFreeText11 => 'st.freetext11',
-        TicketFreeKey12  => 'st.freekey12',
+        TicketFreeKey12 => 'st.freekey12',
         TicketFreeText12 => 'st.freetext12',
-        TicketFreeKey13  => 'st.freekey13',
+        TicketFreeKey13 => 'st.freekey13',
         TicketFreeText13 => 'st.freetext13',
-        TicketFreeKey14  => 'st.freekey14',
+        TicketFreeKey14 => 'st.freekey14',
         TicketFreeText14 => 'st.freetext14',
-        TicketFreeKey15  => 'st.freekey15',
+        TicketFreeKey15 => 'st.freekey15',
         TicketFreeText15 => 'st.freetext15',
-        TicketFreeKey16  => 'st.freekey16',
+        TicketFreeKey16 => 'st.freekey16',
         TicketFreeText16 => 'st.freetext16',
     );
 
@@ -266,8 +268,6 @@ sub Run {
         $SQL .= " ) AND ".
             " sq.group_id IN ( ${\(join ', ', @GroupIDs)} ) ".
             " ORDER BY st.ticket_priority_id DESC, $SortOptions{$SortBy} $Order";
-#            " ORDER BY st.ticket_priority_id DESC, st.freetime1 ASC";
-#            " ORDER BY st.ticket_priority_id DESC, st.create_time_unix $Order";
         $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Self->{Limit});
         my $Counter = 0;
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -277,13 +277,16 @@ sub Run {
             $Counter++;
         }
     }
-    # --
     # show ticket's
-    # --
     my $Counter = 0;
     foreach (@ViewableTickets) {
         $Counter++;
-        print $Self->ShowTicket(TicketID => $_, Counter => $Counter);
+        $Self->{LayoutObject}->Print(
+            Output => \$Self->ShowTicket(
+                TicketID => $_,
+                Counter => $Counter,
+            ),
+        );
     }
     # get page footer
     $Output .= $Self->{LayoutObject}->Footer();
@@ -312,11 +315,7 @@ sub ShowTicket {
             # load module
             if ($Self->{MainObject}->Require($Jobs{$Job}->{Module})) {
                 my $Object = $Jobs{$Job}->{Module}->new(
-                    ConfigObject => $Self->{ConfigObject},
-                    LogObject => $Self->{LogObject},
-                    DBObject => $Self->{DBObject},
-                    LayoutObject => $Self->{LayoutObject},
-                    TicketObject => $Self->{TicketObject},
+                    %{$Self},
                     ArticleID => $Article{ArticleID},
                     UserID => $Self->{UserID},
                     Debug => $Self->{Debug},
@@ -339,9 +338,7 @@ sub ShowTicket {
     }
     # fetch all std. responses ...
     my %StdResponses = $Self->{QueueObject}->GetStdResponses(QueueID => $Article{QueueID});
-    # --
     # customer info
-    # --
     my %CustomerData = ();
     if ($Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoQueue')) {
         if ($Article{CustomerUserID}) {
@@ -355,9 +352,8 @@ sub ShowTicket {
             );
         }
     }
-    # --
+
     # build ticket view
-    # --
     foreach (qw(From To Cc Subject)) {
         if ($Article{$_}) {
             $Self->{LayoutObject}->Block(
@@ -370,43 +366,19 @@ sub ShowTicket {
         }
     }
     foreach (1..3) {
-        if ($Article{"FreeText$_"}) {
+        if ($Article{"ArticleFreeText$_"}) {
             $Self->{LayoutObject}->Block(
                 Name => 'ArticleFreeText',
                 Data => {
-                    Key => $Article{"FreeKey$_"},
-                    Value => $Article{"FreeText$_"},
+                    Key => $Article{"ArticleFreeKey$_"},
+                    Value => $Article{"ArticleFreeText$_"},
                 },
             );
         }
     }
     # create human age
     $Article{Age} = $Self->{LayoutObject}->CustomerAge(Age => $Article{Age}, Space => ' ');
-    # --
-    # prepare escalation time
-    # --
-    if ($Article{TicketOverTime}) {
-        if ($Article{TicketOverTime} <= -60*20) {
-            $Param{TicketOverTimeFont} = "<font color='$Self->{HighlightColor2}'>";
-            $Param{TicketOverTimeFontEnd} = '</font>';
-        }
-        elsif ($Article{TicketOverTime} <= -60*40) {
-            $Param{TicketOverTimeFont} = "<font color='$Self->{HighlightColor1}'>";
-            $Param{TicketOverTimeFontEnd} = '</font>';
-        }
-        # create string
-        $Article{TicketOverTime} = $Self->{LayoutObject}->CustomerAge(
-            Age => $Article{TicketOverTime},
-            Space => '<br>',
-        );
-        if ($Param{TicketOverTimeFont} && $Param{TicketOverTimeFontEnd}) {
-            $Article{TicketOverTime} = $Param{TicketOverTimeFont}.
-                $Article{TicketOverTime}.$Param{TicketOverTimeFontEnd};
-        }
-    }
-    else {
-        $Article{TicketOverTime} = '$Text{"none"}';
-    }
+
     # customer info string
     if ($Self->{ConfigObject}->Get('Ticket::Frontend::CustomerInfoQueue')) {
         $Param{CustomerTable} = $Self->{LayoutObject}->AgentCustomerViewTable(
@@ -428,17 +400,16 @@ sub ShowTicket {
         TicketID => $Article{TicketID},
         ArticleID => $Article{ArticleID},
     );
-    # --
+
     # check if just a only html email
-    # --
     if (my $MimeTypeText = $Self->{LayoutObject}->CheckMimeType(%Article, Action => 'AgentTicketZoom')) {
         $Article{BodyNote} = $MimeTypeText;
         $Article{Body} = '';
     }
     else {
-         # html quoting
+        # html quoting
         $Article{Body} = $Self->{LayoutObject}->Ascii2Html(
-            NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine') || 85,
+            NewLine => $Self->{ConfigObject}->Get('DefaultViewNewLine'),
             Text => $Article{Body},
             VMax => $Self->{ConfigObject}->Get('DefaultPreViewLines') || 25,
             LinkFeature => 1,
@@ -453,14 +424,6 @@ sub ShowTicket {
             $Article{BodyNote} = $CharsetText;
         }
     }
-    # get MoveQueuesStrg
-    if ($Self->{ConfigObject}->Get('Ticket::Frontend::MoveType') =~ /^form$/i) {
-        $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
-            Name => 'DestQueueID',
-            Data => \%MoveQueues,
-            SelectedID => $Article{QueueID},
-        );
-    }
     # get acl actions
     $Self->{TicketObject}->TicketAcl(
         Data => '-',
@@ -497,7 +460,9 @@ sub ShowTicket {
         }
     }
     # create output
-    if ($Self->{ConfigObject}->Get('Ticket::AgentCanBeCustomer') && $Article{CustomerUserID} && $Article{CustomerUserID} =~ /^$Self->{UserLogin}$/i) {
+    if ($Self->{ConfigObject}->Get('Ticket::AgentCanBeCustomer') &&
+        $Article{CustomerUserID} &&
+        $Article{CustomerUserID} =~ /^$Self->{UserLogin}$/i) {
         $Self->{LayoutObject}->Block(
             Name => 'AgentIsCustomer',
             Data => {%Param, %Article, %AclAction},
@@ -508,9 +473,24 @@ sub ShowTicket {
             Name => 'AgentAnswer',
             Data => {%Param, %Article, %AclAction},
         );
+        if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketCompose} &&
+            (!defined($AclAction{AgentTicketCompose}) || $AclAction{AgentTicketCompose})) {
+            $Self->{LayoutObject}->Block(
+                Name => 'AgentAnswerCompose',
+                Data => {%Param, %Article, %AclAction},
+            );
+        }
+        if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketPhoneOutbound} &&
+            (!defined($AclAction{AgentTicketPhoneOutbound}) || $AclAction{AgentTicketPhoneOutbound})) {
+            $Self->{LayoutObject}->Block(
+                Name => 'AgentAnswerPhoneOutbound',
+                Data => {%Param, %Article, %AclAction},
+            );
+        }
     }
     # ticket bulk block
-    if ($Self->{ConfigObject}->Get('Ticket::Frontend::BulkFeature')) {
+    if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketBulk} &&
+        ($Self->{ConfigObject}->Get('Ticket::Frontend::BulkFeature'))) {
         $Self->{LayoutObject}->Block(
             Name => "Bulk",
             Data => { %Param, %Article },
@@ -523,6 +503,116 @@ sub ShowTicket {
             Data => { %Param, %Article },
         );
     }
+    # ticket type
+    if ($Self->{ConfigObject}->Get('Ticket::Type')) {
+        $Self->{LayoutObject}->Block(
+            Name => 'Type',
+            Data => { %Param, %Article },
+        );
+    }
+    # ticket service
+    if ($Self->{ConfigObject}->Get('Ticket::Service') && $Article{Service}) {
+        $Self->{LayoutObject}->Block(
+            Name => 'Service',
+            Data => { %Param, %Article },
+        );
+        if ($Article{SLA}) {
+            $Self->{LayoutObject}->Block(
+                Name => 'SLA',
+                Data => { %Param, %Article },
+            );
+        }
+    }
+    # show first response time if needed
+    if (defined($Article{FirstResponseTime})) {
+        $Article{FirstResponseTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'FirstResponseTime'},
+            Space => ' ',
+        );
+        $Article{FirstResponseTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'FirstResponseTimeWorkingTime'},
+            Space => ' ',
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'FirstResponseTime',
+            Data => { %Param, %Article },
+        );
+        if (60*60*1 > $Article{FirstResponseTime}) {
+            $Self->{LayoutObject}->Block(
+                Name => 'FirstResponseTimeFontStart',
+                Data => { %Param, %Article },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'FirstResponseTimeFontStop',
+                Data => { %Param, %Article },
+            );
+        }
+    }
+    # show update time if needed
+    if (defined($Article{UpdateTime})) {
+        $Article{UpdateTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'UpdateTime'},
+            Space => ' ',
+        );
+        $Article{UpdateTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'UpdateTimeWorkingTime'},
+            Space => ' ',
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'UpdateTime',
+            Data => { %Param, %Article },
+        );
+        if (60*60*1 > $Article{UpdateTime}) {
+            $Self->{LayoutObject}->Block(
+                Name => 'UpdateTimeFontStart',
+                Data => { %Param, %Article },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'UpdateTimeFontStop',
+                Data => { %Param, %Article },
+            );
+        }
+    }
+    # show solution time if needed
+    if (defined($Article{SolutionTime})) {
+        $Article{SolutionTimeHuman} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'SolutionTime'},
+            Space => ' ',
+        );
+        $Article{SolutionTimeWorkingTime} = $Self->{LayoutObject}->CustomerAgeInHours(
+            Age => $Article{'SolutionTimeWorkingTime'},
+            Space => ' ',
+        );
+        $Self->{LayoutObject}->Block(
+            Name => 'SolutionTime',
+            Data => { %Param, %Article },
+        );
+        if (60*60*1 > $Article{SolutionTime}) {
+            $Self->{LayoutObject}->Block(
+                Name => 'SolutionTimeFontStart',
+                Data => { %Param, %Article },
+            );
+            $Self->{LayoutObject}->Block(
+                Name => 'SolutionTimeFontStop',
+                Data => { %Param, %Article },
+            );
+        }
+    }
+    # get MoveQueuesStrg
+    if ($Self->{ConfigObject}->Get('Ticket::Frontend::MoveType') =~ /^form$/i) {
+        $Param{MoveQueuesStrg} = $Self->{LayoutObject}->AgentQueueListOption(
+            Name => 'DestQueueID',
+            Data => \%MoveQueues,
+            SelectedID => $Article{QueueID},
+        );
+    }
+    if ($Self->{ConfigObject}->Get('Frontend::Module')->{AgentTicketMove} &&
+        (!defined($AclAction{AgentTicketMove}) || $AclAction{AgentTicketMove})) {
+        $Self->{LayoutObject}->Block(
+            Name => 'Move',
+            Data => {%Param, %AclAction},
+        );
+    }
     # create & return output
     my $TicketView = $Self->{UserQueueView} || $Self->{ConfigObject}->Get('PreferencesGroups')->{QueueView}->{DataSelected};
     if ($TicketView ne 'AgentTicketQueueTicketViewLite') {
@@ -562,9 +652,9 @@ sub BuildQueueView {
     # check start option, if higher then tickets available, set
     # it to the last ticket page (Thanks to Stefan Schmidt!)
     if ($Self->{Start} > $Data{TicketsAvailAll}) {
-           my $PageShown = $Self->{ViewableTickets};
-           my $Pages = int(($Data{TicketsAvailAll} / $PageShown) + 0.99999);
-           $Self->{Start} = (($Pages - 1) * $PageShown) + 1;
+        my $PageShown = $Self->{ViewableTickets};
+        my $Pages = int(($Data{TicketsAvailAll} / $PageShown) + 0.99999);
+        $Self->{Start} = (($Pages - 1) * $PageShown) + 1;
     }
     # build output ...
     my %AllQueues = $Self->{QueueObject}->GetAllQueues();
@@ -598,21 +688,18 @@ sub _MaskQueueView {
     $Param{SelectedQueue} = $AllQueues{$QueueID} || $CustomQueue;
     my @MetaQueue = split(/::/, $Param{SelectedQueue});
     $Level = $#MetaQueue+2;
-    # --
+
     # prepare shown queues (short names)
     # - get queue total count -
-    # --
     foreach my $QueueRef (@QueuesNew) {
         push (@ListedQueues, $QueueRef);
         my %Queue = %$QueueRef;
         my @Queue = split(/::/, $Queue{Queue});
-        # --
+
         # remember counted/used queues
-        # --
         $UsedQueue{$Queue{Queue}} = 1;
-        # --
+
         # move to short queue names
-        # --
         my $QueueName = '';
         foreach (0..$#Queue) {
             if (!$QueueName) {
@@ -654,29 +741,27 @@ sub _MaskQueueView {
         $Queue{MaxAge} = $Queue{MaxAge} / 60;
         $Queue{QueueID} = 0 if (!$Queue{QueueID});
         # should i highlight this queue
-        if ($Param{SelectedQueue} =~ /^$QueueName[0]/ && $Level-1 >= $#QueueName) {
-            if ($#QueueName == 0 && $#MetaQueue >= 0 && $Queue{Queue} =~ /^$MetaQueue[0]$/) {
+        if ($Param{SelectedQueue} =~ /^\Q$QueueName[0]\E/ && $Level-1 >= $#QueueName) {
+            if ($#QueueName == 0 && $#MetaQueue >= 0 && $Queue{Queue} =~ /^\Q$MetaQueue[0]\E$/) {
                 $QueueStrg .= '<b>';
             }
-            if ($#QueueName == 1 && $#MetaQueue >= 1 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]$/) {
-               $QueueStrg .= '<b>';
+            if ($#QueueName == 1 && $#MetaQueue >= 1 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]\E$/) {
+                $QueueStrg .= '<b>';
             }
-            if ($#QueueName == 2 && $#MetaQueue >= 2 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]$/) {
-               $QueueStrg .= '<b>';
+            if ($#QueueName == 2 && $#MetaQueue >= 2 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]\E$/) {
+                $QueueStrg .= '<b>';
             }
-            if ($#QueueName == 3 && $#MetaQueue >= 3 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::$MetaQueue[3]$/) {
-               $QueueStrg .= '<b>';
+            if ($#QueueName == 3 && $#MetaQueue >= 3 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::$MetaQueue[3]\E$/) {
+                $QueueStrg .= '<b>';
             }
         }
-        # --
+
         # remember to selected queue info
-        # --
         if ($QueueID eq $Queue{QueueID}) {
             $Param{SelectedQueue} = $Queue{Queue};
             $Param{AllSubTickets} = $Counter{$Queue{Queue}};
-            # --
+
             # build Page Navigator for AgentTicketQueue
-            # --
             $Param{PageShown} = $Param{'ViewableTickets'};
             if ($Param{TicketsAvailAll} == 1 || $Param{TicketsAvailAll} == 0) {
                 $Param{Result} = $Param{TicketsAvailAll};
@@ -721,23 +806,22 @@ sub _MaskQueueView {
             $QueueStrg .= "</blink>";
         }
         # should i highlight this queue
-        if ($Queue{MaxAge} >= $Self->{HighlightAge1}
-              || $Queue{MaxAge} >= $Self->{HighlightAge2}) {
+        if ($Queue{MaxAge} >= $Self->{HighlightAge1} || $Queue{MaxAge} >= $Self->{HighlightAge2}) {
             $QueueStrg .= "</font>";
         }
         $QueueStrg .= "</a>";
         # should i highlight this queue
-        if ($Param{SelectedQueue} =~ /^$QueueName[0]/ && $Level >= $#QueueName) {
-            if ($#QueueName == 0 && $#MetaQueue >= 0 && $Queue{Queue} =~ /^$MetaQueue[0]$/) {
+        if ($Param{SelectedQueue} =~ /^\Q$QueueName[0]\E/ && $Level >= $#QueueName) {
+            if ($#QueueName == 0 && $#MetaQueue >= 0 && $Queue{Queue} =~ /^\Q$MetaQueue[0]\E$/) {
                 $QueueStrg .= '</b>';
             }
-            if ($#QueueName == 1 && $#MetaQueue >= 1 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]$/) {
+            if ($#QueueName == 1 && $#MetaQueue >= 1 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]\E$/) {
                 $QueueStrg .= '</b>';
             }
-            if ($#QueueName == 2 && $#MetaQueue >= 2 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]$/) {
+            if ($#QueueName == 2 && $#MetaQueue >= 2 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]\E$/) {
                 $QueueStrg .= '</b>';
             }
-            if ($#QueueName == 3 && $#MetaQueue >= 3 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::$MetaQueue[3]$/) {
+            if ($#QueueName == 3 && $#MetaQueue >= 3 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::$MetaQueue[3]\E$/) {
                 $QueueStrg .= '</b>';
             }
         }
@@ -748,24 +832,30 @@ sub _MaskQueueView {
             }
             $Param{QueueStrg} .= $QueueStrg;
         }
-        elsif ($#QueueName == 1 && $Level >= 2 && $Queue{Queue} =~ /^$MetaQueue[0]::/) {
+        elsif ($#QueueName == 1 && $Level >= 2 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::\E/) {
             if ($Param{QueueStrg1}) {
                 $QueueStrg = ' - '.$QueueStrg;
             }
             $Param{QueueStrg1} .= $QueueStrg;
         }
-        elsif ($#QueueName == 2 && $Level >= 3 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::/) {
+        elsif ($#QueueName == 2 && $Level >= 3 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::\E/) {
             if ($Param{QueueStrg2}) {
                 $QueueStrg = ' - '.$QueueStrg;
             }
             $Param{QueueStrg2} .= $QueueStrg;
         }
-        elsif ($#QueueName == 3 && $Level >= 4 && $Queue{Queue} =~ /^$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::/) {
+        elsif ($#QueueName == 3 && $Level >= 4 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::\E/) {
             if ($Param{QueueStrg3}) {
                 $QueueStrg = ' - '.$QueueStrg;
             }
             $Param{QueueStrg3} .= $QueueStrg;
         }
+        elsif ($#QueueName == 4 && $Level >= 5 && $Queue{Queue} =~ /^\Q$MetaQueue[0]::$MetaQueue[1]::$MetaQueue[2]::$MetaQueue[3]::\E/) {
+            if ($Param{QueueStrg4}) {
+                $QueueStrg = ' - '.$QueueStrg;
+            }
+            $Param{QueueStrg4} .= $QueueStrg;
+        }
     }
     foreach (1..5) {
         if ($Param{'QueueStrg'.$_}) {
