@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/AgentZoom.pm - to get a closer view
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AgentZoom.pm,v 1.86 2006/11/02 12:20:52 tr Exp $
+# $Id: AgentZoom.pm,v 1.87 2007/01/20 18:04:49 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -16,7 +16,7 @@ use Kernel::System::CustomerUser;
 use Kernel::System::LinkObject;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.86 $';
+$VERSION = '$Revision: 1.87 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -32,7 +32,9 @@ sub new {
     }
     # check needed Opjects
     foreach (qw(ParamObject DBObject LayoutObject LogObject ConfigObject )) {
-        die "Got no $_!" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
 
     return $Self;
@@ -47,4 +49,4 @@ sub Run {
     return $Self->{LayoutObject}->Redirect(OP => $Redirect);
 }
 
-1;
+1;
\ No newline at end of file
