@@ -1,8 +1,8 @@
 # --
 # Kernel/Modules/Installer.pm - provides the DB installer
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Installer.pm,v 1.40 2006/10/09 17:38:03 mh Exp $
+# $Id: Installer.pm,v 1.48 2007/07/13 10:27:54 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -18,7 +18,7 @@ use strict;
 use DBI;
 
 use vars qw($VERSION %INC);
-$VERSION = '$Revision: 1.40 $';
+$VERSION = '$Revision: 1.48 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -35,7 +35,9 @@ sub new {
 
     # check needed Opjects
     foreach (qw(ParamObject LayoutObject LogObject ConfigObject)) {
-        die "Got no $_!" if (!$Self->{$_});
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Got no $_!");
+        }
     }
 
     return $Self;
@@ -120,10 +122,23 @@ sub Run {
             $Dist{Webserver} = '';
         }
     }
-    # --
-    # print form
-    # --
+
+    # print intro form
     if (!$Self->{Subaction}) {
+        $Output .= $Self->{LayoutObject}->Header(Title => 'Intro');
+        $Self->{LayoutObject}->Block(
+            Name => 'Intro',
+            Data => { }
+        );
+        $Output .= $Self->{LayoutObject}->Output(
+            TemplateFile => 'Installer',
+            Data => { },
+        );
+        $Output .= $Self->{LayoutObject}->Footer();
+        return $Output;
+    }
+    # print license from
+    elsif ($Self->{Subaction} eq 'License') {
         $Output .= $Self->{LayoutObject}->Header(Title => 'License');
         $Self->{LayoutObject}->Block(
             Name => 'License',
@@ -139,9 +154,7 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
-    # --
     # do database settings
-    # --
     elsif ($Self->{Subaction} eq 'Start') {
         if ($Self->ReConfigure()) {
             $Output .= $Self->{LayoutObject}->Header(Title => 'Error');
@@ -171,9 +184,8 @@ sub Run {
             return $Output;
         }
     }
-    # --
+
     # do database settings
-    # --
     elsif ($Self->{Subaction} eq 'DB') {
         $Output .= $Self->{LayoutObject}->Header(Title => 'Installer');
         # get params
@@ -184,12 +196,13 @@ sub Run {
         $DB{Type} = $Self->{ParamObject}->GetParam(Param => 'DBType') || '';
         $DB{Database} = $Self->{ParamObject}->GetParam(Param => 'DBName') || '';
         $DB{DBAction} = $Self->{ParamObject}->GetParam(Param => 'DBAction') || '';
+        $DB{DBDefaultCharset} = $Self->{ParamObject}->GetParam(Param => 'DBDefaultCharset') || '';
         $DB{DatabaseUser} = $Self->{ParamObject}->GetParam(Param => 'OTRSDBUser') || '';
         $DB{DatabasePw} = $Self->{ParamObject}->GetParam(Param => 'OTRSDBPassword') || '';
         $DB{NewHost} = $Self->{ParamObject}->GetParam(Param => 'OTRSDBConnectHost') || '';
         # check params
         foreach (keys %DB) {
-            if (!$DB{$_} && $_ ne 'Password') {
+            if (!$DB{$_} && $_ !~ /^(Password|DBDefaultCharset)$/) {
                 return $Self->{LayoutObject}->ErrorScreen(
                     Message => "You need '$_'!!",
                     Comment => 'Please go back',
@@ -209,9 +222,8 @@ sub Run {
             );
         }
 
-
         if ($DB{DBAction} eq 'Create') {
-          # FIXME !!! use $DB{Type}!!!
+            # FIXME !!! use $DB{Type}!!!
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResult',
                 Data => {
@@ -219,16 +231,22 @@ sub Run {
                     Step => '2/4',
                 },
             );
-            # --
+
             # create db
-            # --
+            my $DBCreate = '';
+            if ($DB{DBDefaultCharset} eq 'utf8') {
+                $DBCreate =" CREATE DATABASE $DB{Database} charset utf8";
+            }
+            else {
+                $DBCreate =" CREATE DATABASE $DB{Database}";
+            }
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResultItem',
                 Data => {
-                    Item => "Creating database '$DB{Database}'",
+                    Item => "Creating database '$DB{Database}' $DB{DBDefaultCharset}",
                 },
             );
-            if (!$DBH->do("CREATE DATABASE $DB{Database}")) {
+            if (!$DBH->do($DBCreate)) {
                 $Self->{LayoutObject}->Block(
                     Name => 'DatabaseResultItemFalse',
                     Data => { },
@@ -256,9 +274,8 @@ sub Run {
                     Data => { },
                 );
             }
-            # --
+
             # create db tables
-            # --
             # read otrs-schema.mysql.sql and process stuff
             my @SQL = $Self->ParseSQLFile("$DirOfSQLFiles/otrs-schema.mysql.sql");
             $DBH->do("use $DB{Database}");
@@ -297,15 +314,14 @@ sub Run {
                 Name => 'DatabaseResultItemDone',
                 Data => { },
             );
-            # --
-            # inital insert
-            # - read initial_insert.sql and process stuff -
-            # --
-            @SQL = $Self->ParseSQLFile("$DirOfSQLFiles/initial_insert.sql");
+
+            # initial insert
+            # - read otrs-initial_insert.mysql.sql and process stuff -
+            @SQL = $Self->ParseSQLFile("$DirOfSQLFiles/otrs-initial_insert.mysql.sql");
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResultItem',
                 Data => {
-                    Item => "Inserting Inital inserts 'initial_insert.sql'",
+                    Item => "Inserting initial inserts 'otrs-initial_insert.mysql.sql'",
                 },
             );
             foreach (@SQL) {
@@ -337,10 +353,9 @@ sub Run {
                 Name => 'DatabaseResultItemDone',
                 Data => { },
             );
-            # --
+
             # foreign key
             # - read otrs-schema-post.mysql.sql and process stuff -
-            # --
             @SQL = $Self->ParseSQLFile("$DirOfSQLFiles/otrs-schema-post.mysql.sql");
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResultItem',
@@ -377,9 +392,8 @@ sub Run {
                 Name => 'DatabaseResultItemDone',
                 Data => { },
             );
-            # --
+
             # user add
-            # --
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResultItem',
                 Data => {
@@ -414,9 +428,8 @@ sub Run {
                     Data => { },
                 );
             }
-            # --
+
             # Reload the grant tables of your mysql-daemon
-            # --
             $Self->{LayoutObject}->Block(
                 Name => 'DatabaseResultItem',
                 Data => {
@@ -451,9 +464,8 @@ sub Run {
                     Data => { },
                 );
             }
-            # --
+
             # ReConfigure Config.pm
-            # --
             if ($Self->ReConfigure(
                 DatabaseHost => $DB{DatabaseHost},
                 Database => $DB{Database},
@@ -470,6 +482,12 @@ sub Run {
                 return $Output;
             }
             else {
+                # set default charset to utf8 it configured
+                if ($DB{DBDefaultCharset} eq 'utf8') {
+                    $Self->ReConfigure(
+                        DefaultCharset => 'utf-8',
+                    );
+                }
                 $Self->{LayoutObject}->Block(
                     Name => 'DatabaseResultItemMessage',
                     Data => {
@@ -556,9 +574,8 @@ sub Run {
         $Output .= $Self->{LayoutObject}->Footer();
         return $Output;
     }
-    # --
+
     # do system settings
-    # --
     elsif ($Self->{Subaction} eq 'System') {
         my %SystemIDs = ();
         foreach (1..99) {
@@ -585,13 +602,6 @@ sub Run {
             HTMLQuote => 0,
             SelectedID => $Self->{ConfigObject}->Get('LogModule'),
         );
-# it mysql 4.1 is stable, we use this:
-#        if ($Self->{LayoutObject}->{LanguageObject}->GetRecommendedCharset() eq 'utf-8') {
-#            $Param{DefaultCharset} = 'utf-8';
-#        }
-#        else {
-#            $Param{DefaultCharset} = 'iso-8859-1';
-#        }
         $Param{DefaultCharset} = $Self->{ConfigObject}->Get('DefaultCharset') || 'iso-8859-1';
         $Output .= $Self->{LayoutObject}->Header(Title => 'System Settings');
         $Self->{LayoutObject}->Block(
@@ -608,13 +618,11 @@ sub Run {
         );
         $Output .= $Self->{LayoutObject}->Footer();
     }
-    # --
+
     # do system settings action
-    # --
     elsif ($Self->{Subaction} eq 'Finish') {
-        # --
+
         # ReConfigure Config.pm
-        # --
         my %Config = ();
         foreach (qw(SystemID FQDN AdminEmail Organization LogModule LogModule::LogFile
             DefaultCharset DefaultLanguage CheckMXRecord)
@@ -662,9 +670,8 @@ sub Run {
         }
         $Output .= $Self->{LayoutObject}->Footer();
     }
-    # --
+
     # else! error!
-    # --
     else {
         return $Self->{LayoutObject}->ErrorScreen(
             Message => "Unknown Subaction $Self->{Subaction}!",
@@ -679,17 +686,15 @@ sub ReConfigure {
     my $Self = shift;
     my %Param = @_;
     my $Config = '';
-    # --
+
     # perl quote
-    # --
     foreach (keys %Param) {
         if ($Param{$_}) {
             $Param{$_} =~ s/'/\\'/g;
         }
     }
-    # --
+
     # read config file
-    # --
     open (IN, "< $Self->{Path}/Kernel/Config.pm") ||
         return "Can't open $Self->{Path}/Kernel/Config.pm: $!";
     while (<IN>) {
@@ -698,9 +703,7 @@ sub ReConfigure {
         }
         else {
             my $NewConfig = $_;
-            # --
             # replace config with %Param
-            # --
             foreach (keys %Param) {
                 if ($Param{$_} =~ /^[0-9]+$/ && $Param{$_} !~ /^0/) {
                     $NewConfig =~ s/(\$Self->{$_} =.+?);/\$Self->{'$_'} = $Param{$_};/g;
@@ -724,9 +727,7 @@ sub ReConfigure {
             }
         }
     }
-    # --
     # write new config file
-    # --
     open (OUT, "> $Self->{Path}/Kernel/Config.pm") ||
         return "Can't open $Self->{Path}/Kernel/Config.pm: $!";
     print OUT $Config;
@@ -761,7 +762,9 @@ sub ParseSQLFile {
         close (IN);
     }
     else {
-        die "Can't open $File: $!\n";
+        if (!$Self->{$_}) {
+            $Self->{LayoutObject}->FatalError(Message => "Can't open $File: $!");
+        }
     }
     return @SQL;
 }
