@@ -2,7 +2,7 @@
 # Kernel/Output/HTML/LayoutTicket.pm - provides generic ticket HTML output
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: LayoutTicket.pm,v 1.5.2.1 2007/03/12 00:22:46 martin Exp $
+# $Id: LayoutTicket.pm,v 1.15 2007/04/03 18:36:31 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::Output::HTML::LayoutTicket;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.5.2.1 $';
+$VERSION = '$Revision: 1.15 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub TicketStdResponseString {
@@ -66,6 +66,7 @@ sub AgentCustomerViewTable {
     my $Self = shift;
     my %Param = @_;
     my $ShownType = 1;
+    my @MapNew = ();
     if (ref($Param{Data}) ne 'HASH') {
         $Self->FatalError(Message => 'Need Hash ref in Data param');
     }
@@ -73,12 +74,22 @@ sub AgentCustomerViewTable {
         return '$Text{"none"}';
     }
     my $Map = $Param{Data}->{Config}->{Map};
+    if ($Map) {
+        @MapNew = (@{$Map});
+    }
+    # check if customer company support is enabled
+    if ($Param{Data}->{Config}->{CustomerCompanySupport}) {
+        my $Map2 = $Param{Data}->{CompanyConfig}->{Map};
+        if ($Map2) {
+            push (@MapNew, @{$Map2});
+        }
+    }
     if ($Param{Type} && $Param{Type} eq 'Lite') {
         $ShownType = 2;
         # check if min one lite view item is configured, if not, use
         # the normal view also
         my $Used = 0;
-        foreach my $Field (@{$Map}) {
+        foreach my $Field (@MapNew) {
             if ($Field->[3] == 2) {
                 $Used = 1;
             }
@@ -88,7 +99,7 @@ sub AgentCustomerViewTable {
         }
     }
     # build html table
-    foreach my $Field (@{$Map}) {
+    foreach my $Field (@MapNew) {
         if ($Field->[3] && $Field->[3] >= $ShownType && $Param{Data}->{$Field->[0]}) {
             my %Record = ();
             if ($Field->[6]) {
@@ -113,6 +124,13 @@ sub AgentCustomerViewTable {
     return $Self->Output(TemplateFile => 'AgentCustomerTableView', Data => \%Param);
 }
 
+# AgentQueueListOption()
+#
+# !! DONT USE THIS FUNCTION !! Use BuildSelection() instead.
+#
+# Due to compatibility reason this function is still in use and will be removed
+# in a further release.
+
 sub AgentQueueListOption {
     my $Self = shift;
     my %Param = @_;
@@ -134,11 +152,10 @@ sub AgentQueueListOption {
     }
 
     # just show a simple list
-    if ($Self->{ConfigObject}->Get('Ticket::Frontend::QueueListType') eq 'list') {
+    if ($Self->{ConfigObject}->Get('Ticket::Frontend::ListType') eq 'list') {
         $Param{'MoveQueuesStrg'} = $Self->OptionStrgHashRef(
             %Param,
             HTMLQuote => 0,
-#            OnChangeSubmit => 1,
         );
         return $Param{MoveQueuesStrg};
     }
@@ -255,13 +272,15 @@ sub AgentFreeText {
                         $Ticket{"TicketFreeKey$_"} = $Ticket{"TicketFreeKey$_"}->[0];
                     }
                     else {
-                       $Ticket{"TicketFreeKey$_"} = '';
+                        $Ticket{"TicketFreeKey$_"} = '';
                     }
                 }
-                $Data{"TicketFreeKeyField$_"} = '<input type="text" name="TicketFreeKey'.$_.'" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Ticket{"TicketFreeKey$_"}).'" size="20">';
+                $Data{"TicketFreeKeyField$_"} =
+                    '<input type="text" name="TicketFreeKey'.$_.
+                    '" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Ticket{"TicketFreeKey$_"}).'" size="18">';
             }
             else {
-                $Data{"TicketFreeKeyField$_"} = '<input type="text" name="TicketFreeKey'.$_.'" value="" size="20">';
+                $Data{"TicketFreeKeyField$_"} = '<input type="text" name="TicketFreeKey'.$_.'" value="" size="18">';
             }
         }
         # value
@@ -289,12 +308,15 @@ sub AgentFreeText {
                         $Ticket{"TicketFreeText$_"} = '';
                     }
                 }
-                $Data{"TicketFreeTextField$_"} = '<input type="text" name="TicketFreeText'.$_.'" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Ticket{"TicketFreeText$_"}).'" size="30">';
+                $Data{"TicketFreeTextField$_"} =
+                    '<input type="text" name="TicketFreeText'.$_.'" value="'.
+                    $Self->{LayoutObject}->Ascii2Html(Text => $Ticket{"TicketFreeText$_"}).'" size="30">';
             }
             else {
                 $Data{"TicketFreeTextField$_"} = '<input type="text" name="TicketFreeText'.$_.'" value="" size="30">';
             }
         }
+        $Data{"TicketFreeTextField$_"} .= '<font color="red" size="-2">$Text{"$Data{"TicketFreeTextField'.$_.' invalid"}"}</font>';
     }
     return %Data;
 }
@@ -306,8 +328,8 @@ sub AgentFreeDate {
     my %SelectData = ();
     my %Ticket = ();
     my %Config = ();
+
     if ($Param{NullOption}) {
-#        $NullOption{''} = '-';
         $SelectData{Size} = 3;
         $SelectData{Multiple} = 1;
     }
@@ -318,13 +340,18 @@ sub AgentFreeDate {
         %Config = %{$Param{Config}};
     }
     my %Data = ();
-    foreach my $Count (1..2) {
+    foreach my $Count (1..6) {
+        my %TimePeriod = ();
+        if ($Self->{ConfigObject}->Get('TicketFreeTimePeriod'.$Count)) {
+            %TimePeriod = %{$Self->{ConfigObject}->Get('TicketFreeTimePeriod'.$Count)};
+        }
         $Data{'TicketFreeTime'.$Count} = $Self->BuildDateSelection(
             %Param,
             %Ticket,
             Prefix => 'TicketFreeTime'.$Count,
             Format => 'DateInputFormatLong',
             DiffTime => $Self->{ConfigObject}->Get('TicketFreeTimeDiff'.$Count) || 0,
+            %TimePeriod,
         );
     }
     return %Data;
@@ -338,7 +365,6 @@ sub TicketArticleFreeText {
     my %Article = ();
     my %Config = ();
     if ($Param{NullOption}) {
-#        $NullOption{''} = '-';
         $SelectData{Size} = 3;
         $SelectData{Multiple} = 1;
     }
@@ -394,10 +420,12 @@ sub TicketArticleFreeText {
                         $Article{"ArticleFreeKey$_"} = '';
                     }
                 }
-                $Data{"ArticleFreeKeyField$_"} = '<input type="text" name="ArticleFreeKey'.$_.'" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{"ArticleFreeKey$_"}).'" size="20">';
+                $Data{"ArticleFreeKeyField$_"} =
+                    '<input type="text" name="ArticleFreeKey'.$_.
+                    '" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{"ArticleFreeKey$_"}).'" size="18">';
             }
             else {
-                $Data{"ArticleFreeKeyField$_"} = '<input type="text" name="ArticleFreeKey'.$_.'" value="" size="20">';
+                $Data{"ArticleFreeKeyField$_"} = '<input type="text" name="ArticleFreeKey'.$_.'" value="" size="18">';
             }
         }
         # value
@@ -425,7 +453,9 @@ sub TicketArticleFreeText {
                         $Article{"ArticleFreeText$_"} = '';
                     }
                 }
-                $Data{"ArticleFreeTextField$_"} = '<input type="text" name="ArticleFreeText'.$_.'" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{"ArticleFreeText$_"}).'" size="30">';
+                $Data{"ArticleFreeTextField$_"} =
+                    '<input type="text" name="ArticleFreeText'.$_.
+                    '" value="'.$Self->{LayoutObject}->Ascii2Html(Text => $Article{"ArticleFreeText$_"}).'" size="30">';
             }
             else {
                 $Data{"ArticleFreeTextField$_"} = '<input type="text" name="ArticleFreeText'.$_.'" value="" size="30">';
@@ -443,7 +473,6 @@ sub CustomerFreeDate {
     my %Ticket = ();
     my %Config = ();
     if ($Param{NullOption}) {
-#        $NullOption{''} = '-';
         $SelectData{Size} = 3;
         $SelectData{Multiple} = 1;
     }
@@ -454,7 +483,11 @@ sub CustomerFreeDate {
         %Config = %{$Param{Config}};
     }
     my %Data = ();
-    foreach my $Count (1..2) {
+    foreach my $Count (1..6) {
+        my %TimePeriod = ();
+        if ($Self->{ConfigObject}->Get('TicketFreeTimePeriod'.$Count)) {
+            %TimePeriod = %{$Self->{ConfigObject}->Get('TicketFreeTimePeriod'.$Count)};
+        }
         $Data{'TicketFreeTime'.$Count} = $Self->BuildDateSelection(
             Area => 'Customer',
             %Param,
@@ -462,6 +495,7 @@ sub CustomerFreeDate {
             Prefix => 'TicketFreeTime'.$Count,
             Format => 'DateInputFormatLong',
             DiffTime => $Self->{ConfigObject}->Get('TicketFreeTimeDiff'.$Count) || 0,
+            %TimePeriod,
         );
     }
     return %Data;
