@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Auth.pm - provides the authentification
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Auth.pm,v 1.20 2006/08/29 17:30:35 martin Exp $
+# $Id: Auth.pm,v 1.23 2007/01/20 23:11:33 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::Auth;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.20 $';
+$VERSION = '$Revision: 1.23 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -35,24 +35,24 @@ The autentification module for the agent interface.
 
 create a object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
-  use Kernel::System::DB;
-  use Kernel::System::Auth;
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::DB;
+    use Kernel::System::Auth;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $DBObject = Kernel::System::DB->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-  );
-  my $AuthObject = Kernel::System::Auth->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-      DBObject => $DBObject,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $AuthObject = Kernel::System::Auth->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+        DBObject => $DBObject,
+    );
 
 =cut
 
@@ -70,14 +70,16 @@ sub new {
     }
 
     # load generator auth module
-    $Self->{GenericModule} = $Self->{ConfigObject}->Get('AuthModule')
-      || 'Kernel::System::Auth::DB';
-    if (!eval "require $Self->{GenericModule}") {
-        die "Can't load auth backend module $Self->{GenericModule}! $@";
+    foreach my $Count ('', 1..10) {
+        my $GenericModule = $Self->{ConfigObject}->Get("AuthModule$Count");
+        if ($GenericModule) {
+            if (!eval "require $GenericModule") {
+                die "Can't load auth backend module $GenericModule! $@";
+            }
+            $Self->{"Backend$Count"} = $GenericModule->new(%Param, Count => $Count);
+        }
     }
 
-    $Self->{Backend} = $Self->{GenericModule}->new(%Param);
-
     return $Self;
 }
 
@@ -113,10 +115,21 @@ The autentificaion function.
 sub Auth {
     my $Self = shift;
     my %Param = @_;
-    return $Self->{Backend}->Auth(%Param);
+    foreach ('', 1..10) {
+        if ($Self->{"Backend$_"}) {
+            my $Return = $Self->{"Backend$_"}->Auth(%Param);
+            if ($Return) {
+                return $Return;
+            }
+        }
+    }
+    return;
 }
+
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -129,6 +142,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.20 $ $Date: 2006/08/29 17:30:35 $
+$Revision: 1.23 $ $Date: 2007/01/20 23:11:33 $
 
-=cut
+=cut
\ No newline at end of file
