@@ -1,12 +1,12 @@
 # --
 # Kernel/System/Auth/DB.pm - provides the db authentification
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.18 2007/01/30 14:08:06 mh Exp $
+# $Id: DB.pm,v 1.18.2.1 2008/02/18 16:49:29 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Auth::DB;
@@ -16,7 +16,7 @@ use Kernel::System::Valid;
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.18 $';
+$VERSION = '$Revision: 1.18.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -38,7 +38,7 @@ sub new {
 
     # get user table
     $Self->{UserTable} = $Self->{ConfigObject}->Get('DatabaseUserTable'.$Param{Count})
-        || 'user';
+        || 'system_user';
     $Self->{UserTableUserID} = $Self->{ConfigObject}->Get('DatabaseUserTableUserID'.$Param{Count})
         || 'id';
     $Self->{UserTableUserPW} = $Self->{ConfigObject}->Get('DatabaseUserTableUserPW'.$Param{Count})
