@@ -2,7 +2,7 @@
 # Kernel/System/Auth/LDAP.pm - provides the ldap authentification
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: LDAP.pm,v 1.29.2.1 2007/02/02 15:15:23 martin Exp $
+# $Id: LDAP.pm,v 1.39.2.1 2007/11/06 06:53:29 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,11 +12,12 @@
 package Kernel::System::Auth::LDAP;
 
 use strict;
+use warnings;
 use Net::LDAP;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.29.2.1 $';
+$VERSION = '$Revision: 1.39.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -39,26 +40,52 @@ sub new {
     $Self->{Debug} = 0;
 
     # get ldap preferences
-    $Self->{Host} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Host')
-     || die "Need AuthModule::LDAP::Host in Kernel/Config.pm";
-    $Self->{BaseDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::BaseDN')
-     || die "Need AuthModule::LDAP::BaseDN in Kernel/Config.pm";
-    $Self->{UID} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UID')
-     || die "Need AuthModule::LDAP::UID in Kernel/Config.pm";
-    $Self->{SearchUserDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserDN') || '';
-    $Self->{SearchUserPw} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserPw') || '';
-    $Self->{GroupDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::GroupDN') || '';
-    $Self->{AccessAttr} = $Self->{ConfigObject}->Get('AuthModule::LDAP::AccessAttr') || 'memberUid';
-    $Self->{UserAttr} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserAttr') || 'DN';
-    $Self->{UserSuffix} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserSuffix') || '';
-    $Self->{UserLowerCase} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserLowerCase') || 0;
-    $Self->{DestCharset} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Charset') || 'utf-8';
+    $Self->{Count} = $Param{Count} || '';
+    $Self->{Die} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Die'.$Param{Count});
+    if ($Self->{ConfigObject}->Get('AuthModule::LDAP::Host'.$Param{Count})) {
+        $Self->{Host} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Host'.$Param{Count});
+    }
+    else {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Need AuthModule::LDAP::Host$Param{Count} in Kernel/Config.pm",
+        );
+        return;
+    }
+    if (defined($Self->{ConfigObject}->Get('AuthModule::LDAP::BaseDN'.$Param{Count}))) {
+        $Self->{BaseDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::BaseDN'.$Param{Count});
+    }
+    else {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Need AuthModule::LDAP::BaseDN$Param{Count} in Kernel/Config.pm",
+        );
+        return;
+    }
+    if ($Self->{ConfigObject}->Get('AuthModule::LDAP::UID'.$Param{Count})) {
+        $Self->{UID} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UID'.$Param{Count});
+    }
+    else {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Need AuthModule::LDAP::UID$Param{Count} in Kernel/Config.pm",
+        );
+        return;
+    }
+    $Self->{SearchUserDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserDN'.$Param{Count}) || '';
+    $Self->{SearchUserPw} = $Self->{ConfigObject}->Get('AuthModule::LDAP::SearchUserPw'.$Param{Count}) || '';
+    $Self->{GroupDN} = $Self->{ConfigObject}->Get('AuthModule::LDAP::GroupDN'.$Param{Count}) || '';
+    $Self->{AccessAttr} = $Self->{ConfigObject}->Get('AuthModule::LDAP::AccessAttr'.$Param{Count}) || 'memberUid';
+    $Self->{UserAttr} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserAttr'.$Param{Count}) || 'DN';
+    $Self->{UserSuffix} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserSuffix'.$Param{Count}) || '';
+    $Self->{UserLowerCase} = $Self->{ConfigObject}->Get('AuthModule::LDAP::UserLowerCase'.$Param{Count}) || 0;
+    $Self->{DestCharset} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Charset'.$Param{Count}) || 'utf-8';
 
     # ldap filter always used
-    $Self->{AlwaysFilter} = $Self->{ConfigObject}->Get('AuthModule::LDAP::AlwaysFilter') || '';
+    $Self->{AlwaysFilter} = $Self->{ConfigObject}->Get('AuthModule::LDAP::AlwaysFilter'.$Param{Count}) || '';
     # Net::LDAP new params
-    if ($Self->{ConfigObject}->Get('AuthModule::LDAP::Params')) {
-        $Self->{Params} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Params');
+    if ($Self->{ConfigObject}->Get('AuthModule::LDAP::Params'.$Param{Count})) {
+        $Self->{Params} = $Self->{ConfigObject}->Get('AuthModule::LDAP::Params'.$Param{Count});
     }
     else {
         $Self->{Params} = {};
@@ -120,13 +147,26 @@ sub Auth {
     # just in case for debug!
     if ($Self->{Debug} > 0) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: '$Param{User}' tried to authenticate with Pw: '$Param{Pw}' (REMOTE_ADDR: $RemoteAddr)",
+            Priority => 'notice',
+            Message => "User: '$Param{User}' tried to authenticate with Pw: '$Param{Pw}' ".
+                "(REMOTE_ADDR: $RemoteAddr)",
         );
     }
 
     # ldap connect and bind (maybe with SearchUserDN and SearchUserPw)
-    my $LDAP = Net::LDAP->new($Self->{Host}, %{$Self->{Params}}) or die "$@";
+    my $LDAP = Net::LDAP->new($Self->{Host}, %{$Self->{Params}});
+    if (!$LDAP) {
+        if ($Self->{Die}) {
+            die "Can't connect to $Self->{Host}: $@";
+        }
+        else {
+            $Self->{LogObject}->Log(
+                Priority => 'error',
+                Message => "Can't connect to $Self->{Host}: $@",
+            );
+            return;
+        }
+    }
     my $Result = '';
     if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
         $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -141,8 +181,11 @@ sub Auth {
         );
         return;
     }
+    # user quote
+    my $UserQuote = $Param{User};
+    $UserQuote =~ s/\\/\\\\/g;
     # build filter
-    my $Filter = "($Self->{UID}=$Param{User})";
+    my $Filter = "($Self->{UID}=$UserQuote)";
     # prepare filter
     if ($Self->{AlwaysFilter}) {
         $Filter = "(&$Filter$Self->{AlwaysFilter})";
@@ -168,14 +211,17 @@ sub Auth {
     if (!$UserDN) {
         # failed login note
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: $Param{User} authentication failed, no LDAP entry found!".
-            "BaseDN='$Self->{BaseDN}', Filter='$Filter', (REMOTE_ADDR: $RemoteAddr).",
+            Priority => 'notice',
+            Message => "User: $Param{User} authentication failed, no LDAP entry found!".
+                "BaseDN='$Self->{BaseDN}', Filter='$Filter', (REMOTE_ADDR: $RemoteAddr).",
         );
         # take down session
         $LDAP->unbind;
         return;
     }
+    # DN quote
+    my $UserDNQuote = $UserDN;
+    $UserDNQuote =~ s/\\/\\\\/g;
 
     # check if user need to be in a group!
     if ($Self->{AccessAttr} && $Self->{GroupDN}) {
@@ -189,13 +235,13 @@ sub Auth {
         # search if we're allowed to
         my $Filter2 = '';
         if ($Self->{UserAttr} eq 'DN') {
-            $Filter2 = "($Self->{AccessAttr}=$UserDN)";
+            $Filter2 = "($Self->{AccessAttr}=$UserDNQuote)";
         }
         else {
-            $Filter2 = "($Self->{AccessAttr}=$Param{User})";
+            $Filter2 = "($Self->{AccessAttr}=$UserQuote)";
         }
         my $Result2 = $LDAP->search (
-            base   => $Self->{GroupDN},
+            base => $Self->{GroupDN},
             filter => $Filter2,
         );
         if ($Result2->code) {
@@ -214,9 +260,9 @@ sub Auth {
         if (!$GroupDN) {
             # failed login note
             $Self->{LogObject}->Log(
-              Priority => 'notice',
-              Message => "User: $Param{User} authentication failed, no LDAP group entry found".
-                "GroupDN='$Self->{GroupDN}', Filter='$Filter2'! (REMOTE_ADDR: $RemoteAddr).",
+                Priority => 'notice',
+                Message => "User: $Param{User} authentication failed, no LDAP group entry found".
+                    "GroupDN='$Self->{GroupDN}', Filter='$Filter2'! (REMOTE_ADDR: $RemoteAddr).",
             );
             # take down session
             $LDAP->unbind;
@@ -229,8 +275,8 @@ sub Auth {
     if ($Result->code) {
         # failed login note
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "User: $Param{User} ($UserDN) authentication failed: '".$Result->error()."' (REMOTE_ADDR: $RemoteAddr).",
+            Priority => 'notice',
+            Message => "User: $Param{User} ($UserDN) authentication failed: '".$Result->error()."' (REMOTE_ADDR: $RemoteAddr).",
         );
         # take down session
         $LDAP->unbind;
@@ -251,7 +297,7 @@ sub Auth {
             Message => "User: $Param{User} ($UserDN) authentication ok (REMOTE_ADDR: $RemoteAddr).",
         );
         # sync user from ldap
-        if ($Self->{ConfigObject}->Get('UserSyncLDAPMap')) {
+        if ($Self->{ConfigObject}->Get('UserSyncLDAPMap'.$Self->{Count})) {
             my $Result = '';
             if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
                 $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -261,22 +307,22 @@ sub Auth {
             }
             if ($Result->code) {
                 $Self->{LogObject}->Log(
-                  Priority => 'error',
-                  Message => "Sync bind failed! ".$Result->error,
+                    Priority => 'error',
+                    Message => "Sync bind failed! ".$Result->error,
                 );
                 # take down session
                 $LDAP->unbind;
                 return $Param{User};
             }
             # build filter
-            my $Filter = "($Self->{UID}=$Param{User})";
+            my $Filter = "($Self->{UID}=$UserQuote)";
             # prepare filter
             if ($Self->{AlwaysFilter}) {
                 $Filter = "(&$Filter$Self->{AlwaysFilter})";
             }
             # perform user search
             $Result = $LDAP->search (
-                base   => $Self->{BaseDN},
+                base => $Self->{BaseDN},
                 filter => $Filter,
             );
             if ($Result->code) {
@@ -290,10 +336,18 @@ sub Auth {
             my %SyncUser = ();
             foreach my $Entry ($Result->all_entries) {
                 $UserDN = $Entry->dn();
-                foreach (keys %{$Self->{ConfigObject}->Get('UserSyncLDAPMap')}) {
-                    $SyncUser{$_} = $Entry->get_value($Self->{ConfigObject}->Get('UserSyncLDAPMap')->{$_});
+                foreach my $Key (keys %{$Self->{ConfigObject}->Get('UserSyncLDAPMap'.$Self->{Count})}) {
+                    # detect old config setting
+                    if ($Key =~ /^(Firstname|Lastname|Email)/) {
+                        $Key = "User".$Key;
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message => "Old config setting detected, please use the new one from Kernel/Config/Defaults.pm (User* has been added!).",
+                        );
+                    }
+                    $SyncUser{$Key} = $Entry->get_value($Self->{ConfigObject}->Get('UserSyncLDAPMap'.$Self->{Count})->{$Key});
                     # e. g. set utf-8 flag
-                    $SyncUser{$_} = $Self->_ConvertFrom($SyncUser{$_}, $Self->{ConfigObject}->Get('DefaultCharset'));
+                    $SyncUser{$Key} = $Self->_ConvertFrom($SyncUser{$Key}, $Self->{ConfigObject}->Get('DefaultCharset'));
                 }
                 if ($Entry->get_value('userPassword')) {
                     $SyncUser{Pw} = $Entry->get_value('userPassword');
@@ -307,22 +361,22 @@ sub Auth {
                 my %UserData = $Self->{UserObject}->GetUserData(User => $Param{User});
                 if (!%UserData) {
                     my $UserID = $Self->{UserObject}->UserAdd(
-                        Salutation => 'Mr/Mrs',
-                        Login => $Param{User},
+                        UserSalutation => 'Mr/Mrs',
+                        UserLogin => $Param{User},
                         %SyncUser,
                         UserType => 'User',
                         ValidID => 1,
-                        UserID => 1,
+                        ChangeUserID => 1,
                     );
                     if ($UserID) {
                         $Self->{LogObject}->Log(
                             Priority => 'notice',
                             Message => "Initial data for '$Param{User}' ($UserDN) created in RDBMS.",
                         );
-                        # sync inital groups
-                        if ($Self->{ConfigObject}->Get('UserSyncLDAPGroups')) {
+                        # sync initial groups
+                        if ($Self->{ConfigObject}->Get('UserSyncLDAPGroups'.$Self->{Count})) {
                             my %Groups = $Self->{GroupObject}->GroupList();
-                            foreach (@{$Self->{ConfigObject}->Get('UserSyncLDAPGroups')}) {
+                            foreach (@{$Self->{ConfigObject}->Get('UserSyncLDAPGroups'.$Self->{Count})}) {
                                 my $GroupID = '';
                                 foreach my $GID (keys %Groups) {
                                     if ($Groups{$GID} eq $_) {
@@ -343,34 +397,26 @@ sub Auth {
                         }
                     }
                     else {
-                       $Self->{LogObject}->Log(
-                           Priority => 'error',
-                           Message => "Can't create user '$Param{User}' ($UserDN) in RDBMS!",
-                       );
+                        $Self->{LogObject}->Log(
+                            Priority => 'error',
+                            Message => "Can't create user '$Param{User}' ($UserDN) in RDBMS!",
+                        );
                     }
                 }
                 else {
-                    my %CleanUserData = ();
-                    foreach my $Key (keys %UserData) {
-                        if ($Key ne 'UserPw') {
-                            my $CleanKey = $Key;
-                            $CleanKey =~ s/^User(.*)$/$1/;
-                            $CleanUserData{$CleanKey} = $UserData{$Key};
-                        }
-                    }
                     $Self->{UserObject}->UserUpdate(
-                        %CleanUserData,
-                        ID => $UserData{UserID},
-                        Login => $Param{User},
+                        %UserData,
+                        UserID => $UserData{UserID},
+                        UserLogin => $Param{User},
                         %SyncUser,
                         UserType => 'User',
-                        UserID => 1,
+                        ChangeUserID => 1,
                     );
                 }
             }
         }
         # sync ldap group 2 otrs group permissions
-        if ($Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination')) {
+        if ($Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination'.$Self->{Count})) {
             my $Result = '';
             if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
                 $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -380,8 +426,8 @@ sub Auth {
             }
             if ($Result->code) {
                 $Self->{LogObject}->Log(
-                  Priority => 'error',
-                  Message => "Sync bind failed! ".$Result->error,
+                    Priority => 'error',
+                    Message => "Sync bind failed! ".$Result->error,
                 );
                 # take down session
                 $LDAP->unbind;
@@ -391,7 +437,7 @@ sub Auth {
             my %UserData = $Self->{UserObject}->GetUserData(User => $Param{User});
             # system permissions
             my %PermissionsEmpty = ();
-            foreach (@{$Self->{ConfigObject}->Get('System::Permission')}) {
+            foreach (@{$Self->{ConfigObject}->Get('System::Permission'.$Self->{Count})}) {
                 $PermissionsEmpty{$_} = 0;
             }
             # remove all group permissions
@@ -407,7 +453,7 @@ sub Auth {
                 );
             }
             # group config settings
-            foreach my $GroupDN (sort keys %{$Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination')}) {
+            foreach my $GroupDN (sort keys %{$Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination'.$Self->{Count})}) {
                 # just in case for debug
                 $Self->{LogObject}->Log(
                     Priority => 'notice',
@@ -416,13 +462,13 @@ sub Auth {
                 # search if we're allowed to
                 my $Filter = '';
                 if ($Self->{UserAttr} eq 'DN') {
-                    $Filter = "($Self->{AccessAttr}=$UserDN)";
+                    $Filter = "($Self->{AccessAttr}=$UserDNQuote)";
                 }
                 else {
-                    $Filter = "($Self->{AccessAttr}=$Param{User})";
+                    $Filter = "($Self->{AccessAttr}=$UserQuote)";
                 }
                 my $Result = $LDAP->search (
-                    base   => $GroupDN,
+                    base => $GroupDN,
                     filter => $Filter,
                 );
                 if ($Result->code) {
@@ -442,12 +488,12 @@ sub Auth {
                     $Self->{LogObject}->Log(
                         Priority => 'notice',
                         Message => "User: $Param{User} not in ".
-                          "GroupDN='$GroupDN', Filter='$Filter'! (REMOTE_ADDR: $RemoteAddr).",
+                            "GroupDN='$GroupDN', Filter='$Filter'! (REMOTE_ADDR: $RemoteAddr).",
                     );
                 }
                 else {
                     # sync groups permissions
-                    my %SGroups = %{$Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination')->{$GroupDN}};
+                    my %SGroups = %{$Self->{ConfigObject}->Get('UserSyncLDAPGroupsDefination'.$Self->{Count})->{$GroupDN}};
                     foreach my $SGroup (sort keys %SGroups) {
                         my %Permissions = %{$SGroups{$SGroup}};
                         # get group id
@@ -479,7 +525,7 @@ sub Auth {
             }
         }
         # sync ldap group 2 otrs role permissions
-        if ($Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination')) {
+        if ($Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination'.$Self->{Count})) {
             my $Result = '';
             if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
                 $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -489,8 +535,8 @@ sub Auth {
             }
             if ($Result->code) {
                 $Self->{LogObject}->Log(
-                  Priority => 'error',
-                  Message => "Sync bind failed! ".$Result->error,
+                    Priority => 'error',
+                    Message => "Sync bind failed! ".$Result->error,
                 );
                 # take down session
                 $LDAP->unbind;
@@ -509,7 +555,7 @@ sub Auth {
                 );
             }
             # group config settings
-            foreach my $GroupDN (sort keys %{$Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination')}) {
+            foreach my $GroupDN (sort keys %{$Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination'.$Self->{Count})}) {
                 # just in case for debug
                 $Self->{LogObject}->Log(
                     Priority => 'notice',
@@ -518,13 +564,13 @@ sub Auth {
                 # search if we're allowed to
                 my $Filter = '';
                 if ($Self->{UserAttr} eq 'DN') {
-                    $Filter = "($Self->{AccessAttr}=$UserDN)";
+                    $Filter = "($Self->{AccessAttr}=$UserDNQuote)";
                 }
                 else {
-                    $Filter = "($Self->{AccessAttr}=$Param{User})";
+                    $Filter = "($Self->{AccessAttr}=$UserQuote)";
                 }
                 my $Result = $LDAP->search (
-                    base   => $GroupDN,
+                    base => $GroupDN,
                     filter => $Filter,
                 );
                 if ($Result->code) {
@@ -544,12 +590,12 @@ sub Auth {
                     $Self->{LogObject}->Log(
                         Priority => 'notice',
                         Message => "User: $Param{User} not in ".
-                          "GroupDN='$GroupDN', Filter='$Filter'! (REMOTE_ADDR: $RemoteAddr).",
+                            "GroupDN='$GroupDN', Filter='$Filter'! (REMOTE_ADDR: $RemoteAddr).",
                     );
                 }
                 else {
                     # sync groups permissions
-                    my %SRoles = %{$Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination')->{$GroupDN}};
+                    my %SRoles = %{$Self->{ConfigObject}->Get('UserSyncLDAPRolesDefination'.$Self->{Count})->{$GroupDN}};
                     foreach my $SRole (sort keys %SRoles) {
                         # get group id
                         my $RoleID = '';
@@ -577,7 +623,7 @@ sub Auth {
             }
         }
         # sync ldap attribute 2 otrs group permissions
-        if ($Self->{ConfigObject}->Get('UserSyncLDAPAttibuteGroupsDefination')) {
+        if ($Self->{ConfigObject}->Get('UserSyncLDAPAttibuteGroupsDefination'.$Self->{Count})) {
             my $Result = '';
             if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
                 $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -587,8 +633,8 @@ sub Auth {
             }
             if ($Result->code) {
                 $Self->{LogObject}->Log(
-                  Priority => 'error',
-                  Message => "Sync bind failed! ".$Result->error,
+                    Priority => 'error',
+                    Message => "Sync bind failed! ".$Result->error,
                 );
                 # take down session
                 $LDAP->unbind;
@@ -598,7 +644,7 @@ sub Auth {
             my %UserData = $Self->{UserObject}->GetUserData(User => $Param{User});
             # system permissions
             my %PermissionsEmpty = ();
-            foreach (@{$Self->{ConfigObject}->Get('System::Permission')}) {
+            foreach (@{$Self->{ConfigObject}->Get('System::Permission'.$Self->{Count})}) {
                 $PermissionsEmpty{$_} = 0;
             }
             # remove all group permissions
@@ -614,10 +660,10 @@ sub Auth {
                 );
             }
             # build filter
-            my $Filter = "($Self->{UID}=$Param{User})";
+            my $Filter = "($Self->{UID}=$UserQuote)";
             # perform search
             $Result = $LDAP->search (
-                base   => $Self->{BaseDN},
+                base => $Self->{BaseDN},
                 filter => $Filter,
             );
             if ($Result->code) {
@@ -626,14 +672,22 @@ sub Auth {
                     Message => "Search failed! (".$Self->{BaseDN}.") filter='$Filter' ".$Result->error,
                 );
             }
-            my %SyncConfig = %{$Self->{ConfigObject}->Get('UserSyncLDAPAttibuteGroupsDefination')};
+            my %SyncConfig = %{$Self->{ConfigObject}->Get('UserSyncLDAPAttibuteGroupsDefination'.$Self->{Count})};
             foreach my $Attribute (keys %SyncConfig) {
                 my %AttributeValues = %{$SyncConfig{$Attribute}};
                 foreach my $AttributeValue (keys %AttributeValues) {
                     foreach my $Entry ($Result->all_entries) {
-                        if ($Entry->get_value($Attribute) &&
-                            $Entry->get_value($Attribute) eq $AttributeValue
-                        ) {
+                        # Check all values of group attribute if needed value exists.
+                        # If yes, add all groups to the user.
+                        my $Sync = 0;
+                        my @Attributes = $Entry->get_value($Attribute);
+                        for my $Attribute (@Attributes) {
+                            if ($Attribute =~ /^\Q$AttributeValue\E$/i) {
+                                $Sync = 1;
+                                last;
+                            }
+                        }
+                        if ( $Sync ) {
                             my %Groups = %{$AttributeValues{$AttributeValue}};
                             foreach my $Group (keys %Groups) {
                                 # get group id
@@ -667,7 +721,7 @@ sub Auth {
             }
         }
         # sync ldap attribute 2 otrs role permissions
-        if ($Self->{ConfigObject}->Get('UserSyncLDAPAttibuteRolesDefination')) {
+        if ($Self->{ConfigObject}->Get('UserSyncLDAPAttibuteRolesDefination'.$Self->{Count})) {
             my $Result = '';
             if ($Self->{SearchUserDN} && $Self->{SearchUserPw}) {
                 $Result = $LDAP->bind(dn => $Self->{SearchUserDN}, password => $Self->{SearchUserPw});
@@ -677,8 +731,8 @@ sub Auth {
             }
             if ($Result->code) {
                 $Self->{LogObject}->Log(
-                  Priority => 'error',
-                  Message => "Sync bind failed! ".$Result->error,
+                    Priority => 'error',
+                    Message => "Sync bind failed! ".$Result->error,
                 );
                 # take down session
                 $LDAP->unbind;
@@ -697,10 +751,10 @@ sub Auth {
                 );
             }
             # build filter
-            my $Filter = "($Self->{UID}=$Param{User})";
+            my $Filter = "($Self->{UID}=$UserQuote)";
             # perform search
             $Result = $LDAP->search (
-                base   => $Self->{BaseDN},
+                base => $Self->{BaseDN},
                 filter => $Filter,
             );
             if ($Result->code) {
@@ -709,14 +763,22 @@ sub Auth {
                     Message => "Search failed! (".$Self->{BaseDN}.") filter='$Filter' ".$Result->error,
                 );
             }
-            my %SyncConfig = %{$Self->{ConfigObject}->Get('UserSyncLDAPAttibuteRolesDefination')};
+            my %SyncConfig = %{$Self->{ConfigObject}->Get('UserSyncLDAPAttibuteRolesDefination'.$Self->{Count})};
             foreach my $Attribute (keys %SyncConfig) {
                 my %AttributeValues = %{$SyncConfig{$Attribute}};
                 foreach my $AttributeValue (keys %AttributeValues) {
                     foreach my $Entry ($Result->all_entries) {
-                        if ($Entry->get_value($Attribute) &&
-                            $Entry->get_value($Attribute) eq $AttributeValue
-                        ) {
+                        # Check all values of roles attribute if needed value exists.
+                        # If yes, add all roles to the user.
+                        my $Sync = 0;
+                        my @Attributes = $Entry->get_value($Attribute);
+                        for my $Attribute (@Attributes) {
+                            if ($Attribute =~ /^\Q$AttributeValue\E$/i) {
+                                $Sync = 1;
+                                last;
+                            }
+                        }
+                        if ( $Sync ) {
                             my %Roles = %{$AttributeValues{$AttributeValue}};
                             foreach my $Role (keys %Roles) {
                                 # get role id
