@@ -2,7 +2,7 @@
 # Kernel/System/AuthSession/DB.pm - provides session db backend
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.23.2.1 2007/03/12 09:23:29 martin Exp $
+# $Id: DB.pm,v 1.28 2007/06/27 12:09:56 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,15 +12,15 @@
 package Kernel::System::AuthSession::DB;
 
 use strict;
+use warnings;
 use Digest::MD5;
 use MIME::Base64;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.23.2.1 $';
+$VERSION = '$Revision: 1.28 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -40,18 +40,15 @@ sub new {
     # Debug 0=off 1=on
     $Self->{Debug} = 0;
     # session table data
-    $Self->{SQLSessionTable} = $Self->{ConfigObject}->Get('SessionTable')
-     || 'sessions';
+    $Self->{SQLSessionTable} = $Self->{ConfigObject}->Get('SessionTable') || 'sessions';
     # id row
-    $Self->{SQLSessionTableID} = $Self->{ConfigObject}->Get('SessionTableID')
-     || 'session_id';
+    $Self->{SQLSessionTableID} = $Self->{ConfigObject}->Get('SessionTableID') || 'session_id';
     # value row
-    $Self->{SQLSessionTableValue} = $Self->{ConfigObject}->Get('SessionTableValue')
-     || 'session_value';
+    $Self->{SQLSessionTableValue} = $Self->{ConfigObject}->Get('SessionTableValue') || 'session_value';
 
     return $Self;
 }
-# --
+
 sub CheckSessionID {
     my $Self = shift;
     my %Param = @_;
@@ -65,18 +62,18 @@ sub CheckSessionID {
     if (!$Data{UserID} || !$Data{UserLogin}) {
         $Self->{CheckSessionIDMessage} = "SessionID invalid! Need user data!";
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID: '$SessionID' is invalid!!!",
+            Priority => 'notice',
+            Message => "SessionID: '$SessionID' is invalid!!!",
         );
         return;
     }
     # remote ip check
-    if ( $Data{UserRemoteAddr} ne $RemoteAddr &&
-          $Self->{ConfigObject}->Get('SessionCheckRemoteIP') ) {
+    if ($Data{UserRemoteAddr} ne $RemoteAddr &&
+        $Self->{ConfigObject}->Get('SessionCheckRemoteIP') ) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "RemoteIP of '$SessionID' ($Data{UserRemoteAddr}) is different with the ".
-           "request IP ($RemoteAddr). Don't grant access!!!",
+            Priority => 'notice',
+            Message => "RemoteIP of '$SessionID' ($Data{UserRemoteAddr}) is different with the ".
+                "request IP ($RemoteAddr). Don't grant access!!!",
         );
         # delete session id if it isn't the same remote ip?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfNotRemoteID')) {
@@ -87,11 +84,11 @@ sub CheckSessionID {
     # check session idle time
     my $MaxSessionIdleTime = $Self->{ConfigObject}->Get('SessionMaxIdleTime');
     if ( ($Self->{TimeObject}->SystemTime() - $MaxSessionIdleTime) >= $Data{UserLastRequest} ) {
-         $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
-         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID ($SessionID) idle timeout (". int(($Self->{TimeObject}->SystemTime() - $Data{UserLastRequest})/(60*60))
-          ."h)! Don't grant access!!!",
+        $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "SessionID ($SessionID) idle timeout (". int(($Self->{TimeObject}->SystemTime() - $Data{UserLastRequest})/(60*60))
+                ."h)! Don't grant access!!!",
         );
         # delete session id if too old?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld')) {
@@ -102,11 +99,11 @@ sub CheckSessionID {
     # check session time
     my $MaxSessionTime = $Self->{ConfigObject}->Get('SessionMaxTime');
     if ( ($Self->{TimeObject}->SystemTime() - $MaxSessionTime) >= $Data{UserSessionStart} ) {
-         $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
-         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID ($SessionID) too old (". int(($Self->{TimeObject}->SystemTime() - $Data{UserSessionStart})/(60*60))
-          ."h)! Don't grant access!!!",
+        $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "SessionID ($SessionID) too old (". int(($Self->{TimeObject}->SystemTime() - $Data{UserSessionStart})/(60*60))
+                ."h)! Don't grant access!!!",
         );
         # delete session id if too old?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld')) {
@@ -116,13 +113,13 @@ sub CheckSessionID {
     }
     return 1;
 }
-# --
+
 sub CheckSessionIDMessage {
     my $Self = shift;
     my %Param = @_;
     return $Self->{CheckSessionIDMessage} || '';
 }
-# --
+
 sub GetSessionIDData {
     my $Self = shift;
     my %Param = @_;
@@ -139,10 +136,10 @@ sub GetSessionIDData {
     }
     # read data
     my $SQL = "SELECT $Self->{SQLSessionTableValue} ".
-          " FROM ".
-          " $Self->{SQLSessionTable} ".
-          " WHERE ".
-          " $Self->{SQLSessionTableID} = '$Param{SessionID}'";
+        " FROM ".
+        " $Self->{SQLSessionTable} ".
+        " WHERE ".
+        " $Self->{SQLSessionTableID} = '$Param{SessionID}'";
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
         $Strg = $Row[0];
@@ -160,16 +157,16 @@ sub GetSessionIDData {
         }
         # Debug
         if ($Self->{Debug}) {
-             $Self->{LogObject}->Log(
+            $Self->{LogObject}->Log(
                 Priority => 'debug',
                 Message => "GetSessionIDData: '$PaarData[0]:".decode_base64($PaarData[1])."'",
-             );
-         }
+            );
+        }
     }
     # return data
     return %Data;
 }
-# --
+
 sub CreateSessionID {
     my $Self = shift;
     my %Param = @_;
@@ -198,41 +195,52 @@ sub CreateSessionID {
     # quote params
     $DataToStore = $Self->{DBObject}->Quote($DataToStore) || '';
     my $SQL = "INSERT INTO $Self->{SQLSessionTable} ".
-           " ($Self->{SQLSessionTableID}, $Self->{SQLSessionTableValue}) ".
-           " VALUES ".
-           " ('$SessionID', ?)";
-    $Self->{DBObject}->Do(SQL => $SQL, Bind => [\$DataToStore]) || die "Can't insert session id!";
+        " ($Self->{SQLSessionTableID}, $Self->{SQLSessionTableValue}) ".
+        " VALUES ".
+        " ('$SessionID', ?)";
+    $Self->{DBObject}->Do(SQL => $SQL, Bind => [\$DataToStore]);
 
     return $SessionID;
 }
-# --
+
 sub RemoveSessionID {
     my $Self = shift;
     my %Param = @_;
     my $SessionID = $Param{SessionID};
     # delete db recode
-    $Self->{DBObject}->Do(
-         SQL => "DELETE FROM $Self->{SQLSessionTable} ".
-                " WHERE $Self->{SQLSessionTableID} = '$SessionID'"
-    ) || return 0;
-    # log event
-    $Self->{LogObject}->Log(
-        Priority => 'notice',
-        Message => "Removed SessionID $Param{SessionID}."
-    );
-    return 1;
+    if (!$Self->{DBObject}->Do(
+        SQL => "DELETE FROM $Self->{SQLSessionTable} ".
+            " WHERE $Self->{SQLSessionTableID} = '$SessionID'"
+    )) {
+        return;
+    }
+    else {
+        # log event
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "Removed SessionID $Param{SessionID}."
+        );
+        return 1;
+    }
 }
-# --
+
 sub UpdateSessionID {
     my $Self = shift;
     my %Param = @_;
-    my $Key = $Param{Key} || die 'No Key!';
+    my $Key = defined($Param{Key}) ? $Param{Key} : '';
     my $Value = defined($Param{Value}) ? $Param{Value} : '';
-    my $SessionID = $Param{SessionID} || die 'No SessionID!';
+    my $SessionID = $Param{SessionID};
+    # check needed stuff
+    if (!$SessionID) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Need SessionID!",
+        );
+        return;
+    }
     my %SessionData = $Self->GetSessionIDData(SessionID => $SessionID);
     # check needed update! (no changes)
-    if (((exists $SessionData{$Key}) && $SessionData{$Key} eq $Value)
-      || (!exists $SessionData{$Key} && $Value eq '')) {
+    if (((exists $SessionData{$Key}) && $SessionData{$Key} eq $Value) || (!exists $SessionData{$Key} && $Value eq '')) {
         return 1;
     }
     # update the value
@@ -245,37 +253,35 @@ sub UpdateSessionID {
         # Debug
         if ($Self->{Debug}) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "UpdateSessionID: $_=$SessionData{$_}",
+                Priority => 'debug',
+                Message => "UpdateSessionID: $_=$SessionData{$_}",
             );
         }
     }
     # update db enrty
     my $SQL = "UPDATE $Self->{SQLSessionTable} ".
-            " SET ".
-            " $Self->{SQLSessionTableValue} = ? ".
-            " WHERE ".
-            " $Self->{SQLSessionTableID} = '".$Self->{DBObject}->Quote($SessionID)."'";
-    $Self->{DBObject}->Do(SQL => $SQL, Bind => [\$NewDataToStore]) || die "Can't update session table!";
-
-    return 1;
+        " SET ".
+        " $Self->{SQLSessionTableValue} = ? ".
+        " WHERE ".
+        " $Self->{SQLSessionTableID} = '".$Self->{DBObject}->Quote($SessionID)."'";
+    return $Self->{DBObject}->Do(SQL => $SQL, Bind => [\$NewDataToStore]);
 }
-# --
+
 sub GetAllSessionIDs {
     my $Self = shift;
     my %Param = @_;
     my @SessionIDs = ();
     # read data
     my $SQL = "SELECT $Self->{SQLSessionTableID} ".
-          " FROM ".
-          " $Self->{SQLSessionTable} ";
+        " FROM ".
+        " $Self->{SQLSessionTable}";
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @RowTmp = $Self->{DBObject}->FetchrowArray()) {
         push (@SessionIDs,  $RowTmp[0]);
     }
     return @SessionIDs;
 }
-# --
+
 sub CleanUp {
     my $Self = shift;
     my %Param = @_;
@@ -287,6 +293,5 @@ sub CleanUp {
         return;
     }
 }
-# --
 
 1;
