@@ -1,8 +1,8 @@
 # --
 # Kernel/System/AuthSession/IPC.pm - provides session IPC/Mem backend
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: IPC.pm,v 1.20 2006/08/29 17:31:42 martin Exp $
+# $Id: IPC.pm,v 1.25 2007/06/27 12:09:56 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,16 +12,16 @@
 package Kernel::System::AuthSession::IPC;
 
 use strict;
+use warnings;
 use IPC::SysV qw(IPC_PRIVATE IPC_RMID S_IRWXU);
 use Digest::MD5;
 use MIME::Base64;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.20 $';
+$VERSION = '$Revision: 1.25 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -47,21 +47,22 @@ sub new {
     $Self->{IPCKey} = "444422$Self->{SystemID}";
     $Self->{IPCAddBufferSize} = 10*1024;
     $Self->{IPCSize} = 80*1024;
-    $Self->{IPCSizeMax} = (360*1024) - $Self->{IPCAddBufferSize};
+    $Self->{IPCSizeMax} = (2048*1024) - $Self->{IPCAddBufferSize};
     $Self->{CMD} = $Param{CMD} || 0;
     $Self->_InitSHM();
 
     return $Self;
 }
-# --
+
 sub _InitSHM {
     my $Self = shift;
     # init meta data mem
     $Self->{KeyMeta} = shmget($Self->{IPCKeyMeta}, $Self->{IPCSizeMeta}, 0777 | 0001000) || die $!;
     # init session data mem
     $Self->{Key} = shmget($Self->{IPCKey}, $Self->_GetSHMDataSize(), 0777 | 0001000) || die $!;
+    return 1;
 }
-# --
+
 sub _WriteSHM {
     my $Self = shift;
     my %Param = @_;
@@ -74,9 +75,9 @@ sub _WriteSHM {
         shmwrite($Self->{Key}, $Param{Data}, 0, $CurrentDataSize) || die $!;
         if ($DataSize > $Self->{IPCSizeMax}) {
             $Self->{LogObject}->Log(
-              Priority => 'error',
-              Message => "Can't write session data. Max. size ".
-                "($Self->{IPCSizeMax} Bytes) of SessionData reached! Drop old sessions!",
+                Priority => 'error',
+                Message => "Can't write session data. Max. size ".
+                    "($Self->{IPCSizeMax} Bytes) of SessionData reached! Drop old sessions!",
             );
         }
     }
@@ -95,7 +96,7 @@ sub _WriteSHM {
         $Self->_SetSHMDataSize($NewIPCSize);
     }
 }
-# --
+
 sub _ReadSHM {
     my $Self = shift;
     # read session data from mem
@@ -110,7 +111,7 @@ sub _ReadSHM {
     }
     return $String;
 }
-# --
+
 sub _SetSHMDataSize {
     my $Self = shift;
     my $Size = shift || return;
@@ -118,7 +119,7 @@ sub _SetSHMDataSize {
     shmwrite($Self->{KeyMeta}, $Size.";", 0, $Self->{IPCSizeMeta}) || die $!;
     return 1;
 }
-# --
+
 sub _GetSHMDataSize {
     my $Self = shift;
     # read meta data from mem
@@ -130,7 +131,7 @@ sub _GetSHMDataSize {
     }
     return $Items[0];
 }
-# --
+
 sub CheckSessionID {
     my $Self = shift;
     my %Param = @_;
@@ -144,18 +145,18 @@ sub CheckSessionID {
     if (!$Data{UserID} || !$Data{UserLogin}) {
         $Self->{CheckSessionIDMessage} = "SessionID invalid! Need user data!";
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID: '$SessionID' is invalid!!!",
+            Priority => 'notice',
+            Message => "SessionID: '$SessionID' is invalid!!!",
         );
         return;
     }
     # remote ip check
     if ( $Data{UserRemoteAddr} ne $RemoteAddr &&
-          $Self->{ConfigObject}->Get('SessionCheckRemoteIP') ) {
+        $Self->{ConfigObject}->Get('SessionCheckRemoteIP') ) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "RemoteIP of '$SessionID' ($Data{UserRemoteAddr}) is different with the ".
-           "request IP ($RemoteAddr). Don't grant access!!!",
+            Priority => 'notice',
+            Message => "RemoteIP of '$SessionID' ($Data{UserRemoteAddr}) is different with the ".
+                "request IP ($RemoteAddr). Don't grant access!!!",
         );
         # delete session id if it isn't the same remote ip?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfNotRemoteID')) {
@@ -166,11 +167,11 @@ sub CheckSessionID {
     # check session idle time
     my $MaxSessionIdleTime = $Self->{ConfigObject}->Get('SessionMaxIdleTime');
     if ( ($Self->{TimeObject}->SystemTime() - $MaxSessionIdleTime) >= $Data{UserLastRequest} ) {
-         $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
-         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID ($SessionID) idle timeout (". int(($Self->{TimeObject}->SystemTime() - $Data{UserLastRequest})/(60*60))
-          ."h)! Don't grant access!!!",
+        $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "SessionID ($SessionID) idle timeout (". int(($Self->{TimeObject}->SystemTime() - $Data{UserLastRequest})/(60*60))
+                ."h)! Don't grant access!!!",
         );
         # delete session id if too old?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld')) {
@@ -181,11 +182,11 @@ sub CheckSessionID {
     # check session time
     my $MaxSessionTime = $Self->{ConfigObject}->Get('SessionMaxTime');
     if ( ($Self->{TimeObject}->SystemTime() - $MaxSessionTime) >= $Data{UserSessionStart} ) {
-         $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
-         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "SessionID ($SessionID) too old (". int(($Self->{TimeObject}->SystemTime() - $Data{UserSessionStart})/(60*60))
-          ."h)! Don't grant access!!!",
+        $Self->{CheckSessionIDMessage} = 'Session has timed out. Please log in again.';
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "SessionID ($SessionID) too old (". int(($Self->{TimeObject}->SystemTime() - $Data{UserSessionStart})/(60*60))
+                ."h)! Don't grant access!!!",
         );
         # delete session id if too old?
         if ($Self->{ConfigObject}->Get('SessionDeleteIfTimeToOld')) {
@@ -195,13 +196,13 @@ sub CheckSessionID {
     }
     return 1;
 }
-# --
+
 sub CheckSessionIDMessage {
     my $Self = shift;
     my %Param = @_;
     return $Self->{CheckSessionIDMessage} || '';
 }
-# --
+
 sub GetSessionIDData {
     my $Self = shift;
     my %Param = @_;
@@ -241,7 +242,7 @@ sub GetSessionIDData {
     }
     return %Data;
 }
-# --
+
 sub CreateSessionID {
     my $Self = shift;
     my %Param = @_;
@@ -280,7 +281,7 @@ sub CreateSessionID {
     $Self->_WriteSHM(Data => $DataToStore);
     return $SessionID;
 }
-# --
+
 sub RemoveSessionID {
     my $Self = shift;
     my %Param = @_;
@@ -305,17 +306,25 @@ sub RemoveSessionID {
     );
     return 1;
 }
-# --
+
 sub UpdateSessionID {
     my $Self = shift;
     my %Param = @_;
-    my $Key = $Param{Key} || die 'No Key!';
+    my $Key = defined($Param{Key}) ? $Param{Key} : '';
     my $Value = defined($Param{Value}) ? $Param{Value} : '';
-    my $SessionID = $Param{SessionID} || die 'No SessionID!';
+    my $SessionID = $Param{SessionID};
+    # check needed stuff
+    if (!$SessionID) {
+        $Self->{LogObject}->Log(
+            Priority => 'error',
+            Message => "Need SessionID!",
+        );
+        return;
+    }
     my %SessionData = $Self->GetSessionIDData(SessionID => $SessionID);
     # check needed update! (no changes)
     if (((exists $SessionData{$Key}) && $SessionData{$Key} eq $Value)
-      || (!exists $SessionData{$Key} && $Value eq '')) {
+        || (!exists $SessionData{$Key} && $Value eq '')) {
         return 1;
     }
     # update the value
@@ -335,8 +344,8 @@ sub UpdateSessionID {
         # Debug
         if ($Self->{Debug}) {
             $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "UpdateSessionID: $_=$SessionData{$_}",
+                Priority => 'debug',
+                Message => "UpdateSessionID: $_=$SessionData{$_}",
             );
         }
     }
@@ -356,7 +365,7 @@ sub UpdateSessionID {
 
     return 1;
 }
-# --
+
 sub GetAllSessionIDs {
     my $Self = shift;
     my %Param = @_;
@@ -380,7 +389,7 @@ sub GetAllSessionIDs {
     }
     return @SessionIDs;
 }
-# --
+
 sub CleanUp {
     my $Self = shift;
     # remove ipc meta data mem
@@ -401,6 +410,5 @@ sub CleanUp {
     }
     return 1;
 }
-# --
 
 1;
