@@ -1,12 +1,12 @@
 # --
 # Kernel/System/Cache/File.pm - all cache functions
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: File.pm,v 1.3.2.2 2007/11/05 13:27:55 martin Exp $
+# $Id: File.pm,v 1.3.2.4 2008/02/14 15:04:20 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::Cache::File;
@@ -15,7 +15,7 @@ use strict;
 use warnings;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.3.2.2 $';
+$VERSION = '$Revision: 1.3.2.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -51,15 +51,21 @@ sub Set {
     $Param{KeyNice} =~ s/(\n\r)/_/g;
     $Dump .= "#$Param{KeyNice}\n";
     $Dump .= $Self->{MainObject}->Dump($Param{Value})."\n1;";
-    my $FileLocation = $Self->{MainObject}->FileWrite(
-        Directory => $Self->{CacheDirectory},
-        Filename => $Param{Key},
-        Content => \$Dump,
-        Mode => 'utf8',
-        Type => 'MD5',
+
+    my %FileData = (
+        Directory  => $Self->{CacheDirectory},
+        Filename   => $Param{Key},
+        Content    => \$Dump,
+        Type       => 'MD5',
         Permission => '664',
     );
 
+    if ($Self->{ConfigObject}->Get('DefaultCharset') =~ /^utf(-8|8)$/i) {
+        $FileData{Mode} = 'utf8';
+    }
+
+    my $FileLocation = $Self->{MainObject}->FileWrite(%FileData);
+
     return 1;
 }
 
@@ -73,17 +79,23 @@ sub Get {
             return;
         }
     }
-    my $Content = $Self->{MainObject}->FileRead(
-        Directory => $Self->{CacheDirectory},
-        Filename => $Param{Key},
-        Type => 'MD5',
-        Mode => 'utf8',
+
+    my %FileData = (
+        Directory       => $Self->{CacheDirectory},
+        Filename        => $Param{Key},
+        Type            => 'MD5',
         DisableWarnings => 1,
     );
-    # check if cache exists
-    if (!$Content) {
-        return;
+
+    if ($Self->{ConfigObject}->Get('DefaultCharset') =~ /^utf(-8|8)$/i) {
+        $FileData{Mode} = 'utf8';
     }
+
+    my $Content = $Self->{MainObject}->FileRead(%FileData);
+
+    # check if cache exists
+    return if !$Content;
+
     my $TTL;
     my $VAR1;
     eval ${$Content};
