@@ -1,8 +1,8 @@
 # --
 # Kernel/System/CustomerAuth/DB.pm - provides the db authentification
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: DB.pm,v 1.14 2006/08/27 21:19:13 martin Exp $
+# $Id: DB.pm,v 1.17 2007/08/21 11:13:59 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Crypt::PasswdMD5 qw(unix_md5_crypt);
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.14 $';
+$VERSION = '$Revision: 1.17 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -35,22 +35,25 @@ sub new {
     $Self->{Debug} = 0;
 
     # config options
-    $Self->{Table} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::Table')
-      || die "Need CustomerAuthModule::DB::Table in Kernel/Config.pm!";
-    $Self->{Key} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::CustomerKey')
-      || die "Need CustomerAuthModule::DB::CustomerKey in Kernel/Config.pm!";
-    $Self->{Pw} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::CustomerPassword')
-      || die "Need CustomerAuthModule::DB::CustomerPw in Kernel/Config.pm!";
+    $Self->{Table} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::Table'.$Param{Count})
+        || die "Need CustomerAuthModule::DB::Table$Param{Count} in Kernel/Config.pm!";
+    $Self->{Key} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::CustomerKey'.$Param{Count})
+        || die "Need CustomerAuthModule::DB::CustomerKey$Param{Count} in Kernel/Config.pm!";
+    $Self->{Pw} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::CustomerPassword'.$Param{Count})
+        || die "Need CustomerAuthModule::DB::CustomerPw$Param{Count} in Kernel/Config.pm!";
+    $Self->{CryptType} = $Self->{ConfigObject}->Get('Customer::AuthModule::DB::CryptType'.$Param{Count})
+        || '';
 
-
-    if ($Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN')) {
+    if ($Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN'.$Param{Count})) {
         $Self->{DBObject} = Kernel::System::DB->new(
             LogObject => $Param{LogObject},
             ConfigObject => $Param{ConfigObject},
-            DatabaseDSN => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN'),
-            DatabaseUser => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::User'),
-            DatabasePw => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::Password'),
-        ) || die "Can't connect to ".$Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN');
+            MainObject => $Param{MainObject},
+            DatabaseDSN => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN'.$Param{Count}),
+            DatabaseUser => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::User'.$Param{Count}),
+            DatabasePw => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::Password'.$Param{Count}),
+            Type => $Self->{ConfigObject}->Get('Customer::AuthModule::DB::Type'.$Param{Count}) || '',
+        ) || die "Can't connect to ".$Self->{ConfigObject}->Get('Customer::AuthModule::DB::DSN'.$Param{Count});
         # remember that we have the DBObject not from parent call
         $Self->{NotParentDBObject} = 1;
     }
@@ -79,8 +82,8 @@ sub Auth {
     my %Param = @_;
     # check needed stuff
     if (!$Param{User}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need User!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need User!");
+        return;
     }
     # get params
     my $User = $Param{User} || '';
@@ -91,10 +94,10 @@ sub Auth {
 
     # sql query
     my $SQL = "SELECT $Self->{Pw}, $Self->{Key}".
-      " FROM ".
-      " $Self->{Table} ".
-      " WHERE ".
-      " $Self->{Key} = '".$Self->{DBObject}->Quote($User)."'";
+        " FROM ".
+        " $Self->{Table} ".
+        " WHERE ".
+        " $Self->{Key} = '".$Self->{DBObject}->Quote($User)."'";
     $Self->{DBObject}->Prepare(SQL => $SQL);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
         $GetPw = $Row[0];
@@ -104,8 +107,9 @@ sub Auth {
     # check if user exists in auth table
     if (!$UserID) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: No auth record in '$Self->{Table}' for '$User'  (REMOTE_ADDR: $RemoteAddr)",
+            Priority => 'notice',
+            Message => "CustomerUser: No auth record in '$Self->{Table}' for '$User' ".
+                "(REMOTE_ADDR: $RemoteAddr)",
         );
         return;
     }
@@ -114,7 +118,10 @@ sub Auth {
     my $CryptedPw = '';
     my $Salt = $GetPw;
     # md5 pw
-    if ($GetPw !~ /^.{13}$/) {
+    if ($Self->{CryptType} eq 'plain') {
+        $CryptedPw = $Pw;
+    }
+    elsif ($GetPw !~ /^.{13}$/) {
         # strip Salt
         $Salt =~ s/^\$.+?\$(.+?)\$.*$/$1/;
         $CryptedPw = unix_md5_crypt($Pw, $Salt);
@@ -150,40 +157,41 @@ sub Auth {
     # just in case!
     if ($Self->{Debug} > 0) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: '$User' tried to authentificate with Pw: '$Pw' ($UserID/$CryptedPw/$GetPw/$Salt/$RemoteAddr)",
+            Priority => 'notice',
+            Message => "CustomerUser: '$User' tried to authentificate with Pw: '$Pw' ".
+                "($UserID/$CryptedPw/$GetPw/$Salt/$RemoteAddr)",
         );
     }
 
     # just a note
     if (!$Pw) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: $User authentification without Pw!!! (REMOTE_ADDR: $RemoteAddr)",
+            Priority => 'notice',
+            Message => "CustomerUser: $User authentification without Pw!!! (REMOTE_ADDR: $RemoteAddr)",
         );
         return;
     }
     # login note
     elsif ((($GetPw)&&($User)&&($UserID)) && $CryptedPw eq $GetPw) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: $User authentification ok (REMOTE_ADDR: $RemoteAddr).",
+            Priority => 'notice',
+            Message => "CustomerUser: $User authentification ok (REMOTE_ADDR: $RemoteAddr).",
         );
         return $User;
     }
     # just a note
     elsif (($UserID) && ($GetPw)) {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: $User authentification with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
+            Priority => 'notice',
+            Message => "CustomerUser: $User authentification with wrong Pw!!! (REMOTE_ADDR: $RemoteAddr)"
         );
         return;
     }
     # just a note
     else {
         $Self->{LogObject}->Log(
-          Priority => 'notice',
-          Message => "CustomerUser: $User doesn't exist or is invalid!!! (REMOTE_ADDR: $RemoteAddr)"
+            Priority => 'notice',
+            Message => "CustomerUser: $User doesn't exist or is invalid!!! (REMOTE_ADDR: $RemoteAddr)"
         );
         return;
     }
