@@ -2,7 +2,7 @@
 # Kernel/System/DB/mssql.pm - mssql database backend
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: mssql.pm,v 1.14 2007/05/07 17:14:43 martin Exp $
+# $Id: mssql.pm,v 1.19.2.1 2007/12/17 16:08:44 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,9 +12,10 @@
 package Kernel::System::DB::mssql;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.14 $';
+$VERSION = '$Revision: 1.19.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -41,7 +42,7 @@ sub LoadPreferences {
     $Self->{'DB::DirectBlob'} = 0;
     $Self->{'DB::QuoteSingle'} = '\'';
     $Self->{'DB::QuoteBack'} = 0;
-    $Self->{'DB::QuoteSemicolon'} = '\\';
+    $Self->{'DB::QuoteSemicolon'} = '';
     $Self->{'DB::Attribute'} = {
         LongTruncOk => 1,
         LongReadLen => 70*1024*1024,
@@ -56,6 +57,11 @@ sub LoadPreferences {
     $Self->{'DB::ShellCommit'} = ';';
 #    $Self->{'DB::ShellConnect'} = '';
 
+    # init setting
+    if (!$Self->{ConfigObject}->Get('Database::ShellOutput')) {
+        $Self->{'DB::Connect'} = 'SET DATEFORMAT ymd';
+    }
+
     return 1;
 }
 
@@ -279,6 +285,11 @@ sub TableAlter {
     my $Table = '';
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start') {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQLStart .= $Self->{'DB::Comment'}." alter table $Tag->{Name}\n";
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
             $SQLStart .= "ALTER TABLE $Tag->{Name}";
             $Table = $Tag->{Name};
         }
@@ -287,10 +298,26 @@ sub TableAlter {
             $Tag = $Self->_TypeTranslation($Tag);
             # normal data type
             my $SQLEnd = $SQLStart." ADD $Tag->{Name} $Tag->{Type}";
-            if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+            if (!$Tag->{Default} && $Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
                 $SQLEnd .= " NOT NULL";
             }
             push (@SQL, $SQLEnd);
+            # default values
+            if ($Tag->{Default}) {
+                my $Start = '';
+                if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                    $Start = "GO\n";
+                }
+                if ($Tag->{Type} =~ /int/i) {
+                    push (@SQL, $Start."UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE $Tag->{Name} IS NULL");
+                }
+                else {
+                    push (@SQL, $Start."UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE '$Tag->{Name}' IS NULL");
+                }
+                if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+                    push (@SQL, "ALTER TABLE $Table ALTER COLUMN $Tag->{Name} $Tag->{Type} NOT NULL");
+                }
+            }
         }
         elsif ($Tag->{Tag} eq 'ColumnChange' && $Tag->{TagType} eq 'Start') {
             # Type translation
@@ -373,7 +400,7 @@ sub ForeignKeyCreate {
     }
     my $SQL = "ALTER TABLE $Param{LocalTableName} ADD FOREIGN KEY (";
     $SQL .= "$Param{Local}) REFERENCES ";
-    $SQL .= "`$Param{ForeignTableName}($Param{Foreign})`";
+    $SQL .= "$Param{ForeignTableName}($Param{Foreign})";
     # return SQL
     return ($SQL);
 }
