@@ -1,20 +1,21 @@
 # --
 # Kernel/System/DB/mysql.pm - mysql database backend
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: mysql.pm,v 1.11.2.1 2007/03/05 00:41:55 martin Exp $
+# $Id: mysql.pm,v 1.21.2.1 2008/05/07 10:05:38 mh Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 
 package Kernel::System::DB::mysql;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.11.2.1 $';
+$VERSION = '$Revision: 1.21.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -43,10 +44,21 @@ sub LoadPreferences {
     $Self->{'DB::QuoteBack'} = '\\';
     $Self->{'DB::QuoteSemicolon'} = '\\';
     $Self->{'DB::Attribute'} = {};
+    # set current time stamp if different to "current_timestamp"
+    $Self->{'DB::CurrentTimestamp'} = '';
+    # set encoding of selected data to utf8
+    $Self->{'DB::Encode'} = 1;
 
     # shell setting
     $Self->{'DB::Comment'} = '# ';
     $Self->{'DB::ShellCommit'} = ';';
+#    $Self->{'DB::ShellConnect'} = '';
+
+    # init setting
+    if ($Self->{ConfigObject}->Get('DefaultCharset') =~ /(utf(\-8|8))/i &&
+        !$Self->{ConfigObject}->Get('Database::ShellOutput')) {
+        $Self->{'DB::Connect'} = 'SET NAMES utf8';
+    }
 
     return 1;
 }
@@ -77,7 +89,12 @@ sub DatabaseCreate {
         return;
     }
     # return SQL
-    return ("CREATE DATABASE $Param{Name}");
+    if ($Self->{ConfigObject}->Get('DefaultCharset') =~ /(utf(\-8|8))/i) {
+        return ("CREATE DATABASE $Param{Name} DEFAULT CHARSET=utf8");
+    }
+    else {
+        return ("CREATE DATABASE $Param{Name}");
+    }
 }
 
 sub DatabaseDrop {
@@ -110,9 +127,11 @@ sub TableCreate {
     my @Return = ();
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start') {
-            $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
-            $SQLStart .= $Self->{'DB::Comment'}." create table $Tag->{Name}\n";
-            $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQLStart .= $Self->{'DB::Comment'}." create table $Tag->{Name}\n";
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
         }
         if (($Tag->{Tag} eq 'Table' || $Tag->{Tag} eq 'TableCreate') && $Tag->{TagType} eq 'Start') {
             $SQLStart .= "CREATE TABLE $Tag->{Name} (\n";
@@ -153,6 +172,15 @@ sub TableCreate {
         if ($Tag->{Required} =~ /^true$/i) {
             $SQL .= " NOT NULL";
         }
+        # add default
+        if ($Tag->{Default}) {
+            if ($Tag->{Type} =~ /int/i) {
+                $SQL .= " SET DEFAULT ".$Tag->{Default}."";
+            }
+            else {
+                $SQL.= " SET DEFAULT '".$Tag->{Default}."'";
+            }
+        }
         # auto increment
         if ($Tag->{AutoIncrement} && $Tag->{AutoIncrement} =~ /^true$/i) {
             $SQL .= " AUTO_INCREMENT";
@@ -241,9 +269,11 @@ sub TableDrop {
     my $SQL = '';
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Table' && $Tag->{TagType} eq 'Start') {
-            $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
-            $SQL .= $Self->{'DB::Comment'}." drop table $Tag->{Name}\n";
-            $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQL .= $Self->{'DB::Comment'}." drop table $Tag->{Name}\n";
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
         }
         $SQL .= "DROP TABLE IF EXISTS $Tag->{Name}";
         return ($SQL);
@@ -256,19 +286,37 @@ sub TableAlter {
     my @Param = @_;
     my $SQLStart = '';
     my @SQL = ();
+    my $Table = '';
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'TableAlter' && $Tag->{TagType} eq 'Start') {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQLStart .= $Self->{'DB::Comment'}." alter table $Tag->{Name}\n";
+                $SQLStart .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
             $SQLStart .= "ALTER TABLE $Tag->{Name}";
+            $Table = $Tag->{Name};
         }
         elsif ($Tag->{Tag} eq 'ColumnAdd' && $Tag->{TagType} eq 'Start') {
             # Type translation
             $Tag = $Self->_TypeTranslation($Tag);
             # normal data type
             my $SQLEnd = $SQLStart." ADD $Tag->{Name} $Tag->{Type}";
-            if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+            if (!$Tag->{Default} && $Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
                 $SQLEnd .= " NOT NULL";
             }
             push (@SQL, $SQLEnd);
+            if ($Tag->{Default}) {
+                if ($Tag->{Type} =~ /int/i) {
+                    push (@SQL, "UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE $Tag->{Name} IS NULL");
+                }
+                else {
+                    push (@SQL, "UPDATE $Table SET $Tag->{Name} = $Tag->{Default} WHERE '$Tag->{Name}' IS NULL");
+                }
+                if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
+                    push (@SQL, "ALTER TABLE $Table CHANGE $Tag->{Name} $Tag->{Name} $Tag->{Type} NOT NULL");
+                }
+            }
         }
         elsif ($Tag->{Tag} eq 'ColumnChange' && $Tag->{TagType} eq 'Start') {
             # Type translation
@@ -278,6 +326,14 @@ sub TableAlter {
             if ($Tag->{Required} && $Tag->{Required} =~ /^true$/i) {
                 $SQLEnd .= " NOT NULL";
             }
+            if ($Tag->{Default}) {
+                if ($Tag->{Type} =~ /int/i) {
+                    $SQLEnd .= " SET DEFAULT ".$Tag->{Default}."";
+                }
+                else {
+                    $SQLEnd .= " SET DEFAULT '".$Tag->{Default}."'";
+                }
+            }
             push (@SQL, $SQLEnd);
         }
         elsif ($Tag->{Tag} eq 'ColumnDrop' && $Tag->{TagType} eq 'Start') {
@@ -341,7 +397,7 @@ sub ForeignKeyCreate {
     }
     my $SQL = "ALTER TABLE $Param{LocalTableName} ADD FOREIGN KEY (";
     $SQL .= "$Param{Local}) REFERENCES ";
-    $SQL .= "`$Param{ForeignTableName}($Param{Foreign})`";
+    $SQL .= "$Param{ForeignTableName} ($Param{Foreign})";
     # return SQL
     return ($SQL);
 }
@@ -406,35 +462,68 @@ sub Insert {
     my @Values = ();
     foreach my $Tag (@Param) {
         if ($Tag->{Tag} eq 'Insert' && $Tag->{TagType} eq 'Start') {
-            $SQL = "INSERT INTO $Tag->{Table} "
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+                $SQL .= $Self->{'DB::Comment'}." insert into table $Tag->{Table}\n";
+                $SQL .= $Self->{'DB::Comment'}."----------------------------------------------------------\n";
+            }
+            $SQL .= "INSERT INTO $Tag->{Table} "
         }
         if ($Tag->{Tag} eq 'Data' && $Tag->{TagType} eq 'Start') {
             $Tag->{Key} = ${$Self->Quote(\$Tag->{Key})};
             push (@Keys, $Tag->{Key});
-            if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
-                $Tag->{Value} = "'".${$Self->Quote(\$Tag->{Value})}."'";
+            my $Value;
+            if (defined($Tag->{Value})) {
+                $Value = $Tag->{Value};
+                $Self->{LogObject}->Log(
+                    Priority => 'error',
+                    Message => "The content for inserts is not longer appreciated attribut Value, use Content from now on! Reason: You can't use new lines in attributes.",
+                );
+            }
+            elsif (defined($Tag->{Content})) {
+                $Value = $Tag->{Content};
             }
             else {
-                $Tag->{Value} = ${$Self->Quote(\$Tag->{Value})};
+                $Value = '';
             }
-            push (@Values, $Tag->{Value});
+            if ($Tag->{Type} && $Tag->{Type} eq 'Quote') {
+                $Value = "'".${$Self->Quote(\$Value)}."'";
+            }
+            else {
+                $Value = ${$Self->Quote(\$Value)};
+            }
+            push (@Values, $Value);
         }
     }
     my $Key = '';
     foreach (@Keys) {
         if ($Key ne '') {
-            $Key .= ",";
+            $Key .= ", ";
         }
         $Key .= $_;
     }
     my $Value = '';
-    foreach (@Values) {
+    foreach my $Tmp (@Values) {
         if ($Value ne '') {
-            $Value .= ",";
+            $Value .= ", ";
+        }
+        if ($Tmp eq 'current_timestamp') {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $Value .= $Tmp;
+            }
+            else {
+                my $Timestamp = $Self->{TimeObject}->CurrentTimestamp();
+                $Value .= '\''.$Timestamp.'\'';
+            }
+        }
+        else {
+            if ($Self->{ConfigObject}->Get('Database::ShellOutput')) {
+                $Tmp =~ s/\n/\r/g;
+            }
+            $Value .= $Tmp;
         }
-        $Value .= $_;
     }
-    $SQL .= "($Key) VALUES ($Value)";
+    $SQL .= "($Key)\n    VALUES\n    ($Value)";
     return ($SQL);
 }
 
