@@ -1,8 +1,8 @@
 # --
 # Kernel/System/GenericAgent/AutoPriorityIncrease.pm - generic agent auto priority increase
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: AutoPriorityIncrease.pm,v 1.2 2006/08/29 17:31:04 martin Exp $
+# $Id: AutoPriorityIncrease.pm,v 1.4 2007/03/05 02:06:33 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,10 +14,9 @@ package Kernel::System::GenericAgent::AutoPriorityIncrease;
 use strict;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.2 $';
+$VERSION = '$Revision: 1.4 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
-# --
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -36,7 +35,7 @@ sub new {
 
     return $Self;
 }
-# --
+
 sub Run {
     my $Self = shift;
     my %Param = @_;
@@ -86,7 +85,7 @@ sub Run {
     }
     else {
         # increase priority
-        my $Priority = $Self->{TicketObject}->PriorityLookup(ID => ($Ticket{PriorityID}+1));
+        my $Priority = $Self->{PriorityObject}->PriorityLookup(PriorityID => ($Ticket{PriorityID}+1));
         # do nothing if already highest priority
         if (!$Priority) {
             $Self->{LogObject}->Log(
@@ -120,5 +119,5 @@ sub Run {
     }
     return 1;
 }
-# --
+
 1;
