@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Notification.pm - lib for notifications
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: Notification.pm,v 1.10 2006/11/02 12:20:53 tr Exp $
+# $Id: Notification.pm,v 1.12 2007/02/06 21:54:53 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,9 +15,44 @@ use strict;
 use Kernel::System::Encode;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.10 $';
+$VERSION = '$Revision: 1.12 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+=head1 NAME
+
+Kernel::System::Notification - notification functions
+
+=head1 SYNOPSIS
+
+This module is managing notifications.
+
+=head1 PUBLIC INTERFACE
+
+=over 4
+
+=cut
+
+=item new()
+
+create a notification object
+
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::DB;
+
+    my $ConfigObject = Kernel::Config->new();
+
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+
+=cut
+
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -41,13 +76,23 @@ sub new {
     return $Self;
 }
 
+=item NotificationGet()
+
+get notification attributes
+
+    my %Notification = $NotificationObject->NotificationGet(
+        Name => 'de::NewTicket',
+    );
+
+=cut
+
 sub NotificationGet {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
     if (!$Param{Name}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need Name!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need Name!");
+        return;
     }
     my ($Language, $Type);
     if ($Param{Name} =~ /^(.+?)::(.*)/) {
@@ -69,9 +114,8 @@ sub NotificationGet {
     }
     else {
         $SQL .= " notification_type = '$Type' AND ".
-          "notification_language = '$Language'";
+            "notification_language = '$Language'";
     }
-#print STDERR "SQL: $SQL\n";
     if (!$Self->{DBObject}->Prepare(SQL => $SQL)) {
         return;
     }
@@ -120,10 +164,18 @@ sub NotificationGet {
         return;
     }
     else {
-       return ( %Data, Language => $Param{Loop} || $Language );
+        return ( %Data, Language => $Param{Loop} || $Language );
     }
 }
 
+=item NotificationList()
+
+get notification list
+
+    my %List = $NotificationObject->NotificationList();
+
+=cut
+
 sub NotificationList {
     my $Self = shift;
     my %Param = @_;
@@ -145,15 +197,11 @@ sub NotificationList {
     foreach (qw(NewTicket FollowUp LockTimeout OwnerUpdate AddNote Move PendingReminder Escalation)) {
         $Types{'Agent::'.$_} = 1;
     }
-    foreach (qw(QueueUpdate OwnerUpdate StateUpdate)) {
-        $Types{'Customer::'.$_} = 1;
-    }
     # create list
     my %List = ();
     foreach my $Language (keys %Languages) {
         foreach my $Type (keys %Types) {
             $List{$Language.'::'.$Type} = $Language."::$Type";
-#print STDERR "ddd $Language :: $Type\n";
         }
     }
     # get real list
@@ -166,15 +214,30 @@ sub NotificationList {
     return %List;
 }
 
+=item NotificationUpdate()
+
+update notification attributes
+
+    $NotificationObject->NotificationUpdate(
+        Type => 'NewTicket',
+        Charset => 'utf-8',
+        Language => 'en',
+        Subject => 'Some Subject with <OTRS_TAGS>',
+        Body => 'Some Body with <OTRS_TAGS>',
+        UserID => 123,
+    );
+
+=cut
+
 sub NotificationUpdate {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
     foreach (qw(Type Charset Language Subject Body UserID)) {
-      if (!defined($Param{$_})) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!defined($Param{$_})) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # fix some bad stuff from some browsers (Opera)!
     $Param{Body} =~ s/(\n\r|\r\r\n|\r\n|\r)/\n/g;
@@ -186,7 +249,10 @@ sub NotificationUpdate {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
     # sql
-    $Self->{DBObject}->Prepare(SQL => "DELETE FROM notifications WHERE notification_type = '$Param{Type}' AND notification_language = '$Param{Language}'");
+    $Self->{DBObject}->Prepare(
+        SQL => "DELETE FROM notifications WHERE notification_type = '$Param{Type}' ".
+            "AND notification_language = '$Param{Language}'",
+    );
     # sql
     my $SQL = "INSERT INTO notifications ".
         " (notification_type, notification_charset, notification_language, subject, text, ".
@@ -194,7 +260,6 @@ sub NotificationUpdate {
         " VALUES ".
         " ('$Param{Type}', '$Param{Charset}', '$Param{Language}', '$Param{Subject}', '$Param{Body}', ".
         " current_timestamp, $Param{UserID}, current_timestamp,  $Param{UserID})";
-#print STDERR "SQL: $SQL\n";
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
         return 1;
     }
@@ -204,3 +269,21 @@ sub NotificationUpdate {
 }
 
 1;
+
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (http://otrs.org/).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.12 $ $Date: 2007/02/06 21:54:53 $
+
+=cut
