@@ -2,7 +2,7 @@
 # Kernel/System/PostMaster.pm - the global PostMaster module for OTRS
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: PostMaster.pm,v 1.60.2.1 2007/05/30 08:55:28 tr Exp $
+# $Id: PostMaster.pm,v 1.65 2007/03/19 22:27:19 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,8 +12,6 @@
 package Kernel::System::PostMaster;
 
 use strict;
-use Kernel::System::DB;
-use Kernel::System::Main;
 use Kernel::System::EmailParser;
 use Kernel::System::Ticket;
 use Kernel::System::Queue;
@@ -25,9 +23,62 @@ use Kernel::System::PostMaster::DestQueue;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '$Revision: 1.60.2.1 $';
+$VERSION = '$Revision: 1.65 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+=head1 NAME
+
+Kernel::System::PostMaster - postmaster lib
+
+=head1 SYNOPSIS
+
+All postmaster functions. E. g. to process emails.
+
+=head1 PUBLIC INTERFACE
+
+=over 4
+
+=cut
+
+=item new()
+
+create a object
+
+    use Kernel::Config;
+    use Kernel::System::Time;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::Postmaster;
+
+    my $ConfigObject = Kernel::Config->new();
+    my $TimeObject = Kernel::System::Time->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        LogObject => $LogObject,
+        ConfigObject => $ConfigObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        MainObject => $MainObject,
+        LogObject => $LogObject,
+    );
+    my $PostMasterObject = Kernel::System::PostMasterObject->new(
+        DBObject => DBObject,
+        TimeObject => TimeObject,
+        ConfigObject => $ConfigObject,
+        MainObject => $MainObject,
+        LogObject => $LogObject,
+        Email => \@ArrayOfEmailContent,
+        Trusted => 1, # 1|0 ignore X-OTRS header if false
+    );
+
+=cut
+
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -40,7 +91,7 @@ sub new {
         $Self->{$_} = $Param{$_};
     }
     # check needed objects
-    foreach (qw(DBObject LogObject ConfigObject TimeObject Email MainObject)) {
+    foreach (qw(DBObject LogObject ConfigObject TimeObject MainObject Email)) {
         die "Got no $_" if (!$Param{$_});
     }
     # check needed config objects
@@ -52,7 +103,6 @@ sub new {
     $Self->{Debug} = $Param{Debug} || 0;
 
     # create common objects
-    $Self->{MainObject} = Kernel::System::Main->new(%Param);
     $Self->{TicketObject} = Kernel::System::Ticket->new(%Param);
     $Self->{ParseObject} = Kernel::System::EmailParser->new(
         Email => $Param{Email},
@@ -93,9 +143,27 @@ sub new {
     return $Self;
 }
 
+=item Run()
+
+to execute the run process
+
+    $PostMasterObject->Run();
+
+return params
+
+    0 = error (also false)
+    1 = new ticket created
+    2 = follow up / open/reopen
+    3 = follow up / close -> new ticket
+    4 = follow up / close -> reject
+    5 = ignored (because of X-OTRS-Ignore header)
+
+=cut
+
 sub Run {
     my $Self = shift;
     my %Param = @_;
+    my @Return = ();
     # ConfigObject section / get params
     my $GetParam = $Self->GetEmailParams();
 
@@ -109,12 +177,12 @@ sub Run {
             if ($Self->{MainObject}->Require($Jobs{$Job}->{Module})) {
                 my $FilterObject = $Jobs{$Job}->{Module}->new(
                     ConfigObject => $Self->{ConfigObject},
+                    MainObject => $Self->{MainObject},
                     LogObject => $Self->{LogObject},
                     DBObject => $Self->{DBObject},
                     ParseObject => $Self->{ParseObject},
                     TicketObject => $Self->{TicketObject},
                     TimeObject => $Self->{TimeObject},
-                    MainObject => $Self->{MainObject},
                     Debug => $Self->{Debug},
                 );
                 # modify params
@@ -134,21 +202,21 @@ sub Run {
 
     # should I ignore the incoming mail?
     if ($GetParam->{'X-OTRS-Ignore'} && $GetParam->{'X-OTRS-Ignore'} =~ /yes/i) {
-       $Self->{LogObject}->Log(
-           Priority => 'notice',
-           Message => "Ignored Email (From: $GetParam->{'From'}, Message-ID: $GetParam->{'Message-ID'}) " .
-           "because the X-OTRS-Ignore is set (X-OTRS-Ignore: $GetParam->{'X-OTRS-Ignore'})."
-       );
-       return 1;
-   }
-   # ----------------------
-   # ticket section
-   # ----------------------
+        $Self->{LogObject}->Log(
+            Priority => 'notice',
+            Message => "Ignored Email (From: $GetParam->{'From'}, Message-ID: $GetParam->{'Message-ID'}) " .
+                "because the X-OTRS-Ignore is set (X-OTRS-Ignore: $GetParam->{'X-OTRS-Ignore'})."
+        );
+        return (5);
+    }
+    # ----------------------
+    # ticket section
+    # ----------------------
 
-   # check if follow up (again, with new GetParam)
-   ($Tn, $TicketID) = $Self->CheckFollowUp(%{$GetParam});
-   # check if it's a follow up ...
-   if ($Tn && $TicketID) {
+    # check if follow up (again, with new GetParam)
+    ($Tn, $TicketID) = $Self->CheckFollowUp(%{$GetParam});
+    # check if it's a follow up ...
+    if ($Tn && $TicketID) {
         # get ticket data
         my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $TicketID);
         # check if it is possible to do the follow up
@@ -172,9 +240,9 @@ sub Run {
             # send mail && create new article
             # get queue if of From: and To:
             if (!$Param{QueueID}) {
-              $Param{QueueID} = $Self->{DestQueueObject}->GetQueueID(
-                  Params => $GetParam,
-              );
+                $Param{QueueID} = $Self->{DestQueueObject}->GetQueueID(
+                    Params => $GetParam,
+                );
             }
             # check if trusted returns a new queue id
             my $TQueueID = $Self->{DestQueueObject}->GetTrustedQueueID(
@@ -193,6 +261,9 @@ sub Run {
             if (!$TicketID) {
                 return;
             }
+            else {
+                @Return = (3, $TicketID);
+            }
         }
         # reject follow up
         elsif ($FollowUpPossible =~ /reject/i && $State{TypeName} =~ /^close/i) {
@@ -212,6 +283,9 @@ sub Run {
             )) {
                 return;
             }
+            else {
+                @Return = (4, $TicketID);
+            }
         }
         # create normal follow up
         else {
@@ -225,6 +299,9 @@ sub Run {
             )) {
                 return;
             }
+            else {
+                @Return = (2, $TicketID);
+            }
         }
     }
     # create new ticket
@@ -253,6 +330,9 @@ sub Run {
         if (!$TicketID) {
             return;
         }
+        else {
+            @Return = (1, $TicketID);
+        }
     }
 
     # run all PostFilterModules (modify email params)
@@ -262,13 +342,13 @@ sub Run {
             if ($Self->{MainObject}->Require($Jobs{$Job}->{Module})) {
                 my $FilterObject = $Jobs{$Job}->{Module}->new(
                     ConfigObject => $Self->{ConfigObject},
+                    MainObject => $Self->{MainObject},
                     LogObject => $Self->{LogObject},
                     DBObject => $Self->{DBObject},
                     ParseObject => $Self->{ParseObject},
                     TicketObject => $Self->{TicketObject},
                     TimeObject => $Self->{TimeObject},
                     Debug => $Self->{Debug},
-                    MainObject => $Self->{MainObject},
                 );
                 # modify params
                 if (!$FilterObject->Run(
@@ -284,25 +364,31 @@ sub Run {
             }
         }
     }
-
-    # return 1
-    return 1;
+    return @Return;
 }
 
-# CheckFollowUp
+=item CheckFollowUp()
+
+to detect the ticket number in processing email
+
+    my ($TicketNumber, $TicketID) = $PostMasterObject->CheckFollowUp(
+        Subject => 'Re: [Ticket:#123456] Some Subject',
+    );
+
+=cut
 
 sub CheckFollowUp {
     my $Self = shift;
     my %Param = @_;
     my $Subject = $Param{Subject} || '';
     if (my $Tn = $Self->{TicketObject}->GetTNByString($Subject)) {
-        my $TicketID = $Self->{TicketObject}->CheckTicketNr(Tn => $Tn);
+        my $TicketID = $Self->{TicketObject}->TicketCheckNumber(Tn => $Tn);
         if ($TicketID) {
             my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $TicketID);
             if ($Self->{Debug} > 1) {
                 $Self->{LogObject}->Log(
-                  Priority => 'debug',
-                  Message => "CheckFollowUp: ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
+                    Priority => 'debug',
+                    Message => "CheckFollowUp: ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                 );
             }
             return ($Ticket{TicketNumber}, $TicketID);
@@ -319,7 +405,7 @@ sub CheckFollowUp {
             );
             if ($TicketID) {
                 my $Tn = $Self->{TicketObject}->TicketNumberLookup(
-                     TicketID => $TicketID,
+                    TicketID => $TicketID,
                 );
                 if ($TicketID && $Tn) {
                     return ($Tn, $TicketID);
@@ -330,13 +416,13 @@ sub CheckFollowUp {
     # do body ticket number lookup
     if ($Self->{ConfigObject}->Get('PostmasterFollowUpSearchInBody')) {
         if (my $Tn = $Self->{TicketObject}->GetTNByString($Self->{ParseObject}->GetMessageBody())) {
-            my $TicketID = $Self->{TicketObject}->CheckTicketNr(Tn => $Tn);
+            my $TicketID = $Self->{TicketObject}->TicketCheckNumber(Tn => $Tn);
             if ($TicketID) {
                 my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $TicketID);
                 if ($Self->{Debug} > 1) {
                     $Self->{LogObject}->Log(
-                      Priority => 'debug',
-                      Message => "CheckFollowUp (in body): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
+                        Priority => 'debug',
+                        Message => "CheckFollowUp (in body): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                     );
                 }
                 return ($Ticket{TicketNumber}, $TicketID);
@@ -347,13 +433,13 @@ sub CheckFollowUp {
     if ($Self->{ConfigObject}->Get('PostmasterFollowUpSearchInAttachment')) {
         foreach my $Attachment ($Self->{ParseObject}->GetAttachments()) {
             if (my $Tn = $Self->{TicketObject}->GetTNByString($Attachment->{Content})) {
-                my $TicketID = $Self->{TicketObject}->CheckTicketNr(Tn => $Tn);
+                my $TicketID = $Self->{TicketObject}->TicketCheckNumber(Tn => $Tn);
                 if ($TicketID) {
                     my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $TicketID);
                     if ($Self->{Debug} > 1) {
                         $Self->{LogObject}->Log(
-                          Priority => 'debug',
-                          Message => "CheckFollowUp (in attachment): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
+                            Priority => 'debug',
+                            Message => "CheckFollowUp (in attachment): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                         );
                     }
                     return ($Ticket{TicketNumber}, $TicketID);
@@ -364,13 +450,13 @@ sub CheckFollowUp {
     # do plain/raw ticket number lookup
     if ($Self->{ConfigObject}->Get('PostmasterFollowUpSearchInRaw')) {
         if (my $Tn = $Self->{TicketObject}->GetTNByString($Self->{ParseObject}->GetPlainEmail())) {
-            my $TicketID = $Self->{TicketObject}->CheckTicketNr(Tn => $Tn);
+            my $TicketID = $Self->{TicketObject}->TicketCheckNumber(Tn => $Tn);
             if ($TicketID) {
                 my %Ticket = $Self->{TicketObject}->TicketGet(TicketID => $TicketID);
                 if ($Self->{Debug} > 1) {
                     $Self->{LogObject}->Log(
-                      Priority => 'debug',
-                      Message => "CheckFollowUp (in plain/raw): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
+                        Priority => 'debug',
+                        Message => "CheckFollowUp (in plain/raw): ja, it's a follow up ($Ticket{TicketNumber}/$TicketID)",
                     );
                 }
                 return ($Ticket{TicketNumber}, $TicketID);
@@ -380,7 +466,13 @@ sub CheckFollowUp {
     return;
 }
 
-# GetEmailParams
+=item GetEmailParams()
+
+to get all configured PostmasterX-Header email headers
+
+    my %Header = $PostMasterObject->GetEmailParams();
+
+=cut
 
 sub GetEmailParams {
     my $Self = shift;
@@ -389,19 +481,19 @@ sub GetEmailParams {
     # parse section
     my $WantParamTmp = $Self->{'PostmasterX-Header'} || die "Got no \@WantParam ref";
     my @WantParam = @$WantParamTmp;
-    foreach (@WantParam){
-      if (!$Self->{Trusted} && $_ =~ /^x-otrs/i) {
-        # scan not x-otrs header if it's not trusted
-      }
-      else {
-        if ($Self->{Debug} > 2) {
-          $Self->{LogObject}->Log(
-              Priority => 'debug',
-              Message => "$_: " . $Self->{ParseObject}->GetParam(WHAT => $_),
-          );
+    foreach (@WantParam) {
+        if (!$Self->{Trusted} && $_ =~ /^x-otrs/i) {
+            # scan not x-otrs header if it's not trusted
+        }
+        else {
+            if ($Self->{Debug} > 2) {
+                $Self->{LogObject}->Log(
+                    Priority => 'debug',
+                    Message => "$_: " . $Self->{ParseObject}->GetParam(WHAT => $_),
+                );
+            }
+            $GetParam{$_} = $Self->{ParseObject}->GetParam(WHAT => $_);
         }
-        $GetParam{$_} = $Self->{ParseObject}->GetParam(WHAT => $_);
-      }
     }
     # set compat. headers
     if ($GetParam{'Message-Id'}) {
@@ -410,10 +502,22 @@ sub GetEmailParams {
     if ($GetParam{'Reply-To'}) {
         $GetParam{'ReplyTo'} = $GetParam{'Reply-To'};
     }
-    if ($GetParam{'Mailing-List'} || $GetParam{'Precedence'} || $GetParam{'X-Loop'}
-             || $GetParam{'X-No-Loop'} || $GetParam{'X-OTRS-Loop'}) {
+    if ($GetParam{'Mailing-List'} || $GetParam{'Precedence'} ||
+        $GetParam{'X-Loop'} || $GetParam{'X-No-Loop'} || $GetParam{'X-OTRS-Loop'}
+    ) {
         $GetParam{'X-OTRS-Loop'} = 'yes';
     }
+    if (!$GetParam{'X-Sender'}) {
+        # get sender email
+        my @EmailAddresses = $Self->{ParseObject}->SplitAddressLine(
+            Line => $GetParam{From},
+        );
+        foreach (@EmailAddresses) {
+            $GetParam{'X-Sender'} = $Self->{ParseObject}->GetEmailAddress(
+                Email => $_,
+            );
+        }
+    }
     # set sender type if not given
     foreach my $Key (qw(X-OTRS-SenderType X-OTRS-FollowUp-SenderType)) {
         if (!$GetParam{$Key}) {
@@ -451,3 +555,21 @@ sub GetEmailParams {
 }
 
 1;
+
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This Software is part of the OTRS project (http://otrs.org/).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+
+=cut
+
+=head1 VERSION
+
+$Revision: 1.65 $ $Date: 2007/03/19 22:27:19 $
+
+=cut
