@@ -1,8 +1,8 @@
 # --
 # Kernel/System/PostMaster/FollowUp.pm - the sub part of PostMaster.pm
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: FollowUp.pm,v 1.48 2006/12/08 09:30:08 cs Exp $
+# $Id: FollowUp.pm,v 1.54 2007/04/13 00:18:17 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 use Kernel::System::User;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.48 $';
+$VERSION = '$Revision: 1.54 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub new {
@@ -64,6 +64,7 @@ sub Run {
     # Check if owner of ticket is still valid
     my %UserInfo = $Self->{UserObject}->GetUserData(
         UserID => $Ticket{OwnerID},
+        VacationCheck => 1,
     );
     # check data
     if ($UserInfo{ValidID} eq 1) {
@@ -97,6 +98,9 @@ sub Run {
     }
     # set state
     my $State = $Self->{ConfigObject}->Get('PostmasterFollowUpState') || 'open';
+    if ($Ticket{StateType} =~ /^close/ && $Self->{ConfigObject}->Get('PostmasterFollowUpStateClosed')) {
+        $State = $Self->{ConfigObject}->Get('PostmasterFollowUpStateClosed');
+    }
     if ($GetParam{'X-OTRS-FollowUp-State'}) {
         $State = $GetParam{'X-OTRS-FollowUp-State'};
     }
@@ -111,6 +115,19 @@ sub Run {
             print "State: $State\n";
         }
     }
+    # set pending time
+    if ($GetParam{'X-OTRS-FollowUp-State-PendingTime'}) {
+        if ($Self->{TicketObject}->TicketPendingTimeSet(
+            String => $GetParam{'X-OTRS-FollowUp-State-PendingTime'},
+            TicketID => $Param{TicketID},
+            UserID => $Param{InmailUserID},
+        )) {
+            # debug
+            if ($Self->{Debug} > 0) {
+                print "State-PendingTime: $GetParam{'X-OTRS-FollowUp-State-PendingTime'}\n";
+            }
+        }
+    }
     # set priority
     if ($GetParam{'X-OTRS-FollowUp-Priority'}) {
         $Self->{TicketObject}->PrioritySet(
@@ -133,6 +150,50 @@ sub Run {
             print "QueueUpdate: $GetParam{'X-OTRS-FollowUp-Queue'}\n";
         }
     }
+    # set lock
+    if ($GetParam{'X-OTRS-FollowUp-Lock'}) {
+        $Self->{TicketObject}->LockSet(
+            Lock => $GetParam{'X-OTRS-FollowUp-Lock'},
+            TicketID => $Param{TicketID},
+            UserID => $Param{InmailUserID},
+        );
+        if ($Self->{Debug} > 0) {
+            print "Lock: $GetParam{'X-OTRS-FollowUp-Lock'}\n";
+        }
+    }
+    # set ticket type
+    if ($GetParam{'X-OTRS-FollowUp-Type'}) {
+        $Self->{TicketObject}->TicketTypeSet(
+            Type => $GetParam{'X-OTRS-FollowUp-Type'},
+            TicketID => $Param{TicketID},
+            UserID => $Param{InmailUserID},
+        );
+        if ($Self->{Debug} > 0) {
+            print "Type: $GetParam{'X-OTRS-FollowUp-Type'}\n";
+        }
+    }
+    # set ticket service
+    if ($GetParam{'X-OTRS-FollowUp-Service'}) {
+        $Self->{TicketObject}->TicketServiceSet(
+            Service => $GetParam{'X-OTRS-FollowUp-Service'},
+            TicketID => $Param{TicketID},
+            UserID => $Param{InmailUserID},
+        );
+        if ($Self->{Debug} > 0) {
+            print "Service: $GetParam{'X-OTRS-FollowUp-Service'}\n";
+        }
+    }
+    # set ticket sla
+    if ($GetParam{'X-OTRS-FollowUp-SLA'}) {
+        $Self->{TicketObject}->TicketSLASet(
+            SLA => $GetParam{'X-OTRS-FollowUp-SLA'},
+            TicketID => $Param{TicketID},
+            UserID => $Param{InmailUserID},
+        );
+        if ($Self->{Debug} > 0) {
+            print "SLA: $GetParam{'X-OTRS-FollowUp-SLA'}\n";
+        }
+    }
     # set free ticket text
     my @Values = ('X-OTRS-FollowUp-TicketKey', 'X-OTRS-FollowUp-TicketValue');
     my $CounterTmp = 0;
@@ -168,7 +229,6 @@ sub Run {
         UserID => $Param{InmailUserID},
         HistoryType => 'FollowUp',
         HistoryComment => "\%\%$Param{Tn}\%\%$Comment",
-
         AutoResponseType => $AutoResponseType,
         OrigHeader => \%GetParam,
     );
@@ -230,7 +290,7 @@ sub Run {
     $Self->{LogObject}->Log(
         Priority => 'notice',
         Message => "FollowUp Article to Ticket [$Param{Tn}] created ".
-          "(TicketID=$Param{TicketID}, ArticleID=$ArticleID). $Comment,"
+            "(TicketID=$Param{TicketID}, ArticleID=$ArticleID). $Comment,"
     );
 
     return 1;
