@@ -1,8 +1,8 @@
 # --
 # Kernel/System/State.pm - All state related function should be here eventually
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: State.pm,v 1.15 2006/10/19 14:00:32 rk Exp $
+# $Id: State.pm,v 1.20 2007/03/21 11:15:29 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,9 +12,10 @@
 package Kernel::System::State;
 
 use strict;
+use Kernel::System::Valid;
 
 use vars qw(@ISA $VERSION);
-$VERSION = '$Revision: 1.15 $';
+$VERSION = '$Revision: 1.20 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -42,10 +43,10 @@ create a object
     use Kernel::System::State;
 
     my $ConfigObject = Kernel::Config->new();
-    my $TimeObject    = Kernel::System::Time->new(
+    my $TimeObject = Kernel::System::Time->new(
         ConfigObject => $ConfigObject,
     );
-    my $LogObject    = Kernel::System::Log->new(
+    my $LogObject = Kernel::System::Log->new(
         ConfigObject => $ConfigObject,
     );
     my $DBObject = Kernel::System::DB->new(
@@ -71,6 +72,8 @@ sub new {
     foreach (qw(DBObject ConfigObject LogObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
+    $Self->{ValidObject} = Kernel::System::Valid->new(%Param);
+
     # check needed config options
     foreach (qw(Ticket::ViewableStateType Ticket::UnlockStateType)) {
         $Self->{ConfigObject}->Get($_) || die "Need $_ in Kernel/Config.pm!\n";
@@ -83,13 +86,13 @@ sub new {
 
 add new states
 
-  my $ID = $StateObject->StateAdd(
-      Name => 'New State',
-      Comment => 'some comment',
-      ValidID => 1,
-      TypeID => 1,
-      UserID => 123,
-  );
+    my $ID = $StateObject->StateAdd(
+        Name => 'New State',
+        Comment => 'some comment',
+        ValidID => 1,
+        TypeID => 1,
+        UserID => 123,
+    );
 
 =cut
 
@@ -98,10 +101,10 @@ sub StateAdd {
     my %Param = @_;
     # check needed stuff
     foreach (qw(Name ValidID TypeID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # quote params
     foreach (qw(Name Comment)) {
@@ -135,15 +138,15 @@ sub StateAdd {
 
 get states attributes
 
-  my %State = $StateObject->StateGet(
-      Name => 'New State',
-      Cache => 1, # optional
-  );
+    my %State = $StateObject->StateGet(
+        Name => 'New State',
+        Cache => 1, # optional
+    );
 
-  my %State = $StateObject->StateGet(
-      ID => 123,
-      Cache => 1, # optional
-  );
+    my %State = $StateObject->StateGet(
+        ID => 123,
+        Cache => 1, # optional
+    );
 
 =cut
 
@@ -165,7 +168,8 @@ sub StateGet {
         }
     }
     # sql
-    my $SQL = "SELECT ts.id, ts.name, ts.valid_id, ts.comments, ts.type_id, tst.name ".
+    my $SQL = "SELECT ts.id, ts.name, ts.valid_id, ts.comments, ts.type_id, tst.name, ".
+        " ts.change_time, ts.create_time ".
         " FROM ".
         " ticket_state ts, ticket_state_type tst ".
         " WHERE ".
@@ -187,6 +191,8 @@ sub StateGet {
                 ValidID => $Data[2],
                 TypeID => $Data[4],
                 TypeName => $Data[5],
+                ChangeTime => $Data[6],
+                CreateTime => $Data[7],
             );
         }
         # cache data
@@ -215,14 +221,14 @@ sub StateGet {
 
 update state attributes
 
-  $StateObject->StateUpdate(
-      ID => 123,
-      Name => 'New State',
-      Comment => 'some comment',
-      ValidID => 1,
-      TypeID => 1,
-      UserID => 123,
-  );
+    $StateObject->StateUpdate(
+        ID => 123,
+        Name => 'New State',
+        Comment => 'some comment',
+        ValidID => 1,
+        TypeID => 1,
+        UserID => 123,
+    );
 
 =cut
 
@@ -231,10 +237,10 @@ sub StateUpdate {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ID Name ValidID TypeID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # quote params
     foreach (qw(Name Comment)) {
@@ -245,10 +251,10 @@ sub StateUpdate {
     }
     # sql
     my $SQL = "UPDATE ticket_state SET name = '$Param{Name}', " .
-          " comments = '$Param{Comment}', " .
-          " type_id = $Param{TypeID}, valid_id = $Param{ValidID}, " .
-          " change_time = current_timestamp, change_by = $Param{UserID} " .
-          " WHERE id = $Param{ID}";
+        " comments = '$Param{Comment}', " .
+        " type_id = $Param{TypeID}, valid_id = $Param{ValidID}, " .
+        " change_time = current_timestamp, change_by = $Param{UserID} " .
+        " WHERE id = $Param{ID}";
     if ($Self->{DBObject}->Do(SQL => $SQL)) {
         return 1;
     }
@@ -261,23 +267,23 @@ sub StateUpdate {
 
 get list of state types
 
-  get all states with state type open and new
-  (available: new, open, closed, pending reminder, pending auto,
-  removed, merged)
+    get all states with state type open and new
+    (available: new, open, closed, pending reminder, pending auto,
+    removed, merged)
 
-  my @List = $StateObject->StateGetStatesByType(
-      StateType => ['open', 'new'],
-      Result => 'ID', # HASH|ID|Name
-  );
+    my @List = $StateObject->StateGetStatesByType(
+        StateType => ['open', 'new'],
+        Result => 'ID', # HASH|ID|Name
+    );
 
-  get all state types used by config option named like
+    get all state types used by config option named like
 
-  Ticket::ViewableStateType for "Viewable" state types
+    Ticket::ViewableStateType for "Viewable" state types
 
-  my %List = $StateObject->StateGetStatesByType(
-      Type => 'Viewable',
-      Result => 'HASH', # HASH|ID|Name
-  );
+    my %List = $StateObject->StateGetStatesByType(
+        Type => 'Viewable',
+        Result => 'HASH', # HASH|ID|Name
+    );
 
 =cut
 
@@ -289,10 +295,10 @@ sub StateGetStatesByType {
     my %Data = ();
     # check needed stuff
     foreach (qw(Result)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     if (!$Param{Type} && !$Param{StateType}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "Need Type or StateType!");
@@ -310,7 +316,7 @@ sub StateGetStatesByType {
                 Message => "Type 'Ticket::$Param{Type}StateType' not found in Kernel/Config.pm!",
             );
             die;
-       }
+        }
     }
     else {
         @StateType = @{$Param{StateType}};
@@ -323,7 +329,7 @@ sub StateGetStatesByType {
         " AND ".
         " tst.name IN ('${\(join '\', \'', @StateType)}' )".
         " AND ".
-        " ts.valid_id IN ( ${\(join ', ', $Self->{DBObject}->GetValidIDs())} )";
+        " ts.valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
     if ($Self->{DBObject}->Prepare(SQL => $SQL)) {
         while (my @Data = $Self->{DBObject}->FetchrowArray()) {
             push (@Name, $Data[1]);
@@ -346,26 +352,42 @@ sub StateGetStatesByType {
 
 get state list
 
-  my %List = $StateObject->StateList(
-      UserID => 123,
-  );
+    my %List = $StateObject->StateList(
+        UserID => 123,
+    );
+
+    my %List = $StateObject->StateList(
+        UserID => 123,
+        Valid => 1, # is default
+    );
+
+    my %List = $StateObject->StateList(
+        UserID => 123,
+        Valid => 0,
+    );
 
 =cut
 
 sub StateList {
     my $Self = shift;
     my %Param = @_;
+    my $Valid = 1;
     # check needed stuff
     if (!$Param{UserID}) {
         $Self->{LogObject}->Log(Priority => 'error', Message => "UserID!");
         return;
     }
+    if (!$Param{Valid} && defined($Param{Valid})) {
+        $Valid = 0;
+    }
     # sql
     my $SQL = "SELECT id, name ".
         " FROM ".
-        " ticket_state ".
-        " WHERE ".
-        " valid_id IN ( ${\(join ', ', $Self->{DBObject}->GetValidIDs())} )";
+        " ticket_state";
+    if ($Valid) {
+        $SQL .= " WHERE ".
+            " valid_id IN ( ${\(join ', ', $Self->{ValidObject}->ValidIDsGet())} )";
+    }
     my %Data = ();
     if ($Self->{DBObject}->Prepare(SQL => $SQL)) {
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
@@ -377,8 +399,45 @@ sub StateList {
         return;
     }
 }
+
+=item StateTypeList()
+
+get state type list
+
+    my %ListType = $StateObject->StateTypeList(
+        UserID => 123,
+    );
+
+=cut
+
+sub StateTypeList {
+    my $Self = shift;
+    my %Param = @_;
+    # check needed stuff
+    if (!$Param{UserID}) {
+        $Self->{LogObject}->Log(Priority => 'error', Message => "UserID!");
+        return;
+    }
+    # sql
+    my $SQL = "SELECT id, name ".
+        " FROM ".
+        " ticket_state_type";
+    my %Data = ();
+    if ($Self->{DBObject}->Prepare(SQL => $SQL)) {
+        while (my @Row = $Self->{DBObject}->FetchrowArray()) {
+            $Data{$Row[0]} = $Row[1];
+        }
+        return %Data;
+    }
+    else {
+        return;
+    }
+}
+
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This Software is part of the OTRS project (http://otrs.org/).
@@ -391,6 +450,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.15 $ $Date: 2006/10/19 14:00:32 $
+$Revision: 1.20 $ $Date: 2007/03/21 11:15:29 $
 
 =cut
