@@ -2,7 +2,7 @@
 # Kernel/System/Ticket/ArticleStorageDB.pm - article storage module for OTRS kernel
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: ArticleStorageDB.pm,v 1.37.2.2 2007/04/05 14:31:09 martin Exp $
+# $Id: ArticleStorageDB.pm,v 1.45 2007/07/23 09:35:09 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -12,11 +12,12 @@
 package Kernel::System::Ticket::ArticleStorageDB;
 
 use strict;
+use warnings;
 use MIME::Base64;
 use MIME::Words qw(:all);
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.37.2.2 $';
+$VERSION = '$Revision: 1.45 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub ArticleStorageInit {
@@ -24,7 +25,7 @@ sub ArticleStorageInit {
     my %Param = @_;
     # ArticleDataDir
     $Self->{ArticleDataDir} = $Self->{ConfigObject}->Get('ArticleDir')
-       || die "Got no ArticleDir!";
+        || die "Got no ArticleDir!";
     # create ArticleContentPath
     my ($Sec, $Min, $Hour, $Day, $Month, $Year) = $Self->{TimeObject}->SystemTime2Date(
         SystemTime => $Self->{TimeObject}->SystemTime(),
@@ -39,10 +40,10 @@ sub ArticleDelete {
     my %Param = @_;
     # check needed stuff
     foreach (qw(TicketID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # delete attachments and plain emails
     my @Articles = $Self->ArticleIndex(TicketID => $Param{TicketID});
@@ -117,10 +118,10 @@ sub ArticleDeletePlain {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # db quote
     foreach (qw(ArticleID)) {
@@ -148,10 +149,10 @@ sub ArticleDeleteAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # db quote
     foreach (qw(ArticleID)) {
@@ -165,12 +166,11 @@ sub ArticleDeleteAttachment {
     if (-e $Path) {
         my @List = glob($Path);
         foreach my $File (@List) {
-            $File =~ s!^.*/!!;
-            if ($File !~ /^plain.txt$/) {
-                if (!unlink "$Path/$File") {
+            if ($File !~ /(\/|\\)plain.txt$/) {
+                if (!unlink $File) {
                     $Self->{LogObject}->Log(
                         Priority => 'error',
-                        Message => "Can't remove: $Path/$File: $!!",
+                        Message => "Can't remove: $File: $!!",
                     );
                 }
             }
@@ -184,10 +184,10 @@ sub ArticleWritePlain {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID Email UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # encode attachemnt if it's a postgresql backend!!!
     if (!$Self->{DBObject}->GetDatabaseFunction('DirectBlob')) {
@@ -217,10 +217,10 @@ sub ArticleWriteAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(Content Filename ContentType ArticleID UserID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     my $NewFileName = $Param{Filename};
     my %UsedFile = ();
@@ -231,10 +231,10 @@ sub ArticleWriteAttachment {
     for (my $i=1; $i<=12; $i++) {
         if (exists $UsedFile{$NewFileName}) {
             if ($Param{Filename} =~ /^(.*)\.(.+?)$/) {
-               $NewFileName = "$1-$i.$2";
+                $NewFileName = "$1-$i.$2";
             }
             else {
-               $NewFileName = "$Param{Filename}-$i";
+                $NewFileName = "$Param{Filename}-$i";
             }
         }
     }
@@ -252,8 +252,8 @@ sub ArticleWriteAttachment {
         $Param{Content} = encode_base64($Param{Content});
     }
     # db quote (just not Content, use db Bind values)
-    foreach (keys %Param) {
-        $Param{$_} = $Self->{DBObject}->Quote($Param{$_}) if ($_ ne 'Content');
+    foreach (qw(Filename ContentType Filesize)) {
+        $Param{$_} = $Self->{DBObject}->Quote($Param{$_});
     }
     foreach (qw(ArticleID UserID)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
@@ -278,8 +278,8 @@ sub ArticlePlain {
     my %Param = @_;
     # check needed stuff
     if (!$Param{ArticleID}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
+        return;
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -295,8 +295,8 @@ sub ArticlePlain {
             $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
         }
         my $SQL = "SELECT body FROM article_plain ".
-          " WHERE ".
-          " article_id = $Param{ArticleID}";
+            " WHERE ".
+            " article_id = $Param{ArticleID}";
         $Self->{DBObject}->Prepare(SQL => $SQL);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             # decode attachemnt if it's e. g. a postgresql backend!!!
@@ -341,8 +341,8 @@ sub ArticleAttachmentIndex {
     }
     # check needed stuff
     if (!$Param{ArticleID}) {
-      $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
-      return;
+        $Self->{LogObject}->Log(Priority => 'error', Message => "Need ArticleID!");
+        return;
     }
     # get ContentPath if not given
     if (!$Param{ContentPath}) {
@@ -405,16 +405,34 @@ sub ArticleAttachmentIndex {
             }
             # read content type
             my $ContentType = '';
-            if (open(IN, "< $Filename")) {
-                while (<IN>) {
-                    if ($ContentType) {
-                        last;
-                    }
-                    else {
-                        $ContentType = $_;
+            if (-e "$Filename.content_type") {
+                if (open(DATA, "$Filename.content_type")) {
+                    while (<DATA>) {
+                        $ContentType .= $_;
                     }
+                    close(DATA);
+                }
+                else {
+                    $Self->{LogObject}->Log(
+                        Priority => 'error',
+                        Message => "$!: $Filename.content_type!",
+                    );
+                    return;
+                }
+            }
+            # read content type (old style)
+            else {
+                if (open(IN, "< $Filename")) {
+                    while (<IN>) {
+                        if ($ContentType) {
+                            last;
+                        }
+                        else {
+                            $ContentType = $_;
+                        }
+                    }
+                    close(IN);
                 }
-                close(IN);
             }
             # strip filename
             $Filename =~ s!^.*/!!;
@@ -437,10 +455,10 @@ sub ArticleAttachment {
     my %Param = @_;
     # check needed stuff
     foreach (qw(ArticleID FileID)) {
-      if (!$Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
-        return;
-      }
+        if (!$Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_!");
+            return;
+        }
     }
     # prepare/filter ArticleID
     $Param{ArticleID} = quotemeta($Param{ArticleID});
@@ -451,20 +469,74 @@ sub ArticleAttachment {
     my $ContentPath = $Self->ArticleGetContentPath(ArticleID => $Param{ArticleID});
     my %Data = %{$Index{$Param{FileID}}};
 
-    if (open (DATA, "< $Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/$Data{Filename}")) {
-        my $Counter = 0;
-        binmode(DATA);
-        while (<DATA>) {
-            $Data{ContentType} = $_ if ($Counter == 0);
-            $Data{Content} .= $_ if ($Counter > 0);
-            $Counter++;
+    my $Counter = 0;
+    my @List = glob("$Self->{ArticleDataDir}/$ContentPath/$Param{ArticleID}/*");
+    if (@List) {
+        foreach my $Filename (@List) {
+            if ($Filename !~ /\/plain.txt$/ && $Filename !~ /\.content_type$/) {
+                # add the info the the hash
+                $Counter++;
+                if ($Counter == $Param{FileID}) {
+                    # convert the file name in utf-8 if utf-8 is used
+                    $Filename = $Self->{EncodeObject}->Decode(
+                        Text => $Filename,
+                        From => 'utf-8',
+                    );
+                    if (-e "$Filename.content_type") {
+                        if (open(DATA, "$Filename.content_type")) {
+                            while (<DATA>) {
+                                $Data{ContentType} = $_;
+                            }
+                            close(DATA);
+                            if (open(DATA, $Filename)) {
+                                my $Counter = 0;
+                                binmode(DATA);
+                                while (<DATA>) {
+                                    $Data{Content} .= $_;
+                                }
+                                close(DATA);
+                            }
+                            else {
+                                $Self->{LogObject}->Log(
+                                    Priority => 'error',
+                                    Message => "$!: $Filename!",
+                                );
+                                return;
+
+                            }
+                        }
+                        else {
+                            $Self->{LogObject}->Log(
+                                Priority => 'error',
+                                Message => "$!: $Filename.content_type!",
+                            );
+                            return;
+                        }
+                    }
+                    else {
+                        if (open(DATA, $Filename)) {
+                            my $Counter = 0;
+                            binmode(DATA);
+                            while (<DATA>) {
+                                if ($Counter == 0) {
+                                    $Data{ContentType} = $_;
+                                }
+                                else {
+                                    $Data{Content} .= $_;
+                                }
+                                $Counter++;
+                            }
+                            close(DATA);
+                        }
+                    }
+                    if ($Data{ContentType} =~ /plain\/text/i && $Data{ContentType} =~ /(utf\-8|utf8)/i) {
+                        $Self->{EncodeObject}->Encode(\$Data{Content});
+                    }
+                    chomp ($Data{ContentType});
+                    return %Data;
+                }
+            }
         }
-        close (DATA);
-        if ($Data{ContentType} =~ /(utf\-8|utf8)/i) {
-            $Self->{EncodeObject}->Encode(\$Data{Content});
-        }
-        chomp ($Data{ContentType});
-        return %Data;
     }
     else {
         # try database
@@ -474,13 +546,12 @@ sub ArticleAttachment {
         my $SQL = "SELECT content_type, content FROM article_attachment ".
             " WHERE ".
             " article_id = $Param{ArticleID} ORDER BY id";
-        $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{FileID});
+        $Self->{DBObject}->Prepare(SQL => $SQL, Limit => $Param{FileID}, Encode => [1,0]);
         while (my @Row = $Self->{DBObject}->FetchrowArray()) {
             $Data{ContentType} = $Row[0];
             # decode attachemnt if it's e. g. a postgresql backend!!!
             if (!$Self->{DBObject}->GetDatabaseFunction('DirectBlob')) {
                 $Data{Content} = decode_base64($Row[1]);
-                $Self->{EncodeObject}->Encode(\$Data{Content});
             }
             else {
                 $Data{Content} = $Row[1];
