@@ -1,9 +1,9 @@
 # --
 # Kernel/System/Ticket/IndexAccelerator/RuntimeDB.pm - realtime database
 # queue ticket index module
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS GmbH, http://otrs.org/
 # --
-# $Id: RuntimeDB.pm,v 1.43 2007/07/30 09:52:37 martin Exp $
+# $Id: RuntimeDB.pm,v 1.45.2.1 2008/01/12 14:01:52 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,9 +13,10 @@
 package Kernel::System::Ticket::IndexAccelerator::RuntimeDB;
 
 use strict;
+use warnings;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.43 $';
+$VERSION = '$Revision: 1.45.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub TicketAcceleratorUpdate {
@@ -184,70 +185,108 @@ sub GetLockedCount {
             return;
         }
     }
+    # check cache
+    if ($Self->{'Cache::GetLockCount'.$Param{UserID}}) {
+        return %{$Self->{'Cache::GetLockCount'.$Param{UserID}}};
+    }
     # db quote
     foreach (qw(UserID)) {
         $Param{$_} = $Self->{DBObject}->Quote($Param{$_}, 'Integer');
     }
+
     # db query
-    $Self->{DBObject}->Prepare(
-        SQL => "SELECT ar.id as ca, st.name, ti.id, ar.create_by, ti.create_time_unix, ".
-            " ti.until_time, ts.name, tst.name " .
-            " FROM " .
-            " ticket ti, article ar, article_sender_type st, " .
-            " ticket_state ts, ticket_state_type tst " .
-            " WHERE " .
-            " ti.ticket_lock_id not IN ( ${\(join ', ', @{$Self->{ViewableLockIDs}})} ) " .
-            " AND " .
-            " ti.user_id = $Param{UserID} " .
-            " AND " .
-            " ar.ticket_id = ti.id " .
-            " AND " .
-            " st.id = ar.article_sender_type_id " .
-            " AND " .
-            " ts.id = ti.ticket_state_id " .
-            " AND " .
-            " ts.type_id = tst.id " .
-            " ORDER BY ar.create_time DESC",
-    );
+    $Self->{DBObject}
+        ->Prepare( SQL => "SELECT ar.id, ar.article_sender_type_id, ti.id, "
+            . " ar.create_by, ti.create_time_unix, ti.until_time, "
+            . " tst.name, ar.article_type_id "
+            . " FROM "
+            . " ticket ti, article ar, "
+            . " ticket_state ts, ticket_state_type tst "
+            . " WHERE "
+            . " ti.ticket_lock_id NOT IN ( ${\(join ', ', @{$Self->{ViewableLockIDs}})} ) "
+            . " AND "
+            . " ti.user_id = $Param{UserID} AND "
+            . " ar.ticket_id = ti.id AND "
+            . " ts.id = ti.ticket_state_id AND "
+            . " ts.type_id = tst.id "
+            . " ORDER BY ar.create_time DESC" );
+    my @ArticleLocked = ();
+    while ( my @Row = $Self->{DBObject}->FetchrowArray() ) {
+        push (@ArticleLocked, \@Row);
+    }
+
     my %TicketIDs = ();
-    my %Data = ();
-    $Data{'Reminder'} = 0;
-    $Data{'Pending'} = 0;
-    $Data{'All'} = 0;
-    $Data{'New'} = 0;
-    while (my @Row = $Self->{DBObject}->FetchrowArray()) {
-        if (!$Param{"ID$Row[2]"}) {
-            $Data{'All'}++;
-            # put all tickets to ToDo where last sender type is customer / system or ! UserID
-            if ($Row[3] ne $Param{UserID} || $Row[1] eq 'customer' || $Row[1] eq 'system') {
-                $Data{'New'}++;
+    my %Data      = (
+        Reminder => 0,
+        Pending => 0,
+        All => 0,
+        New => 0,
+    );
+
+    # find only new messages
+    # put all tickets to ToDo where last sender type is customer / system or ! UserID
+    # and article type is not a email-notification
+    foreach my $Article (@ArticleLocked) {
+        my $SenderType = $Self->ArticleSenderTypeLookup( SenderTypeID => $Article->[1]);
+        my $ArticleType = $Self->ArticleTypeLookup( ArticleTypeID => $Article->[7]);
+        if ( ! $TicketIDs{ $Article->[2] } ) {
+            if ( $SenderType eq 'system' &&  $ArticleType =~ /^email-extern/i ) {
+                next;
             }
-            if ($Row[5] && $Row[7] =~ /^pending/i) {
+            if ( ( $Article->[3] ne $Param{UserID}
+                || $SenderType eq 'customer' )
+                && $ArticleType !~ /^email-notification/i ) {
+                $Data{'New'}++;
+                $Data{'NewTicketIDs'}->{$Article->[2]} = 1;
+            }
+
+        }
+        $TicketIDs{ $Article->[2] } = 1;
+    }
+
+    # find all and reminder tickets
+    %TicketIDs = ();
+    foreach my $Article (@ArticleLocked) {
+        my $SenderType = $Self->ArticleSenderTypeLookup( SenderTypeID => $Article->[1]);
+        my $ArticleType = $Self->ArticleTypeLookup( ArticleTypeID => $Article->[7]);
+        if ( ! $TicketIDs{ $Article->[2] } ) {
+            $Data{'All'}++;
+
+            if ( $Article->[5] && $Article->[6] =~ /^pending/i ) {
                 $Data{'Pending'}++;
-                if ($Row[7] !~ /^pending auto/i && $Row[5] <= $Self->{TimeObject}->SystemTime()) {
+                $Data{'PendingTicketIDs'}->{$Article->[2]} = 1;
+                if ( $Article->[6] !~ /^pending auto/i && $Article->[5] <= $Self->{TimeObject}->SystemTime() ) {
+                    $Data{'ReminderTicketIDs'}->{$Article->[2]} = 1;
                     $Data{'Reminder'}++;
                 }
             }
         }
-        $Param{"ID$Row[2]"} = 1;
-        $Data{"MaxAge"} = $Row[4];
-        $TicketIDs{$Row[2]} = 1;
+        $Data{"MaxAge"}             = $Article->[4];
+        $TicketIDs{ $Article->[2] } = 1;
     }
+
     # show just unseen tickets as new
-    if ($Self->{ConfigObject}->Get('Ticket::NewMessageMode') eq 'ArticleSeen') {
+    if ( $Self->{ConfigObject}->Get('Ticket::NewMessageMode') eq 'ArticleSeen' ) {
+
         # reset new message count
         $Data{'New'} = 0;
-        foreach my $TicketID (keys %TicketIDs) {
-            my @Index = $Self->ArticleIndex(TicketID => $TicketID);
+        $Data{'NewTicketIDs'} = undef;
+        for my $TicketID ( keys %TicketIDs ) {
+            my @Index = $Self->ArticleIndex( TicketID => $TicketID );
             my %Flag = $Self->ArticleFlagGet(
-                ArticleID => $Index[$#Index],
-                UserID => $Param{UserID},
+                ArticleID => $Index[-1],
+                UserID    => $Param{UserID},
             );
-            if (!$Flag{seen}) {
+            if ( !$Flag{seen} ) {
+                $Data{'NewTicketIDs'}->{$TicketID} = 1;
                 $Data{'New'}++;
             }
         }
     }
+
+    # cache result
+    $Self->{ 'Cache::GetLockCount' . $Param{UserID} } = \%Data;
+
     return %Data;
 }
 
@@ -261,16 +300,14 @@ sub GetOverTimeTickets {
         Type => 'Viewable',
         Result => 'ID',
     );
-    my @ViewableLockIDs = $Self->{LockObject}->LockViewableLock(Type => 'ID');
     my $SQL = "SELECT st.id, st.tn, st.escalation_start_time, st.escalation_response_time, st.escalation_solution_time, ".
         "st.ticket_state_id, st.service_id, st.sla_id, st.create_time, st.queue_id, st.ticket_lock_id ".
         " FROM ".
-        " queue q, ticket st ".
+        " ticket st, queue q ".
         " WHERE ".
-        " st.ticket_state_id IN ( ${\(join ', ', @ViewableStateIDs)} ) " .
+        " st.queue_id = q.id ".
         " AND " .
-        " q.id = st.queue_id ".
-        " AND ";
+        " st.ticket_state_id IN ( ${\(join ', ', @ViewableStateIDs)} ) ";
     if ($Self->{UserID} && $Self->{UserID} ne 1) {
         my @GroupIDs = $Self->{GroupObject}->GroupMemberList(
             UserID => $Self->{UserID},
@@ -278,13 +315,12 @@ sub GetOverTimeTickets {
             Result => 'ID',
             Cached => 1,
         );
-        $SQL .= " q.group_id IN ( ${\(join ', ', @GroupIDs)} ) AND ";
+        $SQL .= " AND q.group_id IN ( ${\(join ', ', @GroupIDs)} )";
         # check if user is in min. one group! if not, return here
         if (!@GroupIDs) {
             return;
         }
     }
-    $SQL .= " st.ticket_lock_id IN ( ${\(join ', ', @ViewableLockIDs)} ) ";
     $SQL .= " ORDER BY st.escalation_start_time ASC";
     $Self->{DBObject}->Prepare(SQL => $SQL, Limit => 5000);
     while (my @Row = $Self->{DBObject}->FetchrowArray()) {
