@@ -1,12 +1,12 @@
 # --
 # Ticket/Number/Date.pm - a date ticket number generator
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: Date.pm,v 1.20 2007/04/12 23:51:04 martin Exp $
+# $Id: Date.pm,v 1.20.2.3 2008/04/23 20:29:29 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
-# did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+# did not receive this file, see http://www.gnu.org/licenses/gpl-2.0.txt.
 # --
 # Note:
 # available objects are: ConfigObject, LogObject and DBObject
@@ -19,7 +19,7 @@ package Kernel::System::Ticket::Number::Date;
 use strict;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.20 $';
+$VERSION = '$Revision: 1.20.2.3 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 sub TicketCreateNumber {
@@ -37,7 +37,9 @@ sub TicketCreateNumber {
     if (-f $CounterLog) {
         open (DATA, "< $CounterLog") || die "Can't open $CounterLog: $!";
         my $Line = <DATA>;
-        ($Count) = split(/;/, $Line);
+        if ( $Line ) {
+            ($Count) = split(/;/, $Line);
+        }
         close (DATA);
         # just debug
         if ($Self->{Debug} > 0) {
@@ -74,7 +76,7 @@ sub TicketCreateNumber {
     # Check ticket number. If exists generate new one!
     if ($Self->TicketCheckNumber(Tn=>$Tn)) {
         $Self->{LoopProtectionCounter}++;
-        if ($Self->{LoopProtectionCounter} >= 6000) {
+        if ($Self->{LoopProtectionCounter} >= 16000) {
             # loop protection
             $Self->{LogObject}->Log(
                 Priority => 'error',
@@ -110,7 +112,7 @@ sub GetTNByString {
     }
     else {
         # check default setting
-        if ($String =~ /\Q$TicketHook\E:+.{0,2}(\d{4,10}$SystemID\d{1,40})/i) {
+        if ($String =~ /\Q$TicketHook\E:\s{0,2}(\d{4,10}$SystemID\d{1,40})/i) {
             return $1;
         }
         else {
