@@ -1,8 +1,8 @@
 # --
 # Kernel/System/Web/InterfaceCustomer.pm - the customer interface file (incl. auth)
-# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS GmbH, http://otrs.org/
 # --
-# $Id: InterfaceCustomer.pm,v 1.16.2.1 2007/01/04 14:54:11 martin Exp $
+# $Id: InterfaceCustomer.pm,v 1.20.2.1 2008/01/14 12:15:07 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -14,7 +14,7 @@ package Kernel::System::Web::InterfaceCustomer;
 use strict;
 
 use vars qw($VERSION @INC);
-$VERSION = '$Revision: 1.16.2.1 $';
+$VERSION = '$Revision: 1.20.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 # all framework needed modules
@@ -49,10 +49,10 @@ the global customer web interface (incl. auth, session, ...)
 
 create customer web interface object
 
-  use Kernel::System::Web::InterfaceCustomer;
+    use Kernel::System::Web::InterfaceCustomer;
 
-  my $Self->{Debug} = 0;
-  my $InterfaceCustomer = Kernel::System::Web::InterfaceCustomer->new(Debug => $Self->{Debug});
+    my $Debug = 0;
+    my $InterfaceCustomer = Kernel::System::Web::InterfaceCustomer->new(Debug => $Debug);
 
 =cut
 
@@ -98,7 +98,7 @@ sub new {
 
 execute the object
 
-  $InterfaceCustomer->Run();
+    $InterfaceCustomer->Run();
 
 =cut
 
@@ -122,16 +122,16 @@ sub Run {
     };
     foreach my $Key (keys %{$FramworkPrams}) {
         $Param{$Key} = $Self->{ParamObject}->GetParam(Param => $Key)
-          || $FramworkPrams->{$Key};
+            || $FramworkPrams->{$Key};
     }
 
     # Check if the brwoser sends the SessionID cookie and set the SessionID-cookie
     # as SessionID! GET or POST SessionID have the lowest priority.
     if ($Self->{ConfigObject}->Get('SessionUseCookie')) {
-      $Param{SessionIDCookie} = $Self->{ParamObject}->GetCookie(Key => $Param{SessionName});
-      if ($Param{SessionIDCookie}) {
-        $Param{SessionID} = $Param{SessionIDCookie};
-      }
+        $Param{SessionIDCookie} = $Self->{ParamObject}->GetCookie(Key => $Param{SessionName});
+        if ($Param{SessionIDCookie}) {
+            $Param{SessionID} = $Param{SessionIDCookie};
+        }
     }
 
     # create common framework objects 2/3
@@ -143,21 +143,15 @@ sub Run {
     # check common objects
     $Self->{DBObject} = Kernel::System::DB->new(%{$Self});
     if (!$Self->{DBObject}) {
-        print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->CustomerError(
+        $Self->{LayoutObject}->CustomerFatalError(
             Comment => 'Please contact your admin'
         );
-        print $Self->{LayoutObject}->CustomerFooter();
-        exit (1);
     }
     if ($Self->{ParamObject}->Error()) {
-        print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->CustomerError(
+        $Self->{LayoutObject}->CustomerFatalError(
             Message => $Self->{ParamObject}->Error(),
             Comment => 'Please contact your admin'
         );
-        print $Self->{LayoutObject}->CustomerFooter();
-        exit (1);
     }
 
     # create common framework objects 3/3
@@ -169,14 +163,14 @@ sub Run {
     my %CommonObject = %{$Self->{ConfigObject}->Get('CustomerFrontend::CommonObject')};
     foreach my $Key (keys %CommonObject) {
         if ($Self->{MainObject}->Require($CommonObject{$Key})) {
-            $Self->{$Key} = $CommonObject{$Key}->new(%{$Self});
+            # workaround for bug# 977 - do not use GroupObject in Kernel::System::Ticket
+            $Self->{$Key} = $CommonObject{$Key}->new( %{$Self}, GroupObject => undef );
         }
         else {
             # print error
-            print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
-            print $Self->{LayoutObject}->CustomerError();
-            print $Self->{LayoutObject}->CustomerFooter();
-            exit;
+            $Self->{LayoutObject}->CustomerFatalError(
+                Comment => 'Please contact your admin'
+            );
         }
     }
 
@@ -210,10 +204,12 @@ sub Run {
                 }
                 else {
                     # show login screen
-                    print $Self->{LayoutObject}->CustomerLogin(
-                        Title => 'Panic!',
-                        Message => 'Panic! No UserData!!!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                            Title => 'Panic!',
+                            Message => 'Panic! No UserData!!!',
+                            %Param,
+                        ),
                     );
                     exit (0);
                 }
@@ -288,26 +284,27 @@ sub Run {
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
                     ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
-                      "?Reason=LoginFailed&RequestedURL=$Param{RequestedURL}",
+                        "?Reason=LoginFailed&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show normal login
-                print $Self->{LayoutObject}->CustomerLogin(
-                    Title => 'Login',
-                    Message => $Self->{LogObject}->GetLogEntry(
-                        Type => 'Info',
-                        What => 'Message',
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                        Title => 'Login',
+                        Message => $Self->{LogObject}->GetLogEntry(
+                            Type => 'Info',
+                            What => 'Message',
                         ) || 'Login failed! Your username or password was entered incorrectly.',
-                    User => $PostUser,
-                    %Param,
+                        User => $PostUser,
+                        %Param,
+                    ),
                 );
             }
         }
     }
-
     # Logout
-    elsif ($Param{Action} eq "Logout"){
+    elsif ($Param{Action} eq "Logout") {
         if ($Self->{SessionObject}->CheckSessionID(SessionID => $Param{SessionID})) {
             # get session data
             my %UserData = $Self->{SessionObject}->GetSessionIDData(
@@ -335,24 +332,19 @@ sub Run {
                 }
                 else {
                     # show logout screen
-                    print $Self->{LayoutObject}->CustomerLogin(
-                        Title => 'Logout',
-                        Message => 'Logout successful. Thank you for using OTRS!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                            Title => 'Logout',
+                            Message => 'Logout successful. Thank you for using OTRS!',
+                            %Param,
+                        ),
                     );
                 }
             }
             else {
-                print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Logout');
-                print $Self->{LayoutObject}->CustomerError(
-                    Message => 'Can`t remove SessionID',
-                    Comment => 'Please contact your admin!'
+                $Self->{LayoutObject}->CustomerFatalError(
+                    Comment => 'Please contact your admin'
                 );
-                $Self->{LogObject}->Log(
-                    Message => 'Can`t remove SessionID',
-                    Priority => 'error',
-                );
-                print $Self->{LayoutObject}->CustomerFooter();
             }
         }
         else {
@@ -374,15 +366,16 @@ sub Run {
             }
         }
     }
-
     # CustomerLostPassword
-    elsif ($Param{Action} eq "CustomerLostPassword"){
+    elsif ($Param{Action} eq "CustomerLostPassword") {
         # check feature
         if (! $Self->{ConfigObject}->Get('CustomerPanelLostPassword')) {
             # show normal login
-            print $Self->{LayoutObject}->CustomerLogin(
-                Title => 'Login',
-                Message => 'Feature not active!',
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                    Title => 'Login',
+                    Message => 'Feature not active!',
+                ),
             );
             exit 0;
         }
@@ -391,9 +384,11 @@ sub Run {
         # get user data
         my %UserData = $Self->{UserObject}->CustomerUserDataGet(User => $User);
         if (! $UserData{UserID}) {
-            print $Self->{LayoutObject}->CustomerLogin(
-                Title => 'Login',
-                Message => 'There is no account with that login name.',
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                    Title => 'Login',
+                    Message => 'There is no account with that login name.',
+                ),
             );
         }
         else {
@@ -404,40 +399,44 @@ sub Run {
             # send notify email
             my $EmailObject = Kernel::System::Email->new(%{$Self});
             my $Body = $Self->{ConfigObject}->Get('CustomerPanelBodyLostPassword')
-              || "New Password is: <OTRS_NEWPW>";
+                || "New Password is: <OTRS_NEWPW>";
             my $Subject = $Self->{ConfigObject}->Get('CustomerPanelSubjectLostPassword')
-              || 'New Password!';
+                || 'New Password!';
             foreach (keys %UserData) {
                 $Body =~ s/<OTRS_$_>/$UserData{$_}/gi;
             }
             if ($EmailObject->Send(
-              To => $UserData{UserEmail},
-              Subject => $Subject,
-              Charset => 'iso-8859-15',
-              Type => 'text/plain',
-              Body => $Body)) {
-                print $Self->{LayoutObject}->CustomerLogin(
-                  Title => 'Login',
-                  Message => "Sent new password to: ".$UserData{"UserEmail"},
-                  User => $User,
+                To => $UserData{UserEmail},
+                Subject => $Subject,
+                Charset => 'iso-8859-15',
+                Type => 'text/plain',
+                Body => $Body)
+            ) {
+                $Self->{LayoutObject}->Print(
+                    Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                        Title => 'Login',
+                        Message => "Sent new password to: ".$UserData{"UserEmail"},
+                        User => $User,
+                    ),
                 );
             }
             else {
-                print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
-                print $Self->{LayoutObject}->CustomerError();
-                print $Self->{LayoutObject}->CustomerFooter();
+                $Self->{LayoutObject}->CustomerFatalError(
+                    Comment => 'Please contact your admin'
+                );
             }
         }
     }
-
     # create new customer account
-    elsif ($Param{Action} eq "CustomerCreateAccount"){
+    elsif ($Param{Action} eq "CustomerCreateAccount") {
         # check feature
         if (! $Self->{ConfigObject}->Get('CustomerPanelCreateAccount')) {
             # show normal login
-            print $Self->{LayoutObject}->CustomerLogin(
-                Title => 'Login',
-                Message => 'Feature not active!',
+            $Self->{LayoutObject}->Print(
+                Output =>  \$Self->{LayoutObject}->CustomerLogin(
+                    Title => 'Login',
+                    Message => 'Feature not active!',
+                ),
             );
             exit 0;
         }
@@ -459,12 +458,14 @@ sub Run {
         # get user data
         my %UserData = $Self->{UserObject}->CustomerUserDataGet(User => $GetParams{UserLogin});
         if ($UserData{UserID} || ! $GetParams{UserLogin}) {
-            print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
-            print $Self->{LayoutObject}->CustomerWarning(
+            my $Output = '';
+            $Output .= $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
+            $Output .= $Self->{LayoutObject}->CustomerWarning(
                 Message => 'This account exists.',
                 Comment => 'Please press Back and try again.'
             );
-            print $Self->{LayoutObject}->CustomerFooter();
+            $Output .= $Self->{LayoutObject}->CustomerFooter();
+            $Self->{LayoutObject}->Print(Output =>  \$Output);
         }
         else {
             if ($Self->{UserObject}->CustomerUserAdd(
@@ -479,24 +480,27 @@ sub Run {
                 # send notify email
                 my $EmailObject = Kernel::System::Email->new(%{$Self});
                 my $Body = $Self->{ConfigObject}->Get('CustomerPanelBodyNewAccount')
-                  || "No Config Option found!";
+                    || "No Config Option found!";
                 my $Subject = $Self->{ConfigObject}->Get('CustomerPanelSubjectNewAccount')
-                  || 'New OTRS Account!';
+                    || 'New OTRS Account!';
                 foreach (keys %GetParams) {
                     $Body =~ s/<OTRS_$_>/$GetParams{$_}/gi;
                 }
                 # send account info
                 if (!$EmailObject->Send(
-                  To => $GetParams{UserEmail},
-                  Subject => $Subject,
-                  Charset => 'iso-8859-15',
-                  Type => 'text/plain',
-                  Body => $Body)) {
-                    print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
-                    print $Self->{LayoutObject}->CustomerWarning(
+                    To => $GetParams{UserEmail},
+                    Subject => $Subject,
+                    Charset => 'iso-8859-15',
+                    Type => 'text/plain',
+                    Body => $Body)
+                ) {
+                    my $Output = '';
+                    $Output .= $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
+                    $Output .= $Self->{LayoutObject}->CustomerWarning(
                         Comment => 'Can\' send account info!'
                     );
-                    print $Self->{LayoutObject}->CustomerFooter();
+                    $Output .= $Self->{LayoutObject}->CustomerFooter();
+                    $Self->{LayoutObject}->Print(Output =>  \$Output);
                 }
                 # show sent account info
                 if ($Self->{ConfigObject}->Get('CustomerPanelLoginURL')) {
@@ -504,29 +508,32 @@ sub Run {
                     $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                     print $Self->{LayoutObject}->Redirect(
                         ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
-                         "?RequestedURL=$Param{RequestedURL}&User=$GetParams{UserLogin}&".
-                         "&Email=$GetParams{UserEmail}&Reason=NewAccountCreated",
+                            "?RequestedURL=$Param{RequestedURL}&User=$GetParams{UserLogin}&".
+                            "&Email=$GetParams{UserEmail}&Reason=NewAccountCreated",
                     );
                 }
                 else {
                     # login screen
-                    print $Self->{LayoutObject}->CustomerLogin(
-                        Title => 'Login',
-                        Message => "New account created. Sent Login-Account to '$GetParams{UserEmail}'",
-                        User => $GetParams{UserLogin},
+                    $Self->{LayoutObject}->Print(
+                        Output => \$Self->{LayoutObject}->CustomerLogin(
+                            Title => 'Login',
+                            Message => "New account created. Sent Login-Account to '$GetParams{UserEmail}'",
+                            User => $GetParams{UserLogin},
+                        ),
                     );
                 }
             }
             else {
-                print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
-                print $Self->{LayoutObject}->CustomerWarning(
+                my $Output = '';
+                $Output .= $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error');
+                $Output .= $Self->{LayoutObject}->CustomerWarning(
                     Comment => 'Please press Back and try again.'
                 );
-                print $Self->{LayoutObject}->CustomerFooter();
+                $Output .= $Self->{LayoutObject}->CustomerFooter();
+                $Self->{LayoutObject}->Print(Output =>  \$Output);
             }
         }
     }
-
     # show login site
     elsif (!$Param{SessionID}) {
         # create AuthObject
@@ -543,18 +550,19 @@ sub Run {
             $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
             print $Self->{LayoutObject}->Redirect(
                 ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
-                 "?RequestedURL=$Param{RequestedURL}",
+                    "?RequestedURL=$Param{RequestedURL}",
             );
         }
         else {
             # login screen
-            print $Self->{LayoutObject}->CustomerLogin(
-                Title => 'Login',
-                %Param,
+            $Self->{LayoutObject}->Print(
+                Output => \$Self->{LayoutObject}->CustomerLogin(
+                    Title => 'Login',
+                    %Param,
+                ),
             );
         }
     }
-
     # run modules if exists a version value
     elsif ($Self->{MainObject}->Require("Kernel::Modules::$Param{Action}")) {
         # check session id
@@ -574,20 +582,21 @@ sub Run {
                 # redirect to alternate login
                 $Param{RequestedURL} = $Self->{LayoutObject}->LinkEncode($Param{RequestedURL});
                 print $Self->{LayoutObject}->Redirect(
-                  ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
-                   "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
+                    ExtURL => $Self->{ConfigObject}->Get('CustomerPanelLoginURL').
+                        "?Reason=InvalidSessionID&RequestedURL=$Param{RequestedURL}",
                 );
             }
             else {
                 # show login
-                print $Self->{LayoutObject}->CustomerLogin(
-                    Title => 'Login',
-                    Message => $Self->{SessionObject}->CheckSessionIDMessage(),
-                    %Param,
+                $Self->{LayoutObject}->Print(
+                    Output => \$Self->{LayoutObject}->CustomerLogin(
+                        Title => 'Login',
+                        Message => $Self->{SessionObject}->CheckSessionIDMessage(),
+                        %Param,
+                    ),
                 );
             }
         }
-
         # run module
         else {
             # get session data
@@ -604,10 +613,12 @@ sub Run {
                 }
                 else {
                     # show login screen
-                    print $Self->{LayoutObject}->CustomerLogin(
-                        Title => 'Panic!',
-                        Message => 'Panic! Invalid Session!!!',
-                        %Param,
+                    $Self->{LayoutObject}->Print(
+                        Output => \$Self->{LayoutObject}->CustomerLogin(
+                            Title => 'Panic!',
+                            Message => 'Panic! Invalid Session!!!',
+                            %Param,
+                        ),
                     );
                     exit (0);
                 }
@@ -625,10 +636,9 @@ sub Run {
                     Priority => 'error',
                     Message => "Module Kernel::Modules::$Param{Action} not registered in Kernel/Config.pm!",
                 );
-                print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
-                print $Self->{LayoutObject}->Error();
-                print $Self->{LayoutObject}->CustomerFooter();
-                exit 0;
+                $Self->{LayoutObject}->CustomerFatalError(
+                    Comment => 'Please contact your admin'
+                );
             }
             # updated last request time
             $Self->{SessionObject}->UpdateSessionID(
@@ -664,7 +674,7 @@ sub Run {
                         );
                         my $Output = $PreModuleObject->PreRun();
                         if ($Output) {
-                            print $PreModuleObject->PreRun();
+                            $Self->{LayoutObject}->Print(Output => \$Output);
                             exit (0);
                         }
                     }
@@ -692,7 +702,7 @@ sub Run {
                 );
             }
             # ->Run $Action with $GenericObject
-            print $GenericObject->Run();
+            $Self->{LayoutObject}->Print(Output => \$GenericObject->Run());
             # log request time
             if ($Self->{ConfigObject}->Get('PerformanceLog')) {
                 if ((!$QueryString && $Param{Action}) || ($QueryString !~ /Action=/)) {
@@ -716,7 +726,6 @@ sub Run {
             }
         }
     }
-
     # else print an error screen
     else {
         # create new LayoutObject with '%Param'
@@ -729,11 +738,10 @@ sub Run {
             %Data,
         );
         # print error
-        print $Self->{LayoutObject}->CustomerHeader(Area => 'Core', Title => 'Error!');
-        print $Self->{LayoutObject}->CustomerError();
-        print $Self->{LayoutObject}->CustomerFooter();
+        $Self->{LayoutObject}->CustomerFatalError(
+            Comment => 'Please contact your admin'
+        );
     }
-
     # debug info
     if ($Self->{Debug}) {
         $Self->{LogObject}->Log(
@@ -748,6 +756,8 @@ sub Run {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -760,6 +770,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.16.2.1 $ $Date: 2007/01/04 14:54:11 $
+$Revision: 1.20.2.1 $ $Date: 2008/01/14 12:15:07 $
 
 =cut
