@@ -2,7 +2,7 @@
 # Kernel/System/Web/UploadCache.pm - a fs upload cache
 # Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: UploadCache.pm,v 1.3.2.1 2007/03/12 23:56:52 martin Exp $
+# $Id: UploadCache.pm,v 1.7 2007/08/21 11:09:26 martin Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -15,7 +15,7 @@ use strict;
 
 use vars qw($VERSION);
 
-$VERSION = '$Revision: 1.3.2.1 $ ';
+$VERSION = '$Revision: 1.7 $ ';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 =head1 NAME
@@ -36,24 +36,35 @@ All upload cache functions.
 
 create param object
 
-  use Kernel::Config;
-  use Kernel::System::Log;
-  use Kernel::System::DB;
-  use Kernel::System::Web::UploadCache;
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::Encode;
+    use Kernel::System::Main;
+    use Kernel::System::DB;
+    use Kernel::System::Web::UploadCache;
 
-  my $ConfigObject = Kernel::Config->new();
-  my $LogObject    = Kernel::System::Log->new(
-      ConfigObject => $ConfigObject,
-  );
-  my $DBObject = Kernel::System::DB->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-  );
-  my $UploadParamObject = Kernel::System::Web::UploadCache->new(
-      ConfigObject => $ConfigObject,
-      LogObject => $LogObject,
-      DBObject => $DBObject,
-  );
+    my $ConfigObject = Kernel::Config->new();
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+    my $MainObject = Kernel::System::Main->new(
+        LogObject => $LogObject,
+        ConfigObject => $ConfigObject,
+    );
+    my $EncodeObject = Kernel::System::Encode->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $DBObject = Kernel::System::DB->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+    my $UploadCache= Kernel::System::Web::UploadCache->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+        DBObject => $DBObject,
+        EncodeObject => $EncodeObject,
+    );
 
 =cut
 
@@ -65,18 +76,20 @@ sub new {
     my $Self = {};
     bless ($Self, $Type);
     # check needed objects
-    foreach (qw(ConfigObject LogObject EncodeObject)) {
+    foreach (qw(ConfigObject LogObject MainObject EncodeObject)) {
         $Self->{$_} = $Param{$_} || die "Got no $_!";
     }
 
     # load generator auth module
     $Self->{GenericModule} = $Self->{ConfigObject}->Get('WebUploadCacheModule')
-      || 'Kernel::System::Web::UploadCache::DB';
-    if (!eval "require $Self->{GenericModule}") {
-        die "Can't load backend module $Self->{GenericModule}! $@";
-    }
+        || 'Kernel::System::Web::UploadCache::DB';
 
-    $Self->{Backend} = $Self->{GenericModule}->new(%Param);
+    if ($Self->{MainObject}->Require($Self->{GenericModule})) {
+        $Self->{Backend} = $Self->{GenericModule}->new(%Param);
+    }
+    else {
+        return;
+    }
 
     return $Self;
 }
@@ -85,7 +98,7 @@ sub new {
 
 create a new form id
 
-  my $FormID = $UploadParamObject->FormIDCreate();
+    my $FormID = $UploadCacheObject->FormIDCreate();
 
 =cut
 
@@ -98,7 +111,7 @@ sub FormIDCreate {
 
 remove all data with form id
 
-  $UploadParamObject->FormIDRemove(FormID => 123456);
+    $UploadCacheObject->FormIDRemove(FormID => 123456);
 
 =cut
 
@@ -111,12 +124,12 @@ sub FormIDRemove {
 
 add a file to the form id
 
-  $UploadParamObject->FormIDAddFile(
-      FormID => 12345,
-      Filename => 'somefile.html',
-      Content => $FileInSting,
-      ContentType => 'text/html',
-  );
+    $UploadCacheObject->FormIDAddFile(
+        FormID => 12345,
+        Filename => 'somefile.html',
+        Content => $FileInSting,
+        ContentType => 'text/html',
+    );
 
 =cut
 
@@ -129,10 +142,10 @@ sub FormIDAddFile {
 
 removes a file to the form id
 
-  $UploadParamObject->FormIDRemoveFile(
-      FormID => 12345,
-      FileID => 1,
-  );
+    $UploadCacheObject->FormIDRemoveFile(
+        FormID => 12345,
+        FileID => 1,
+    );
 
 =cut
 
@@ -145,11 +158,11 @@ sub FormIDRemoveFile {
 
 returns a array with hash ref of all form id files
 
-  my @Data = $UploadParamObject->FormIDGetAllFilesData(
-      FormID => 12345,
-  );
+    my @Data = $UploadCacheObject->FormIDGetAllFilesData(
+        FormID => 12345,
+    );
 
-  Return data of on hash is Content, ContentType, Filename, Filesize, FileID;
+    Return data of on hash is Content, ContentType, Filename, Filesize, FileID;
 
 =cut
 
@@ -164,11 +177,11 @@ returns a array with hash ref of all form id files
 
 Note: No Content will be returned, just meta data.
 
-  my @Data = $UploadParamObject->FormIDGetAllFilesMeta(
-      FormID => 12345,
-  );
+    my @Data = $UploadCacheObject->FormIDGetAllFilesMeta(
+        FormID => 12345,
+    );
 
-  Return data of on hash is Filename, Filesize, FileID;
+    Return data of on hash is Filename, Filesize, FileID;
 
 =cut
 
@@ -183,7 +196,7 @@ Removed no longer needed tmp file.
 
 Each file older then 1 day will be removed.
 
-  $UploadParamObject->FormIDCleanUp();
+    $UploadCacheObject->FormIDCleanUp();
 
 =cut
 
@@ -194,6 +207,8 @@ sub FormIDCleanUp {
 
 1;
 
+=back
+
 =head1 TERMS AND CONDITIONS
 
 This software is part of the OTRS project (http://otrs.org/).
@@ -206,6 +221,6 @@ did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
 
 =head1 VERSION
 
-$Revision: 1.3.2.1 $ $Date: 2007/03/12 23:56:52 $
+$Revision: 1.7 $ $Date: 2007/08/21 11:09:26 $
 
 =cut
