@@ -1,8 +1,8 @@
 # --
 # Kernel/System/XMLMaster.pm - the global XMLMaster module for OTRS
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: XMLMaster.pm,v 1.4 2006/11/02 12:20:54 tr Exp $
+# $Id: XMLMaster.pm,v 1.7 2007/02/12 15:52:22 tr Exp $
 # --
 # This software comes with ABSOLUTELY NO WARRANTY. For details, see
 # the enclosed file COPYING for license information (GPL). If you
@@ -13,13 +13,68 @@ package Kernel::System::XMLMaster;
 
 use strict;
 use Kernel::System::XML;
-use Kernel::System::Main;
 
 use vars qw(@ISA $VERSION);
 
-$VERSION = '$Revision: 1.4 $';
+$VERSION = '$Revision: 1.7 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
+=head1 NAME
+
+Kernel::System::XMLMaster - xml master handle
+
+=head1 SYNOPSIS
+
+This module is managing xml master handle.
+
+=head1 PUBLIC INTERFACE
+
+=over 4
+
+=cut
+
+=item new()
+
+create a xml master object
+
+    use Kernel::Config;
+    use Kernel::System::Log;
+    use Kernel::System::Main;
+    use Kernel::System::Time;
+    use Kernel::System::DB;
+
+    my $ConfigObject = Kernel::Config->new();
+
+    my $LogObject = Kernel::System::Log->new(
+        ConfigObject => $ConfigObject,
+    );
+
+    my $MainObject = Kernel::System::Main->new(
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+
+    my $TimeObject = Kernel::System::Time->new(
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+
+    my $DBObject = Kernel::System::DB->new(
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+
+    my $XMLMasterObject = Kernel::System::XMLMaster->new(
+        DBObject => $DBObject,
+        MainObject => $MainObject,
+        ConfigObject => $ConfigObject,
+        LogObject => $LogObject,
+    );
+
+=cut
+
 sub new {
     my $Type = shift;
     my %Param = @_;
@@ -32,7 +87,7 @@ sub new {
         $Self->{$_} = $Param{$_};
     }
     # check needed objects
-    foreach (qw(DBObject LogObject ConfigObject TimeObject)) {
+    foreach (qw(DBObject LogObject ConfigObject TimeObject MainObject)) {
         die "Got no $_" if (!$Param{$_});
     }
 
@@ -41,20 +96,31 @@ sub new {
 
     # create common objects
     $Self->{XMLObject} = Kernel::System::XML->new(%Param);
-    $Self->{MainObject} = Kernel::System::Main->new(%Param);
 
     return $Self;
 }
 
+=item Run()
+
+to execute the run process
+
+    my $XML = '<SomeXMLString>Test<SomeXMLString>';
+
+    $XMLMasterObject->Run(
+        XML => \$XML,
+    );
+
+=cut
+
 sub Run {
     my $Self = shift;
     my %Param = @_;
     # check needed stuff
     foreach (qw(XML)) {
-      if (!defined $Param{$_}) {
-        $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_ !");
-        return;
-      }
+        if (!defined $Param{$_}) {
+            $Self->{LogObject}->Log(Priority => 'error', Message => "Need $_ !");
+            return;
+        }
     }
 
     my @XMLHash = $Self->{XMLObject}->XMLParse2XMLHash(String => ${$Param{XML}});
@@ -88,3 +154,19 @@ sub Run {
 }
 
 1;
+
+=back
+
+=head1 TERMS AND CONDITIONS
+
+This software is part of the OTRS project (http://otrs.org/).
+
+This software comes with ABSOLUTELY NO WARRANTY. For details, see
+the enclosed file COPYING for license information (GPL). If you
+did not receive this file, see http://www.gnu.org/licenses/gpl.txt.
+
+=head1 VERSION
+
+$Revision: 1.7 $ $Date: 2007/02/12 15:52:22 $
+
+=cut
