@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # mkStats.pl - send stats output via email
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2008 OTRS AG, http://otrs.org/
 # --
-# $Id: mkStats.pl,v 1.43 2006/11/10 14:26:35 tr Exp $
+# $Id: mkStats.pl,v 1.49.2.1 2008/05/28 08:03:43 tr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -20,17 +20,18 @@
 # Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # --
 
+use strict;
+use warnings;
+
 # use ../ as lib location
 use File::Basename;
 use FindBin qw($RealBin);
 use lib dirname($RealBin);
 use lib dirname($RealBin)."/Kernel/cpan-lib";
 
-use strict;
-
 use vars qw($VERSION);
 
-$VERSION = '$Revision: 1.43 $';
+$VERSION = '$Revision: 1.49.2.1 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 use Getopt::Std;
@@ -46,32 +47,28 @@ use Kernel::System::Group;
 use Kernel::System::User;
 use Kernel::System::CSV;
 use Kernel::System::PDF;
-use Kernel::Output::HTML::Layout;
+use Kernel::Language;
 
-# --
 # create common objects
-# --
 my %CommonObject = ();
 $CommonObject{UserID} = 1;
-$CommonObject{ConfigObject}    = Kernel::Config->new();
-$CommonObject{LogObject}       = Kernel::System::Log->new(
+$CommonObject{ConfigObject} = Kernel::Config->new();
+$CommonObject{LogObject} = Kernel::System::Log->new(
     LogPrefix => 'OTRS-SendStats',
     %CommonObject,
 );
-$CommonObject{CSVObject}       = Kernel::System::CSV->new(%CommonObject);
-$CommonObject{TimeObject}      = Kernel::System::Time->new(%CommonObject);
-$CommonObject{MainObject}      = Kernel::System::Main->new(%CommonObject);
-$CommonObject{DBObject}        = Kernel::System::DB->new(%CommonObject);
-$CommonObject{GroupObject}     = Kernel::System::Group->new(%CommonObject);
-$CommonObject{UserObject}      = Kernel::System::User->new(%CommonObject);
-$CommonObject{StatsObject}     = Kernel::System::Stats->new(%CommonObject);
+$CommonObject{CSVObject} = Kernel::System::CSV->new(%CommonObject);
+$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
+$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
+$CommonObject{DBObject} = Kernel::System::DB->new(%CommonObject);
+$CommonObject{GroupObject} = Kernel::System::Group->new(%CommonObject);
+$CommonObject{UserObject} = Kernel::System::User->new(%CommonObject);
+$CommonObject{StatsObject} = Kernel::System::Stats->new(%CommonObject);
 $CommonObject{CheckItemObject} = Kernel::System::CheckItem->new(%CommonObject);
-$CommonObject{EmailObject}     = Kernel::System::Email->new(%CommonObject);
-$CommonObject{PDFObject}       = Kernel::System::PDF->new(%CommonObject);
+$CommonObject{EmailObject} = Kernel::System::Email->new(%CommonObject);
+$CommonObject{PDFObject} = Kernel::System::PDF->new(%CommonObject);
 
-# --
 # get options
-# --
 my %Opts = ();
 getopt('nrsmhoplf', \%Opts);
 if ($Opts{'h'}) {
@@ -83,72 +80,74 @@ if ($Opts{'h'}) {
     exit 1;
 }
 # required output param check
-if (!$Opts{'o'} && !$Opts{'r'}) {
+if (!$Opts{o} && !$Opts{r}) {
     print STDERR "ERROR: Need -o /tmp/ OR -r email\@example.com [-m 'some message']\n";
     exit 1;
 }
 # stats module check
-if (!$Opts{'n'}) {
+if (!$Opts{n}) {
     print STDERR "ERROR: Need -n StatNumber\n";
     exit 1;
 }
 # fill up body
-if (!$Opts{'m'} && $Opts{'p'}) {
-    $Opts{'m'} .= "Stats with following options:\n\n";
-    $Opts{'m'} .= "StatNumber: $Opts{'n'}\n";
-    my @P = split(/&/, $Opts{'p'}||'');
-    foreach (@P) {
+if (!$Opts{m} && $Opts{p}) {
+    $Opts{m} .= "Stats with following options:\n\n";
+    $Opts{m} .= "StatNumber: $Opts{n}\n";
+    my @P = split(/&/, $Opts{'p'});
+    for (@P) {
         my ($Key, $Value) = split(/=/, $_, 2);
         $Opts{'m'} .= "$Key: $Value\n";
     }
 }
 # only necessary for emails
-if (!$Opts{'m'} && $Opts{'r'}) {
+if (!$Opts{m} && $Opts{r}) {
     print STDERR "ERROR: Need -m 'some message (necessary for emails)'\n";
     exit 1;
 }
 # language
 my $Lang = $CommonObject{ConfigObject}->Get('DefaultLanguage') || 'en';
-if ($Opts{'l'}) {
-    $Lang = $Opts{'l'};
+if ($Opts{l}) {
+    $Lang = $Opts{l};
 }
-$CommonObject{LayoutObject} = Kernel::Output::HTML::Layout->new(
-    %CommonObject,
-    Lang => $Lang,
+$CommonObject{LanguageObject} = Kernel::Language->new(
+    UserLanguage => $Lang,
+    LogObject => $CommonObject{LogObject},
+    ConfigObject => $CommonObject{ConfigObject},
+    MainObject => $CommonObject{MainObject},
 );
 
 # format
 my $Format = 'CSV';
-if ($Opts{'f'}) {
-    if ($Opts{'f'} eq 'Print') {
+if ($Opts{f}) {
+    if ($Opts{f} eq 'Print') {
         $Format = 'Print';
     }
 }
+
 # recipient check
-if ($Opts{'r'}) {
-    if (!$CommonObject{CheckItemObject}->CheckEmail(Address => $Opts{'r'})) {
+if ($Opts{r}) {
+    if (!$CommonObject{CheckItemObject}->CheckEmail(Address => $Opts{r})) {
         print STDERR "ERROR: " . $CommonObject{CheckItemObject}->CheckError() . "\n";
         exit 1;
     }
 }
+
 # sender, if given
-if (!$Opts{'s'}) {
-    $Opts{'s'} = '';
+if (!$Opts{s}) {
+    $Opts{s} = '';
 }
+
 # directory check
-if ($Opts{'o'} && !-e $Opts{'o'}) {
-    print STDERR "ERROR: No such directory: $Opts{'o'}\n";
+if ($Opts{o} && !-e $Opts{o}) {
+    print STDERR "ERROR: No such directory: $Opts{o}\n";
     exit 1;
 }
 
-# --
-# process the informations
-# --
-
-my $StatNumber = $Opts{'n'};
-my $StatID     = $CommonObject{StatsObject}->StatNumber2StatID(StatNumber => $StatNumber);
+# process the information
+my $StatNumber = $Opts{n};
+my $StatID = $CommonObject{StatsObject}->StatNumber2StatID(StatNumber => $StatNumber);
 if (!$StatID) {
-    print STDERR "ERROR: No StatNumber: $Opts{'n'}\n";
+    print STDERR "ERROR: No StatNumber: $Opts{n}\n";
     exit 1;
 }
 
@@ -156,13 +155,13 @@ my ($s,$m,$h, $D,$M,$Y) = $CommonObject{TimeObject}->SystemTime2Date(
     SystemTime => $CommonObject{TimeObject}->SystemTime(),
 );
 
-my %GetParam   = ();
+my %GetParam = ();
 my $Stat = $CommonObject{StatsObject}->StatsGet(StatID => $StatID);
 
 if ($Stat->{StatType} eq 'static') {
-    $GetParam{Year}  = $Y;
+    $GetParam{Year} = $Y;
     $GetParam{Month} = $M;
-    $GetParam{Day}   = $D;
+    $GetParam{Day} = $D;
 
     # get params from -p
     # only for static files
@@ -200,7 +199,7 @@ elsif ($Stat->{StatType} eq 'dynamic') {
 
 # run stat...
 my @StatArray = @{$CommonObject{StatsObject}->StatsRun(
-    StatID       => $StatID,
+    StatID => $StatID,
     GetParam => \%GetParam,
 )};
 
@@ -217,18 +216,23 @@ my %Attachment;
 
 if ($Format eq 'Print' && $CommonObject{PDFObject}) {
     # Create the PDF
-    my $PrintedBy = $CommonObject{LayoutObject}->{LanguageObject}->Get('printed by');
-    my $Page = $CommonObject{LayoutObject}->{LanguageObject}->Get('Page');
-    my $Time = $CommonObject{LayoutObject}->Output(Template => '$Env{"Time"}');
     my %User = $CommonObject{UserObject}->GetUserData(UserID => $CommonObject{UserID});
 
+    my $PrintedBy = $CommonObject{LanguageObject}->Get('printed by');
+    my $Page = $CommonObject{LanguageObject}->Get('Page');
+    my $SystemTime = $CommonObject{TimeObject}->SystemTime();
+    my $TimeStamp = $CommonObject{TimeObject}->SystemTime2TimeStamp(
+        SystemTime => $SystemTime,
+    );
+    my $Time = $CommonObject{LanguageObject}->FormatTimeString($TimeStamp, 'DateFormat');
+
     # create the content array
     my $CellData;
     my $CounterRow = 0;
     my $CounterHead = 0;
     foreach my $Content (@{$HeadArrayRef}) {
         $CellData->[$CounterRow]->[$CounterHead]->{Content} = $Content;
-        $CellData->[$CounterRow]->[$CounterHead]->{Font} = 'HelveticaBold';
+        $CellData->[$CounterRow]->[$CounterHead]->{Font} = 'ProportionalBold';
         $CounterHead++;
     }
     if ($CounterHead > 0) {
@@ -243,7 +247,7 @@ if ($Format eq 'Print' && $CommonObject{PDFObject}) {
         $CounterRow++;
     }
     if (!$CellData->[0]->[0]) {
-        $CellData->[0]->[0]->{Content} = $CommonObject{LayoutObject}->{LanguageObject}->Get('No Result!');
+        $CellData->[0]->[0]->{Content} = $CommonObject{LanguageObject}->Get('No Result!');
     }
     # page params
     my %PageParam;
@@ -279,6 +283,7 @@ if ($Format eq 'Print' && $CommonObject{PDFObject}) {
     # create new pdf document
     $CommonObject{PDFObject}->DocumentNew(
         Title => $CommonObject{ConfigObject}->Get('Product') . ': ' . $Title,
+        Encode => $CommonObject{LanguageObject}->GetRecommendedCharset(),
     );
     # start table output
     my $Loop = 1;
@@ -318,10 +323,10 @@ if ($Format eq 'Print' && $CommonObject{PDFObject}) {
         String => $Stat->{Title} . " Created",
     );
     %Attachment = (
-        Filename    => $Filename . ".pdf",
+        Filename => $Filename . ".pdf",
         ContentType => "application/pdf",
-        Content     => $PDFString,
-        Encoding    => "base64",
+        Content => $PDFString,
+        Encoding => "base64",
         Disposition => "attachment",
     );
 }
@@ -339,36 +344,38 @@ else {
     );
 
     %Attachment = (
-        Filename    => $Filename . ".csv",
+        Filename => $Filename . ".csv",
         ContentType => "text/csv",
-        Content     => $Output,
-        Encoding    => "base64",
+        Content => $Output,
+        Encoding => "base64",
         Disposition => "attachment",
     );
 }
 
 # write output
-if ($Opts{'o'}) {
-    if (open(OUT, "> $Opts{'o'}/$Attachment{Filename}")) {
-        print OUT $Attachment{Content};
-        close (OUT);
-        print "NOTICE: Writing file $Opts{'o'}/$Attachment{Filename}.\n";
+if ($Opts{o}) {
+    if (open my $Filehandle, '>', "$Opts{o}/$Attachment{Filename}") {
+        print $Filehandle $Attachment{Content};
+        close $Filehandle;
+        print "NOTICE: Writing file $Opts{o}/$Attachment{Filename}.\n";
         exit;
     }
     else {
-        print STDERR "ERROR: Can't write $Opts{'o'}/$Attachment{Filename}: $!\n";
+        print STDERR "ERROR: Can't write $Opts{o}/$Attachment{Filename}: $!\n";
         exit 1;
     }
 }
+
 # send email
 elsif ($CommonObject{EmailObject}->Send(
-    From       => $Opts{'s'},
-    To         => $Opts{'r'},
-    Subject    => "[Stats - $CountStatArray Records] $Title; Created: $Time",
-    Body       => $Opts{'m'},
+    From => $Opts{s},
+    To => $Opts{r},
+    Subject => "[Stats - $CountStatArray Records] $Title; Created: $Time",
+    Body => $CommonObject{LanguageObject}->Get($Opts{'m'}),
+    Charset => $CommonObject{ConfigObject}  ->{DefaultCharset},
     Attachment => [
         {
-            %Attachment,
+            %Attachment
         },
     ],
 )) {
@@ -381,8 +388,8 @@ sub GetParam {
     if (!$Param{Param}) {
         print STDERR "ERROR: Need Param Arg in GetParam()\n";
     }
-    my @P = split(/&/, $Opts{'p'}||'');
-    foreach (@P) {
+    my @P = split(/&/, $Opts{p} || '');
+    for (@P) {
         my ($Key, $Value) = split(/=/, $_, 2);
         if ($Key eq $Param{Param}) {
             return $Value;
@@ -396,9 +403,9 @@ sub GetArray {
     if (!$Param{Param}) {
         print STDERR "ERROR: Need Param Arg in GetArray()\n";
     }
-    my @P = split(/&/, $Opts{'p'}||'');
+    my @P = split(/&/, $Opts{p} || '');
     my @Array;
-    foreach (@P) {
+    for (@P) {
         my ($Key, $Value) = split(/=/, $_, 1);
         if ($Key eq $Param{Param}) {
             push (@Array, $Value);
