@@ -6,9 +6,7 @@ use strict;
 # check $ENV{MOD_PERL}, $ENV{GATEWAY_INTERFACE} is deprecated for mod_perl2
 $ENV{MOD_PERL} =~ /mod_perl/ or die "MOD_PERL not used!";
 
-# --
 # set otrs lib path!
-# --
 use lib "/opt/otrs/";
 use lib "/opt/otrs/Kernel/cpan-lib";
 
@@ -19,7 +17,6 @@ use lib "/opt/otrs/Kernel/cpan-lib";
 use CGI (); CGI->compile(':cgi');
 use CGI::Carp ();
 
-#use Apache ();
 #use Apache::DBI ();
 #Apache::DBI->connect_on_init('DBI:mysql:otrs', 'otrs', 'some-pass');
 use DBI ();
@@ -50,7 +47,6 @@ use Kernel::System::AuthSession::DB;
 #use Kernel::System::AuthSession::FS;
 use Kernel::System::User;
 use Kernel::System::User::Preferences::DB;
-use Kernel::System::Permission;
 #use Kernel::System::PDF;
 use Kernel::System::XML;
 use Kernel::System::Log;
