@@ -1,9 +1,9 @@
 #!/usr/bin/perl -w
 # --
 # xml2docbook.pl - config xml to docbook
-# Copyright (C) 2001-2006 OTRS GmbH, http://otrs.org/
+# Copyright (C) 2001-2007 OTRS GmbH, http://otrs.org/
 # --
-# $Id: xml2docbook.pl,v 1.10 2006/10/05 14:15:30 cs Exp $
+# $Id: xml2docbook.pl,v 1.13 2007/02/13 15:04:06 tr Exp $
 # --
 # This program is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -30,13 +30,14 @@ use strict;
 use Getopt::Std;
 
 use vars qw($VERSION);
-$VERSION = '$Revision: 1.10 $';
+$VERSION = '$Revision: 1.13 $';
 $VERSION =~ s/^\$.*:\W(.*)\W.+?$/$1/;
 
 use Kernel::Config;
+use Kernel::System::Log;
+use Kernel::System::Main;
 use Kernel::System::Time;
 use Kernel::System::DB;
-use Kernel::System::Log;
 use Kernel::System::Config;
 
 # create common objects
@@ -46,9 +47,8 @@ $CommonObject{LogObject} = Kernel::System::Log->new(
     LogPrefix => 'OTRS-xml2docbook',
     %CommonObject,
 );
-$CommonObject{TimeObject} = Kernel::System::Time->new(
-    %CommonObject,
-);
+$CommonObject{MainObject} = Kernel::System::Main->new(%CommonObject);
+$CommonObject{TimeObject} = Kernel::System::Time->new(%CommonObject);
 $CommonObject{DBObject} = Kernel::System::DB->new(%CommonObject);
 $CommonObject{SysConfigObject} = Kernel::System::Config->new(%CommonObject);
 
@@ -57,9 +57,7 @@ $CommonObject{SysConfigObject} = Kernel::System::Config->new(%CommonObject);
 my @Groups = (qw(Framework Ticket));
 my $UserLang = '';
 
-# --
 # get options
-# --
 my %Opts = ();
 
 getopt('l',  \%Opts);
@@ -68,16 +66,14 @@ if ($Opts{'l'}) {
     $UserLang = $Opts{'l'};
 }
 else {
-   die "Need -l <Language>\n";
+    die "Need -l <Language>\n";
 }
 
-# --
 # start xml output
-# --
 
-print '<?xml version="1.0" encoding="ISO-8859-1"?>
+print '<?xml version="1.0" encoding="' . $CommonObject{ConfigObject}->Get('DefaultCharset') . '"?>
 <!DOCTYPE appendix PUBLIC "-//OASIS//DTD DocBook XML V4.4//EN"
-  "http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd">
+    "http://www.oasis-open.org/docbook/xml/4.4/docbookx.dtd">
 ';
 print "\n<appendix id=\"config\"><title>Config Referenzliste</title>\n";
 foreach my $Group (@Groups) {
@@ -180,4 +176,3 @@ foreach my $Group (@Groups) {
 print "</appendix> \n";
 
 exit;
-
