@@ -1,5 +1,5 @@
 // ----------------------------------------------------------
-//  driver: maxdb, generated: 2007-07-26 19:05:38
+//  driver: maxdb, generated: 2007-11-05 14:29:37
 // ----------------------------------------------------------
 // ----------------------------------------------------------
 //  insert into table valid
@@ -291,7 +291,7 @@ INSERT INTO standard_response (name, text, valid_id, create_by, create_time, cha
 // ----------------------------------------------------------
 INSERT INTO standard_response (name, text, valid_id, create_by, create_time, change_by, change_time)
     VALUES
-    ('test answer', 'Some test answer to show who a standard response can be used.', 1, 1, timestamp, 1, timestamp)
+    ('test answer', 'Some test answer to show how a standard response can be used.', 1, 1, timestamp, 1, timestamp)
 //
 // ----------------------------------------------------------
 //  insert into table queue_standard_response
@@ -374,7 +374,7 @@ Your e-mail will be answered by a human asap
 Have fun with OTRS! :-)
 
 Your OTRS Team
-', 'RE: <OTRS_CUSTOMER_SUBJECT[20]>', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
+', 'RE: <OTRS_CUSTOMER_SUBJECT[24]>', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
 //
 // ----------------------------------------------------------
 //  insert into table auto_response
@@ -388,7 +388,7 @@ INSERT INTO auto_response (type_id, system_address_id, name, text0, text1, chars
 Please create a new ticket.
 
 Your OTRS Team
-', 'Your email has been rejected! (RE: <OTRS_CUSTOMER_SUBJECT[20]>)', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
+', 'Your email has been rejected! (RE: <OTRS_CUSTOMER_SUBJECT[24]>)', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
 //
 // ----------------------------------------------------------
 //  insert into table auto_response
@@ -405,7 +405,7 @@ Your e-mail will be answered by a human asap.
 Have fun with OTRS!
 
 Your OTRS Team
-', 'RE: <OTRS_CUSTOMER_SUBJECT[20]>', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
+', 'RE: <OTRS_CUSTOMER_SUBJECT[24]>', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
 //
 // ----------------------------------------------------------
 //  insert into table auto_response
@@ -424,7 +424,7 @@ Your e-mail will be answered by a human asap.
 Have fun with OTRS!
 
 Your OTRS Team
-', 'New ticket has been created! (RE: <OTRS_CUSTOMER_SUBJECT[20]>)', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
+', 'New ticket has been created! (RE: <OTRS_CUSTOMER_SUBJECT[24]>)', 'iso-8859-1', '', 1, 1, timestamp, 1, timestamp)
 //
 // ----------------------------------------------------------
 //  insert into table ticket_type
@@ -899,14 +899,14 @@ INSERT INTO ticket_history (name, history_type_id, ticket_id, type_id, article_i
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::NewTicket', 'iso-8859-1', 'en', 'New ticket notification! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_UserFirstname>,
+    ('Agent::NewTicket', 'iso-8859-1', 'en', 'New ticket notification! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 there is a new ticket in "<OTRS_TICKET_Queue>"!
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -918,14 +918,14 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::FollowUp', 'iso-8859-1', 'en', 'You got follow up! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::FollowUp', 'iso-8859-1', 'en', 'You got follow up! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 you got a follow up!
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -937,14 +937,14 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::LockTimeout', 'iso-8859-1', 'en', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::LockTimeout', 'iso-8859-1', 'en', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 unlocked (lock timeout) your locked ticket [<OTRS_TICKET_TicketNumber>].
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -956,7 +956,7 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::OwnerUpdate', 'iso-8859-1', 'en', 'Ticket owner assigned to you! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::OwnerUpdate', 'iso-8859-1', 'en', 'Ticket owner assigned to you! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 a ticket [<OTRS_TICKET_TicketNumber>] is assigned to you by "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>".
 
@@ -973,7 +973,7 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'en', 'Ticket responsible assigned to you! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_RESPONSIBLE_UserFirstname>,
+    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'en', 'Ticket responsible assigned to you! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_RESPONSIBLE_UserFirstname>,
 
 a ticket [<OTRS_TICKET_TicketNumber>] is assigned to you by "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>".
 
@@ -990,7 +990,7 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::AddNote', 'iso-8859-1', 'en', 'New note! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::AddNote', 'iso-8859-1', 'en', 'New note! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" added a new note to ticket [<OTRS_TICKET_TicketNumber>].
 
@@ -1006,12 +1006,12 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Move', 'iso-8859-1', 'en', 'Moved ticket in "<OTRS_CUSTOMER_QUEUE>" queue! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi,
+    ('Agent::Move', 'iso-8859-1', 'en', 'Moved ticket in "<OTRS_CUSTOMER_QUEUE>" queue! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" moved a ticket [<OTRS_TICKET_TicketNumber>] into "<OTRS_CUSTOMER_QUEUE>".
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1023,7 +1023,7 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::PendingReminder', 'iso-8859-1', 'en', 'Ticket reminder has been reached! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::PendingReminder', 'iso-8859-1', 'en', 'Ticket reminder has been reached! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 the ticket "<OTRS_TICKET_TicketNumber>" has been reached the reminder time!
 
@@ -1031,7 +1031,7 @@ the ticket "<OTRS_TICKET_TicketNumber>" has been reached the reminder time!
 
 wrote:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Please have a look at:
@@ -1045,15 +1045,15 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Escalation', 'iso-8859-1', 'en', 'Ticket Escalation! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_UserFirstname>,
+    ('Agent::Escalation', 'iso-8859-1', 'en', 'Ticket Escalation! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
-the ticket "<OTRS_TICKET_TicketNumber>" is escaleted!
+the ticket "<OTRS_TICKET_TicketNumber>" is escalated!
 
 <OTRS_CUSTOMER_FROM>
 
 wrote:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Please have a look at:
@@ -1067,14 +1067,14 @@ Your OTRS Notification Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::NewTicket', 'iso-8859-1', 'de', 'Neues Ticket! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
+    ('Agent::NewTicket', 'iso-8859-1', 'de', 'Neues Ticket! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 es ist ein neues Ticket in "<OTRS_TICKET_Queue>"!
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1086,14 +1086,14 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::FollowUp', 'iso-8859-1', 'de', 'Nachfrage! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::FollowUp', 'iso-8859-1', 'de', 'Nachfrage! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 Sie haben eine Nachfrage bekommen!
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1105,14 +1105,14 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::LockTimeout', 'iso-8859-1', 'de', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::LockTimeout', 'iso-8859-1', 'de', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 Aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_TicketNumber>].
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1124,7 +1124,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::OwnerUpdate', 'iso-8859-1', 'de', 'Ticket Besitz uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::OwnerUpdate', 'iso-8859-1', 'de', 'Ticket Besitz uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 der Besitz des Tickets [<OTRS_TICKET_TicketNumber>] wurde an Sie von "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" uebertragen.
 
@@ -1141,7 +1141,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'de', 'Ticket Verantwortung uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_RESPONSIBLE_UserFirstname> <OTRS_RESPONSIBLE_UserLastname>,
+    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'de', 'Ticket Verantwortung uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_RESPONSIBLE_UserFirstname> <OTRS_RESPONSIBLE_UserLastname>,
 
 die Verantwortung des Tickets [<OTRS_TICKET_TicketNumber>] wurde an Sie von "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" uebertragen.
 
@@ -1158,7 +1158,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::AddNote', 'iso-8859-1', 'de', 'Neue Notiz! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::AddNote', 'iso-8859-1', 'de', 'Neue Notiz! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" fuegte eine Notiz an Ticket [<OTRS_TICKET_TicketNumber>].
 
@@ -1174,12 +1174,12 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Move', 'iso-8859-1', 'de', 'Ticket verschoben in "<OTRS_CUSTOMER_QUEUE>" Queue! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi,
+    ('Agent::Move', 'iso-8859-1', 'de', 'Ticket verschoben in "<OTRS_CUSTOMER_QUEUE>" Queue! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" verschob Ticket [<OTRS_TICKET_TicketNumber>] nach "<OTRS_CUSTOMER_QUEUE>".
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1191,7 +1191,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::PendingReminder', 'iso-8859-1', 'de', 'Ticket Erinnerung erreicht! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>
+    ('Agent::PendingReminder', 'iso-8859-1', 'de', 'Ticket Erinnerung erreicht! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 das Ticket "<OTRS_TICKET_TicketNumber>" hat die Erinnerungszeit erreicht!
 
@@ -1199,7 +1199,7 @@ das Ticket "<OTRS_TICKET_TicketNumber>" hat die Erinnerungszeit erreicht!
 
 schrieb:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Bitte um weitere Bearbeitung:
@@ -1213,7 +1213,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, timestamp, 1, timestamp)
 // ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Escalation', 'iso-8859-1', 'de', 'Ticket Eskalation! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
+    ('Agent::Escalation', 'iso-8859-1', 'de', 'Ticket Eskalation! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 das Ticket "<OTRS_TICKET_TicketNumber>" ist eskaliert!
 
@@ -1221,7 +1221,7 @@ das Ticket "<OTRS_TICKET_TicketNumber>" ist eskaliert!
 
 schrieb:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Bitte um Bearbeitung:
