@@ -1,5 +1,5 @@
 -- ----------------------------------------------------------
---  driver: oracle, generated: 2007-04-16 12:42:41
+--  driver: oracle, generated: 2007-11-05 14:29:59
 -- ----------------------------------------------------------
 SET DEFINE OFF;
 -- ----------------------------------------------------------
@@ -253,7 +253,7 @@ INSERT INTO standard_response (name, text, valid_id, create_by, create_time, cha
 -- ----------------------------------------------------------
 INSERT INTO standard_response (name, text, valid_id, create_by, create_time, change_by, change_time)
     VALUES
-    ('test answer', 'Some test answer to show who a standard response can be used.', 1, 1, current_timestamp, 1, current_timestamp);
+    ('test answer', 'Some test answer to show how a standard response can be used.', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table queue_standard_response
 -- ----------------------------------------------------------
@@ -326,7 +326,7 @@ Your e-mail will be answered by a human asap
 Have fun with OTRS! :-)
 
 Your OTRS Team
-', 'RE: <OTRS_CUSTOMER_SUBJECT[20]>', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
+', 'RE: <OTRS_CUSTOMER_SUBJECT[24]>', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table auto_response
 -- ----------------------------------------------------------
@@ -339,7 +339,7 @@ INSERT INTO auto_response (type_id, system_address_id, name, text0, text1, chars
 Please create a new ticket.
 
 Your OTRS Team
-', 'Your email has been rejected! (RE: <OTRS_CUSTOMER_SUBJECT[20]>)', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
+', 'Your email has been rejected! (RE: <OTRS_CUSTOMER_SUBJECT[24]>)', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table auto_response
 -- ----------------------------------------------------------
@@ -355,7 +355,7 @@ Your e-mail will be answered by a human asap.
 Have fun with OTRS!
 
 Your OTRS Team
-', 'RE: <OTRS_CUSTOMER_SUBJECT[20]>', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
+', 'RE: <OTRS_CUSTOMER_SUBJECT[24]>', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table auto_response
 -- ----------------------------------------------------------
@@ -373,7 +373,7 @@ Your e-mail will be answered by a human asap.
 Have fun with OTRS!
 
 Your OTRS Team
-', 'New ticket has been created! (RE: <OTRS_CUSTOMER_SUBJECT[20]>)', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
+', 'New ticket has been created! (RE: <OTRS_CUSTOMER_SUBJECT[24]>)', 'iso-8859-1', '', 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table ticket_type
 -- ----------------------------------------------------------
@@ -749,9 +749,9 @@ INSERT INTO article_sender_type (name, valid_id, create_by, create_time, change_
 -- ----------------------------------------------------------
 --  insert into table ticket
 -- ----------------------------------------------------------
-INSERT INTO ticket (tn, queue_id, ticket_lock_id, ticket_answered, user_id, responsible_user_id, group_id, ticket_priority_id, ticket_state_id, create_time_unix, escalation_start_time, valid_id, create_by, create_time, change_by, change_time)
+INSERT INTO ticket (tn, queue_id, ticket_lock_id, ticket_answered, user_id, responsible_user_id, group_id, ticket_priority_id, ticket_state_id, create_time_unix, escalation_response_time, escalation_start_time, escalation_solution_time, valid_id, create_by, create_time, change_by, change_time)
     VALUES
-    ('1010001', 2, 1, 0, 1, 1, 1, 3, 1, 1173345999, 1173345999, 1, 1, current_timestamp, 1, current_timestamp);
+    ('1010001', 2, 1, 0, 1, 1, 1, 3, 1, 1173345999, 0, 1173345999, 0, 1, 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 --  insert into table article
 -- ----------------------------------------------------------
@@ -782,14 +782,14 @@ INSERT INTO ticket_history (name, history_type_id, ticket_id, type_id, article_i
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::NewTicket', 'iso-8859-1', 'en', 'New ticket notification! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_UserFirstname>,
+    ('Agent::NewTicket', 'iso-8859-1', 'en', 'New ticket notification! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 there is a new ticket in "<OTRS_TICKET_Queue>"!
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -800,14 +800,14 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::FollowUp', 'iso-8859-1', 'en', 'You got follow up! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::FollowUp', 'iso-8859-1', 'en', 'You got follow up! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 you got a follow up!
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -818,14 +818,14 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::LockTimeout', 'iso-8859-1', 'en', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::LockTimeout', 'iso-8859-1', 'en', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 unlocked (lock timeout) your locked ticket [<OTRS_TICKET_TicketNumber>].
 
 <OTRS_CUSTOMER_FROM> wrote:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -836,7 +836,7 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::OwnerUpdate', 'iso-8859-1', 'en', 'Ticket owner assigned to you! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::OwnerUpdate', 'iso-8859-1', 'en', 'Ticket owner assigned to you! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 a ticket [<OTRS_TICKET_TicketNumber>] is assigned to you by "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>".
 
@@ -852,7 +852,7 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'en', 'Ticket responsible assigned to you! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_RESPONSIBLE_UserFirstname>,
+    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'en', 'Ticket responsible assigned to you! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_RESPONSIBLE_UserFirstname>,
 
 a ticket [<OTRS_TICKET_TicketNumber>] is assigned to you by "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>".
 
@@ -868,7 +868,7 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::AddNote', 'iso-8859-1', 'en', 'New note! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::AddNote', 'iso-8859-1', 'en', 'New note! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" added a new note to ticket [<OTRS_TICKET_TicketNumber>].
 
@@ -883,12 +883,12 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Move', 'iso-8859-1', 'en', 'Moved ticket in ">OTRS_CUSTOMER_QUEUE<" queue! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi,
+    ('Agent::Move', 'iso-8859-1', 'en', 'Moved ticket in "<OTRS_CUSTOMER_QUEUE>" queue! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" moved a ticket [<OTRS_TICKET_TicketNumber>] into "<OTRS_CUSTOMER_QUEUE>".
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -899,7 +899,7 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::PendingReminder', 'iso-8859-1', 'en', 'Ticket reminder has been reached! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname>,
+    ('Agent::PendingReminder', 'iso-8859-1', 'en', 'Ticket reminder has been reached! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
 the ticket "<OTRS_TICKET_TicketNumber>" has been reached the reminder time!
 
@@ -907,7 +907,7 @@ the ticket "<OTRS_TICKET_TicketNumber>" has been reached the reminder time!
 
 wrote:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Please have a look at:
@@ -920,15 +920,15 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Escalation', 'iso-8859-1', 'en', 'Ticket Escalation! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_UserFirstname>,
+    ('Agent::Escalation', 'iso-8859-1', 'en', 'Ticket Escalation! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hi <OTRS_UserFirstname>,
 
-the ticket "<OTRS_TICKET_TicketNumber>" is escaleted!
+the ticket "<OTRS_TICKET_TicketNumber>" is escalated!
 
 <OTRS_CUSTOMER_FROM>
 
 wrote:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Please have a look at:
@@ -941,14 +941,14 @@ Your OTRS Notification Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::NewTicket', 'iso-8859-1', 'de', 'Neues Ticket! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
+    ('Agent::NewTicket', 'iso-8859-1', 'de', 'Neues Ticket! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 es ist ein neues Ticket in "<OTRS_TICKET_Queue>"!
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -959,14 +959,14 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::FollowUp', 'iso-8859-1', 'de', 'Nachfrage! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::FollowUp', 'iso-8859-1', 'de', 'Nachfrage! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 Sie haben eine Nachfrage bekommen!
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -977,14 +977,14 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::LockTimeout', 'iso-8859-1', 'de', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::LockTimeout', 'iso-8859-1', 'de', 'Lock Timeout! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 Aufhebung der Sperre auf Dein gesperrtes Ticket [<OTRS_TICKET_TicketNumber>].
 
 <OTRS_CUSTOMER_FROM> schrieb:
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -995,7 +995,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::OwnerUpdate', 'iso-8859-1', 'de', 'Ticket Besitz uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::OwnerUpdate', 'iso-8859-1', 'de', 'Ticket Besitz uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 der Besitz des Tickets [<OTRS_TICKET_TicketNumber>] wurde an Sie von "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" uebertragen.
 
@@ -1011,7 +1011,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'de', 'Ticket Verantwortung uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_RESPONSIBLE_UserFirstname> <OTRS_RESPONSIBLE_UserLastname>,
+    ('Agent::ResponsibleUpdate', 'iso-8859-1', 'de', 'Ticket Verantwortung uebertragen an Sie! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_RESPONSIBLE_UserFirstname> <OTRS_RESPONSIBLE_UserLastname>,
 
 die Verantwortung des Tickets [<OTRS_TICKET_TicketNumber>] wurde an Sie von "(<OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" uebertragen.
 
@@ -1027,7 +1027,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::AddNote', 'iso-8859-1', 'de', 'Neue Notiz! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>,
+    ('Agent::AddNote', 'iso-8859-1', 'de', 'Neue Notiz! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" fuegte eine Notiz an Ticket [<OTRS_TICKET_TicketNumber>].
 
@@ -1042,12 +1042,12 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Move', 'iso-8859-1', 'de', 'Ticket verschoben in ">OTRS_CUSTOMER_QUEUE<" Queue! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi,
+    ('Agent::Move', 'iso-8859-1', 'de', 'Ticket verschoben in "<OTRS_CUSTOMER_QUEUE>" Queue! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 <OTRS_CURRENT_UserFirstname> <OTRS_CURRENT_UserLastname>" verschob Ticket [<OTRS_TICKET_TicketNumber>] nach "<OTRS_CUSTOMER_QUEUE>".
 
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 <OTRS_CONFIG_HttpType>://<OTRS_CONFIG_FQDN>/<OTRS_CONFIG_ScriptAlias>index.pl?Action=AgentZoom&TicketID=<OTRS_TICKET_TicketID>
@@ -1058,7 +1058,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::PendingReminder', 'iso-8859-1', 'de', 'Ticket Erinnerung erreicht! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hi <OTRS_OWNER_UserFirstname> <OTRS_OWNER_UserLastname>
+    ('Agent::PendingReminder', 'iso-8859-1', 'de', 'Ticket Erinnerung erreicht! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 das Ticket "<OTRS_TICKET_TicketNumber>" hat die Erinnerungszeit erreicht!
 
@@ -1066,7 +1066,7 @@ das Ticket "<OTRS_TICKET_TicketNumber>" hat die Erinnerungszeit erreicht!
 
 schrieb:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Bitte um weitere Bearbeitung:
@@ -1079,7 +1079,7 @@ Ihr OTRS Benachrichtigungs-Master', 1, current_timestamp, 1, current_timestamp);
 -- ----------------------------------------------------------
 INSERT INTO notifications (notification_type, notification_charset, notification_language, subject, text, create_by, create_time, change_by, change_time)
     VALUES
-    ('Agent::Escalation', 'iso-8859-1', 'de', 'Ticket Eskalation! (<OTRS_CUSTOMER_SUBJECT[18]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
+    ('Agent::Escalation', 'iso-8859-1', 'de', 'Ticket Eskalation! (<OTRS_CUSTOMER_SUBJECT[24]>)', 'Hallo <OTRS_UserFirstname> <OTRS_UserLastname>,
 
 das Ticket "<OTRS_TICKET_TicketNumber>" ist eskaliert!
 
@@ -1087,7 +1087,7 @@ das Ticket "<OTRS_TICKET_TicketNumber>" ist eskaliert!
 
 schrieb:
 <snip>
-<OTRS_CUSTOMER_EMAIL[16]>
+<OTRS_CUSTOMER_EMAIL[30]>
 <snip>
 
 Bitte um Bearbeitung:
