@@ -1,10 +1,11 @@
 // ----------------------------------------------------------
-//  database: maxdb, generated: Mon Aug 28 00:13:38 2006
+//  driver: maxdb, generated: 2007-07-26 15:10:15
 // ----------------------------------------------------------
 // ----------------------------------------------------------
 //  create table valid
 // ----------------------------------------------------------
-CREATE TABLE valid (
+CREATE TABLE valid
+(
     id serial,
     name VARCHAR (50) NOT NULL,
     create_time timestamp NOT NULL,
@@ -18,9 +19,27 @@ CREATE TABLE valid (
 // ----------------------------------------------------------
 //  create table ticket_priority
 // ----------------------------------------------------------
-CREATE TABLE ticket_priority (
+CREATE TABLE ticket_priority
+(
     id serial,
     name VARCHAR (50) NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    create_time timestamp NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+)
+//
+// ----------------------------------------------------------
+//  create table ticket_type
+// ----------------------------------------------------------
+CREATE TABLE ticket_type
+(
+    id serial,
+    name VARCHAR (50) NOT NULL,
+    valid_id SMALLINT NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp NOT NULL,
@@ -32,7 +51,8 @@ CREATE TABLE ticket_priority (
 // ----------------------------------------------------------
 //  create table ticket_lock_type
 // ----------------------------------------------------------
-CREATE TABLE ticket_lock_type (
+CREATE TABLE ticket_lock_type
+(
     id serial,
     name VARCHAR (50) NOT NULL,
     valid_id SMALLINT NOT NULL,
@@ -47,7 +67,8 @@ CREATE TABLE ticket_lock_type (
 // ----------------------------------------------------------
 //  create table system_user
 // ----------------------------------------------------------
-CREATE TABLE system_user (
+CREATE TABLE system_user
+(
     id serial,
     login VARCHAR (100) NOT NULL,
     pw VARCHAR (50) NOT NULL,
@@ -66,18 +87,20 @@ CREATE TABLE system_user (
 // ----------------------------------------------------------
 //  create table user_preferences
 // ----------------------------------------------------------
-CREATE TABLE user_preferences (
+CREATE TABLE user_preferences
+(
     user_id INTEGER NOT NULL,
     preferences_key VARCHAR (150) NOT NULL,
     preferences_value VARCHAR (250)
 )
 //
-CREATE INDEX index_user_preferenc96 ON user_preferences (user_id)
+CREATE INDEX index_user_preferenc47 ON user_preferences (user_id)
 //
 // ----------------------------------------------------------
 //  create table groups
 // ----------------------------------------------------------
-CREATE TABLE groups (
+CREATE TABLE groups
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -93,7 +116,8 @@ CREATE TABLE groups (
 // ----------------------------------------------------------
 //  create table group_user
 // ----------------------------------------------------------
-CREATE TABLE group_user (
+CREATE TABLE group_user
+(
     user_id INTEGER NOT NULL,
     group_id INTEGER NOT NULL,
     permission_key VARCHAR (20) NOT NULL,
@@ -107,7 +131,8 @@ CREATE TABLE group_user (
 // ----------------------------------------------------------
 //  create table group_role
 // ----------------------------------------------------------
-CREATE TABLE group_role (
+CREATE TABLE group_role
+(
     role_id INTEGER NOT NULL,
     group_id INTEGER NOT NULL,
     permission_key VARCHAR (20) NOT NULL,
@@ -121,7 +146,8 @@ CREATE TABLE group_role (
 // ----------------------------------------------------------
 //  create table group_customer_user
 // ----------------------------------------------------------
-CREATE TABLE group_customer_user (
+CREATE TABLE group_customer_user
+(
     user_id VARCHAR (100) NOT NULL,
     group_id INTEGER NOT NULL,
     permission_key VARCHAR (20) NOT NULL,
@@ -135,7 +161,8 @@ CREATE TABLE group_customer_user (
 // ----------------------------------------------------------
 //  create table roles
 // ----------------------------------------------------------
-CREATE TABLE roles (
+CREATE TABLE roles
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -151,7 +178,8 @@ CREATE TABLE roles (
 // ----------------------------------------------------------
 //  create table role_user
 // ----------------------------------------------------------
-CREATE TABLE role_user (
+CREATE TABLE role_user
+(
     user_id INTEGER NOT NULL,
     role_id INTEGER NOT NULL,
     create_time timestamp NOT NULL,
@@ -163,7 +191,8 @@ CREATE TABLE role_user (
 // ----------------------------------------------------------
 //  create table personal_queues
 // ----------------------------------------------------------
-CREATE TABLE personal_queues (
+CREATE TABLE personal_queues
+(
     user_id INTEGER NOT NULL,
     queue_id INTEGER NOT NULL
 )
@@ -171,7 +200,8 @@ CREATE TABLE personal_queues (
 // ----------------------------------------------------------
 //  create table theme
 // ----------------------------------------------------------
-CREATE TABLE theme (
+CREATE TABLE theme
+(
     id serial,
     theme VARCHAR (100) NOT NULL,
     valid_id SMALLINT NOT NULL,
@@ -186,7 +216,8 @@ CREATE TABLE theme (
 // ----------------------------------------------------------
 //  create table ticket_state
 // ----------------------------------------------------------
-CREATE TABLE ticket_state (
+CREATE TABLE ticket_state
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -203,7 +234,8 @@ CREATE TABLE ticket_state (
 // ----------------------------------------------------------
 //  create table ticket_state_type
 // ----------------------------------------------------------
-CREATE TABLE ticket_state_type (
+CREATE TABLE ticket_state_type
+(
     id serial,
     name VARCHAR (120) NOT NULL,
     comments VARCHAR (250),
@@ -218,7 +250,8 @@ CREATE TABLE ticket_state_type (
 // ----------------------------------------------------------
 //  create table salutation
 // ----------------------------------------------------------
-CREATE TABLE salutation (
+CREATE TABLE salutation
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     text VARCHAR (3000) NOT NULL,
@@ -235,7 +268,8 @@ CREATE TABLE salutation (
 // ----------------------------------------------------------
 //  create table signature
 // ----------------------------------------------------------
-CREATE TABLE signature (
+CREATE TABLE signature
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     text VARCHAR (3000) NOT NULL,
@@ -252,7 +286,8 @@ CREATE TABLE signature (
 // ----------------------------------------------------------
 //  create table system_address
 // ----------------------------------------------------------
-CREATE TABLE system_address (
+CREATE TABLE system_address
+(
     id serial,
     value0 VARCHAR (200) NOT NULL,
     value1 VARCHAR (200) NOT NULL,
@@ -271,7 +306,8 @@ CREATE TABLE system_address (
 // ----------------------------------------------------------
 //  create table follow_up_possible
 // ----------------------------------------------------------
-CREATE TABLE follow_up_possible (
+CREATE TABLE follow_up_possible
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -287,12 +323,15 @@ CREATE TABLE follow_up_possible (
 // ----------------------------------------------------------
 //  create table queue
 // ----------------------------------------------------------
-CREATE TABLE queue (
+CREATE TABLE queue
+(
     id serial,
     name VARCHAR (200) NOT NULL,
     group_id INTEGER NOT NULL,
     unlock_timeout INTEGER,
-    escalation_time INTEGER,
+    first_response_time INTEGER,
+    update_time INTEGER,
+    solution_time INTEGER,
     system_address_id SMALLINT NOT NULL,
     calendar_name VARCHAR (100),
     default_sign_key VARCHAR (100),
@@ -317,13 +356,17 @@ CREATE TABLE queue (
 // ----------------------------------------------------------
 //  create table ticket
 // ----------------------------------------------------------
-CREATE TABLE ticket (
+CREATE TABLE ticket
+(
     id serial,
     tn VARCHAR (50) NOT NULL,
     title VARCHAR (255),
     queue_id INTEGER NOT NULL,
     ticket_lock_id SMALLINT NOT NULL,
     ticket_answered SMALLINT NOT NULL,
+    type_id SMALLINT,
+    service_id INTEGER,
+    sla_id INTEGER,
     user_id INTEGER NOT NULL,
     responsible_user_id INTEGER NOT NULL,
     group_id INTEGER NOT NULL,
@@ -338,6 +381,8 @@ CREATE TABLE ticket (
     timeout INTEGER,
     until_time INTEGER,
     escalation_start_time INTEGER NOT NULL,
+    escalation_response_time INTEGER NOT NULL,
+    escalation_solution_time INTEGER NOT NULL,
     freekey1 VARCHAR (80),
     freetext1 VARCHAR (150),
     freekey2 VARCHAR (80),
@@ -372,8 +417,12 @@ CREATE TABLE ticket (
     freetext16 VARCHAR (150),
     freetime1 timestamp,
     freetime2 timestamp,
+    freetime3 timestamp,
+    freetime4 timestamp,
+    freetime5 timestamp,
+    freetime6 timestamp,
     valid_id SMALLINT NOT NULL,
-    create_time_unix BIGINT NOT NULL,
+    create_time_unix INTEGER NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL,
     change_time timestamp NOT NULL,
@@ -384,14 +433,17 @@ CREATE TABLE ticket (
 //
 CREATE INDEX index_ticket_user ON ticket (user_id)
 //
-CREATE INDEX index_ticket_queue_v60 ON ticket (ticket_state_id, ticket_lock_id, group_id)
+CREATE INDEX index_ticket_type ON ticket (type_id)
 //
-CREATE INDEX index_ticket_answere79 ON ticket (ticket_answered)
+CREATE INDEX index_ticket_queue_v80 ON ticket (ticket_state_id, ticket_lock_id, group_id)
+//
+CREATE INDEX index_ticket_answere82 ON ticket (ticket_answered)
 //
 // ----------------------------------------------------------
 //  create table object_link
 // ----------------------------------------------------------
-CREATE TABLE object_link (
+CREATE TABLE object_link
+(
     object_link_a_id VARCHAR (80) NOT NULL,
     object_link_b_id VARCHAR (80) NOT NULL,
     object_link_a_object VARCHAR (200) NOT NULL,
@@ -402,12 +454,14 @@ CREATE TABLE object_link (
 // ----------------------------------------------------------
 //  create table ticket_history
 // ----------------------------------------------------------
-CREATE TABLE ticket_history (
+CREATE TABLE ticket_history
+(
     id serial,
     name VARCHAR (200) NOT NULL,
     history_type_id SMALLINT NOT NULL,
-    ticket_id BIGINT NOT NULL,
-    article_id BIGINT,
+    ticket_id INTEGER NOT NULL,
+    article_id INTEGER,
+    type_id SMALLINT NOT NULL,
     queue_id INTEGER NOT NULL,
     owner_id INTEGER NOT NULL,
     priority_id SMALLINT NOT NULL,
@@ -420,14 +474,15 @@ CREATE TABLE ticket_history (
     PRIMARY KEY(id)
 )
 //
-CREATE INDEX ticket_history_ticke63 ON ticket_history (ticket_id)
+CREATE INDEX ticket_history_ticke37 ON ticket_history (ticket_id)
 //
-CREATE INDEX ticket_history_creat20 ON ticket_history (create_time)
+CREATE INDEX ticket_history_creat40 ON ticket_history (create_time)
 //
 // ----------------------------------------------------------
 //  create table ticket_history_type
 // ----------------------------------------------------------
-CREATE TABLE ticket_history_type (
+CREATE TABLE ticket_history_type
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -443,7 +498,8 @@ CREATE TABLE ticket_history_type (
 // ----------------------------------------------------------
 //  create table article_type
 // ----------------------------------------------------------
-CREATE TABLE article_type (
+CREATE TABLE article_type
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -459,7 +515,8 @@ CREATE TABLE article_type (
 // ----------------------------------------------------------
 //  create table article_sender_type
 // ----------------------------------------------------------
-CREATE TABLE article_sender_type (
+CREATE TABLE article_sender_type
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     comments VARCHAR (250),
@@ -475,23 +532,25 @@ CREATE TABLE article_sender_type (
 // ----------------------------------------------------------
 //  create table article_flag
 // ----------------------------------------------------------
-CREATE TABLE article_flag (
-    article_id BIGINT NOT NULL,
+CREATE TABLE article_flag
+(
+    article_id INTEGER NOT NULL,
     article_flag VARCHAR (50) NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL
 )
 //
-CREATE INDEX article_flag_create_64 ON article_flag (create_by)
+CREATE INDEX article_flag_create_48 ON article_flag (create_by)
 //
-CREATE INDEX article_flag_article95 ON article_flag (article_id)
+CREATE INDEX article_flag_article18 ON article_flag (article_id)
 //
 // ----------------------------------------------------------
 //  create table article
 // ----------------------------------------------------------
-CREATE TABLE article (
+CREATE TABLE article
+(
     id serial,
-    ticket_id BIGINT NOT NULL,
+    ticket_id INTEGER NOT NULL,
     article_type_id SMALLINT NOT NULL,
     article_sender_type_id SMALLINT NOT NULL,
     a_from VARCHAR (3800),
@@ -525,9 +584,10 @@ CREATE INDEX article_message_id ON article (a_message_id)
 // ----------------------------------------------------------
 //  create table article_plain
 // ----------------------------------------------------------
-CREATE TABLE article_plain (
+CREATE TABLE article_plain
+(
     id serial,
-    article_id BIGINT NOT NULL,
+    article_id INTEGER NOT NULL,
     body LONG NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL,
@@ -536,14 +596,15 @@ CREATE TABLE article_plain (
     PRIMARY KEY(id)
 )
 //
-CREATE INDEX article_plain_articl48 ON article_plain (article_id)
+CREATE INDEX article_plain_articl82 ON article_plain (article_id)
 //
 // ----------------------------------------------------------
 //  create table article_attachment
 // ----------------------------------------------------------
-CREATE TABLE article_attachment (
+CREATE TABLE article_attachment
+(
     id serial,
-    article_id BIGINT NOT NULL,
+    article_id INTEGER NOT NULL,
     filename VARCHAR (250),
     content_size VARCHAR (30),
     content_type VARCHAR (250),
@@ -555,12 +616,13 @@ CREATE TABLE article_attachment (
     PRIMARY KEY(id)
 )
 //
-CREATE INDEX article_attachment_a34 ON article_attachment (article_id)
+CREATE INDEX article_attachment_a22 ON article_attachment (article_id)
 //
 // ----------------------------------------------------------
 //  create table standard_response
 // ----------------------------------------------------------
-CREATE TABLE standard_response (
+CREATE TABLE standard_response
+(
     id serial,
     name VARCHAR (80) NOT NULL,
     text LONG,
@@ -577,7 +639,8 @@ CREATE TABLE standard_response (
 // ----------------------------------------------------------
 //  create table queue_standard_response
 // ----------------------------------------------------------
-CREATE TABLE queue_standard_response (
+CREATE TABLE queue_standard_response
+(
     queue_id INTEGER NOT NULL,
     standard_response_id INTEGER NOT NULL,
     create_time timestamp NOT NULL,
@@ -589,7 +652,8 @@ CREATE TABLE queue_standard_response (
 // ----------------------------------------------------------
 //  create table standard_attachment
 // ----------------------------------------------------------
-CREATE TABLE standard_attachment (
+CREATE TABLE standard_attachment
+(
     id serial,
     name VARCHAR (150) NOT NULL,
     content_type VARCHAR (150) NOT NULL,
@@ -608,7 +672,8 @@ CREATE TABLE standard_attachment (
 // ----------------------------------------------------------
 //  create table standard_response_attachment
 // ----------------------------------------------------------
-CREATE TABLE standard_response_attachment (
+CREATE TABLE standard_response_attachment
+(
     id serial,
     standard_attachment_id INTEGER NOT NULL,
     standard_response_id INTEGER NOT NULL,
@@ -622,7 +687,8 @@ CREATE TABLE standard_response_attachment (
 // ----------------------------------------------------------
 //  create table auto_response_type
 // ----------------------------------------------------------
-CREATE TABLE auto_response_type (
+CREATE TABLE auto_response_type
+(
     id serial,
     name VARCHAR (50) NOT NULL,
     comments VARCHAR (200),
@@ -638,7 +704,8 @@ CREATE TABLE auto_response_type (
 // ----------------------------------------------------------
 //  create table auto_response
 // ----------------------------------------------------------
-CREATE TABLE auto_response (
+CREATE TABLE auto_response
+(
     id serial,
     name VARCHAR (100) NOT NULL,
     text0 LONG,
@@ -660,7 +727,8 @@ CREATE TABLE auto_response (
 // ----------------------------------------------------------
 //  create table queue_auto_response
 // ----------------------------------------------------------
-CREATE TABLE queue_auto_response (
+CREATE TABLE queue_auto_response
+(
     id serial,
     queue_id INTEGER NOT NULL,
     auto_response_id INTEGER NOT NULL,
@@ -674,10 +742,11 @@ CREATE TABLE queue_auto_response (
 // ----------------------------------------------------------
 //  create table time_accounting
 // ----------------------------------------------------------
-CREATE TABLE time_accounting (
+CREATE TABLE time_accounting
+(
     id serial,
-    ticket_id BIGINT NOT NULL,
-    article_id BIGINT,
+    ticket_id INTEGER NOT NULL,
+    article_id INTEGER,
     time_unit DECIMAL (10,2) NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL,
@@ -686,13 +755,14 @@ CREATE TABLE time_accounting (
     PRIMARY KEY(id)
 )
 //
-CREATE INDEX index_time_accountin62 ON time_accounting (ticket_id)
+CREATE INDEX index_time_accountin50 ON time_accounting (ticket_id)
 //
 // ----------------------------------------------------------
 //  create table ticket_watcher
 // ----------------------------------------------------------
-CREATE TABLE ticket_watcher (
-    ticket_id BIGINT NOT NULL,
+CREATE TABLE ticket_watcher
+(
+    ticket_id INTEGER NOT NULL,
     user_id INTEGER NOT NULL,
     create_time timestamp NOT NULL,
     create_by INTEGER NOT NULL,
@@ -700,12 +770,67 @@ CREATE TABLE ticket_watcher (
     change_by INTEGER NOT NULL
 )
 //
-CREATE INDEX ticket_id ON ticket_watcher (ticket_id)
+CREATE INDEX ticket_watcher_ticke63 ON ticket_watcher (ticket_id)
+//
+// ----------------------------------------------------------
+//  create table service
+// ----------------------------------------------------------
+CREATE TABLE service
+(
+    id serial,
+    name VARCHAR (200) NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    comments VARCHAR (200),
+    create_time timestamp NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+)
+//
+// ----------------------------------------------------------
+//  create table service_customer_user
+// ----------------------------------------------------------
+CREATE TABLE service_customer_user
+(
+    customer_user_login VARCHAR (100) NOT NULL,
+    service_id INTEGER NOT NULL,
+    create_time timestamp NOT NULL,
+    create_by INTEGER NOT NULL
+)
+//
+CREATE INDEX service_customer_use43 ON service_customer_user (customer_user_login)
+//
+CREATE INDEX service_customer_use9 ON service_customer_user (service_id)
+//
+// ----------------------------------------------------------
+//  create table sla
+// ----------------------------------------------------------
+CREATE TABLE sla
+(
+    id serial,
+    service_id INTEGER NOT NULL,
+    name VARCHAR (200) NOT NULL,
+    calendar_name VARCHAR (100),
+    first_response_time INTEGER NOT NULL,
+    update_time INTEGER NOT NULL,
+    solution_time INTEGER NOT NULL,
+    valid_id SMALLINT NOT NULL,
+    comments VARCHAR (200),
+    create_time timestamp NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp NOT NULL,
+    change_by INTEGER NOT NULL,
+    PRIMARY KEY(id),
+    UNIQUE (name)
+)
 //
 // ----------------------------------------------------------
 //  create table sessions
 // ----------------------------------------------------------
-CREATE TABLE sessions (
+CREATE TABLE sessions
+(
     session_id VARCHAR (150) NOT NULL,
     session_value LONG NOT NULL
 )
@@ -715,31 +840,34 @@ CREATE INDEX index_session_id ON sessions (session_id)
 // ----------------------------------------------------------
 //  create table ticket_index
 // ----------------------------------------------------------
-CREATE TABLE ticket_index (
-    ticket_id BIGINT NOT NULL,
+CREATE TABLE ticket_index
+(
+    ticket_id INTEGER NOT NULL,
     queue_id INTEGER NOT NULL,
     queue VARCHAR (70) NOT NULL,
     group_id INTEGER NOT NULL,
     s_lock VARCHAR (70) NOT NULL,
     s_state VARCHAR (70) NOT NULL,
-    create_time_unix BIGINT NOT NULL
+    create_time_unix INTEGER NOT NULL
 )
 //
-CREATE INDEX index_ticket_index_t1 ON ticket_index (ticket_id)
+CREATE INDEX index_ticket_index_t85 ON ticket_index (ticket_id)
 //
 // ----------------------------------------------------------
 //  create table ticket_lock_index
 // ----------------------------------------------------------
-CREATE TABLE ticket_lock_index (
-    ticket_id BIGINT NOT NULL
+CREATE TABLE ticket_lock_index
+(
+    ticket_id INTEGER NOT NULL
 )
 //
-CREATE INDEX index_ticket_lock_ti27 ON ticket_lock_index (ticket_id)
+CREATE INDEX index_ticket_lock_ti91 ON ticket_lock_index (ticket_id)
 //
 // ----------------------------------------------------------
 //  create table customer_user
 // ----------------------------------------------------------
-CREATE TABLE customer_user (
+CREATE TABLE customer_user
+(
     id serial,
     login VARCHAR (100) NOT NULL,
     email VARCHAR (150) NOT NULL,
@@ -761,30 +889,55 @@ CREATE TABLE customer_user (
 // ----------------------------------------------------------
 //  create table customer_preferences
 // ----------------------------------------------------------
-CREATE TABLE customer_preferences (
+CREATE TABLE customer_preferences
+(
     user_id VARCHAR (250) NOT NULL,
     preferences_key VARCHAR (150) NOT NULL,
     preferences_value VARCHAR (250)
 )
 //
-CREATE INDEX index_customer_prefe11 ON customer_preferences (user_id)
+CREATE INDEX index_customer_prefe81 ON customer_preferences (user_id)
+//
+// ----------------------------------------------------------
+//  create table customer_company
+// ----------------------------------------------------------
+CREATE TABLE customer_company
+(
+    customer_id VARCHAR (100) NOT NULL,
+    name VARCHAR (100) NOT NULL,
+    street VARCHAR (200),
+    zip VARCHAR (200),
+    city VARCHAR (200),
+    country VARCHAR (200),
+    url VARCHAR (200),
+    comments VARCHAR (250),
+    valid_id SMALLINT NOT NULL,
+    create_time timestamp NOT NULL,
+    create_by INTEGER NOT NULL,
+    change_time timestamp NOT NULL,
+    change_by INTEGER NOT NULL,
+    UNIQUE (customer_id),
+    UNIQUE (name)
+)
 //
 // ----------------------------------------------------------
 //  create table ticket_loop_protection
 // ----------------------------------------------------------
-CREATE TABLE ticket_loop_protection (
+CREATE TABLE ticket_loop_protection
+(
     sent_to VARCHAR (250) NOT NULL,
     sent_date VARCHAR (150) NOT NULL
 )
 //
-CREATE INDEX index_ticket_loop_pr94 ON ticket_loop_protection (sent_to)
+CREATE INDEX index_ticket_loop_pr75 ON ticket_loop_protection (sent_to)
 //
-CREATE INDEX index_ticket_loop_pr89 ON ticket_loop_protection (sent_date)
+CREATE INDEX index_ticket_loop_pr18 ON ticket_loop_protection (sent_date)
 //
 // ----------------------------------------------------------
 //  create table pop3_account
 // ----------------------------------------------------------
-CREATE TABLE pop3_account (
+CREATE TABLE pop3_account
+(
     id serial,
     login VARCHAR (200) NOT NULL,
     pw VARCHAR (200) NOT NULL,
@@ -803,7 +956,8 @@ CREATE TABLE pop3_account (
 // ----------------------------------------------------------
 //  create table postmaster_filter
 // ----------------------------------------------------------
-CREATE TABLE postmaster_filter (
+CREATE TABLE postmaster_filter
+(
     f_name VARCHAR (200) NOT NULL,
     f_type VARCHAR (20) NOT NULL,
     f_key VARCHAR (200) NOT NULL,
@@ -813,16 +967,18 @@ CREATE TABLE postmaster_filter (
 // ----------------------------------------------------------
 //  create table generic_agent_jobs
 // ----------------------------------------------------------
-CREATE TABLE generic_agent_jobs (
+CREATE TABLE generic_agent_jobs
+(
     job_name VARCHAR (200) NOT NULL,
     job_key VARCHAR (200) NOT NULL,
-    job_value VARCHAR (200) NOT NULL
+    job_value VARCHAR (200)
 )
 //
 // ----------------------------------------------------------
 //  create table search_profile
 // ----------------------------------------------------------
-CREATE TABLE search_profile (
+CREATE TABLE search_profile
+(
     login VARCHAR (200) NOT NULL,
     profile_name VARCHAR (200) NOT NULL,
     profile_type VARCHAR (30) NOT NULL,
@@ -833,7 +989,8 @@ CREATE TABLE search_profile (
 // ----------------------------------------------------------
 //  create table process_id
 // ----------------------------------------------------------
-CREATE TABLE process_id (
+CREATE TABLE process_id
+(
     process_name VARCHAR (200) NOT NULL,
     process_id VARCHAR (200) NOT NULL,
     process_host VARCHAR (200) NOT NULL,
@@ -843,19 +1000,21 @@ CREATE TABLE process_id (
 // ----------------------------------------------------------
 //  create table web_upload_cache
 // ----------------------------------------------------------
-CREATE TABLE web_upload_cache (
+CREATE TABLE web_upload_cache
+(
     form_id VARCHAR (250),
     filename VARCHAR (250),
     content_size VARCHAR (30),
     content_type VARCHAR (250),
     content LONG NOT NULL,
-    create_time_unix BIGINT NOT NULL
+    create_time_unix INTEGER NOT NULL
 )
 //
 // ----------------------------------------------------------
 //  create table notifications
 // ----------------------------------------------------------
-CREATE TABLE notifications (
+CREATE TABLE notifications
+(
     id serial,
     notification_type VARCHAR (200) NOT NULL,
     notification_charset VARCHAR (60) NOT NULL,
@@ -872,23 +1031,23 @@ CREATE TABLE notifications (
 // ----------------------------------------------------------
 //  create table xml_storage
 // ----------------------------------------------------------
-CREATE TABLE xml_storage (
+CREATE TABLE xml_storage
+(
     xml_type VARCHAR (200) NOT NULL,
     xml_key VARCHAR (250) NOT NULL,
     xml_content_key VARCHAR (250) NOT NULL,
-    xml_content_value LONG NOT NULL
+    xml_content_value LONG
 )
 //
-CREATE INDEX xml_content_key ON xml_storage (xml_content_key)
+CREATE INDEX xml_storage_xml_cont43 ON xml_storage (xml_content_key)
 //
-CREATE INDEX xml_type ON xml_storage (xml_type)
-//
-CREATE INDEX xml_key ON xml_storage (xml_key)
+CREATE INDEX xml_storage_key_type37 ON xml_storage (xml_key, xml_type)
 //
 // ----------------------------------------------------------
 //  create table package_repository
 // ----------------------------------------------------------
-CREATE TABLE package_repository (
+CREATE TABLE package_repository
+(
     id serial,
     name VARCHAR (250) NOT NULL,
     version VARCHAR (250) NOT NULL,
