@@ -1,7 +1,7 @@
 -- ----------------------------------------------------------
---  database: oracle, generated: Wed Sep 27 14:15:55 2006
+--  driver: oracle, generated: 2007-07-26 15:10:16
 -- ----------------------------------------------------------
-DROP TABLE valid CASCADE CONSTRAINTS;
+SET DEFINE OFF;
 -- ----------------------------------------------------------
 --  create table valid
 -- ----------------------------------------------------------
@@ -27,13 +27,13 @@ begin
 end;
 /
 --;
-DROP TABLE ticket_priority CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_priority
 -- ----------------------------------------------------------
 CREATE TABLE ticket_priority (
     id NUMBER (5, 0) NOT NULL,
     name VARCHAR2 (50) NOT NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
     create_time DATE NOT NULL,
     create_by NUMBER NOT NULL,
     change_time DATE NOT NULL,
@@ -53,7 +53,32 @@ begin
 end;
 /
 --;
-DROP TABLE ticket_lock_type CASCADE CONSTRAINTS;
+-- ----------------------------------------------------------
+--  create table ticket_type
+-- ----------------------------------------------------------
+CREATE TABLE ticket_type (
+    id NUMBER (5, 0) NOT NULL,
+    name VARCHAR2 (50) NOT NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER NOT NULL,
+    CONSTRAINT ticket_type_U_1 UNIQUE (name)
+);
+ALTER TABLE ticket_type ADD CONSTRAINT ticket_type_PK PRIMARY KEY (id);
+DROP SEQUENCE ticket_type_seq;
+CREATE SEQUENCE ticket_type_seq;
+CREATE OR REPLACE TRIGGER ticket_type_s_t
+before insert on ticket_type
+for each row
+begin
+    select ticket_type_seq.nextval
+    into :new.id
+    from dual;
+end;
+/
+--;
 -- ----------------------------------------------------------
 --  create table ticket_lock_type
 -- ----------------------------------------------------------
@@ -80,7 +105,6 @@ begin
 end;
 /
 --;
-DROP TABLE system_user CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table system_user
 -- ----------------------------------------------------------
@@ -111,7 +135,6 @@ begin
 end;
 /
 --;
-DROP TABLE user_preferences CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table user_preferences
 -- ----------------------------------------------------------
@@ -121,7 +144,6 @@ CREATE TABLE user_preferences (
     preferences_value VARCHAR2 (250)
 );
 CREATE INDEX index_user_preferences_user_id ON user_preferences (user_id);
-DROP TABLE groups CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table groups
 -- ----------------------------------------------------------
@@ -149,7 +171,6 @@ begin
 end;
 /
 --;
-DROP TABLE group_user CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table group_user
 -- ----------------------------------------------------------
@@ -163,7 +184,6 @@ CREATE TABLE group_user (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-DROP TABLE group_role CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table group_role
 -- ----------------------------------------------------------
@@ -177,7 +197,6 @@ CREATE TABLE group_role (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-DROP TABLE group_customer_user CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table group_customer_user
 -- ----------------------------------------------------------
@@ -191,7 +210,6 @@ CREATE TABLE group_customer_user (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-DROP TABLE roles CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table roles
 -- ----------------------------------------------------------
@@ -219,7 +237,6 @@ begin
 end;
 /
 --;
-DROP TABLE role_user CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table role_user
 -- ----------------------------------------------------------
@@ -231,7 +248,6 @@ CREATE TABLE role_user (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-DROP TABLE personal_queues CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table personal_queues
 -- ----------------------------------------------------------
@@ -239,7 +255,6 @@ CREATE TABLE personal_queues (
     user_id NUMBER NOT NULL,
     queue_id NUMBER NOT NULL
 );
-DROP TABLE theme CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table theme
 -- ----------------------------------------------------------
@@ -266,7 +281,6 @@ begin
 end;
 /
 --;
-DROP TABLE ticket_state CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_state
 -- ----------------------------------------------------------
@@ -295,7 +309,6 @@ begin
 end;
 /
 --;
-DROP TABLE ticket_state_type CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_state_type
 -- ----------------------------------------------------------
@@ -322,7 +335,6 @@ begin
 end;
 /
 --;
-DROP TABLE salutation CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table salutation
 -- ----------------------------------------------------------
@@ -351,7 +363,6 @@ begin
 end;
 /
 --;
-DROP TABLE signature CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table signature
 -- ----------------------------------------------------------
@@ -380,7 +391,6 @@ begin
 end;
 /
 --;
-DROP TABLE system_address CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table system_address
 -- ----------------------------------------------------------
@@ -411,7 +421,6 @@ begin
 end;
 /
 --;
-DROP TABLE follow_up_possible CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table follow_up_possible
 -- ----------------------------------------------------------
@@ -439,7 +448,6 @@ begin
 end;
 /
 --;
-DROP TABLE queue CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table queue
 -- ----------------------------------------------------------
@@ -448,7 +456,9 @@ CREATE TABLE queue (
     name VARCHAR2 (200) NOT NULL,
     group_id NUMBER NOT NULL,
     unlock_timeout NUMBER,
-    escalation_time NUMBER,
+    first_response_time NUMBER,
+    update_time NUMBER,
+    solution_time NUMBER,
     system_address_id NUMBER (5, 0) NOT NULL,
     calendar_name VARCHAR2 (100),
     default_sign_key VARCHAR2 (100),
@@ -481,7 +491,6 @@ begin
 end;
 /
 --;
-DROP TABLE ticket CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket
 -- ----------------------------------------------------------
@@ -492,6 +501,9 @@ CREATE TABLE ticket (
     queue_id NUMBER NOT NULL,
     ticket_lock_id NUMBER (5, 0) NOT NULL,
     ticket_answered NUMBER (5, 0) NOT NULL,
+    type_id NUMBER (5, 0),
+    service_id NUMBER,
+    sla_id NUMBER,
     user_id NUMBER NOT NULL,
     responsible_user_id NUMBER NOT NULL,
     group_id NUMBER NOT NULL,
@@ -506,6 +518,8 @@ CREATE TABLE ticket (
     timeout NUMBER,
     until_time NUMBER,
     escalation_start_time NUMBER NOT NULL,
+    escalation_response_time NUMBER NOT NULL,
+    escalation_solution_time NUMBER NOT NULL,
     freekey1 VARCHAR2 (80),
     freetext1 VARCHAR2 (150),
     freekey2 VARCHAR2 (80),
@@ -540,6 +554,10 @@ CREATE TABLE ticket (
     freetext16 VARCHAR2 (150),
     freetime1 DATE,
     freetime2 DATE,
+    freetime3 DATE,
+    freetime4 DATE,
+    freetime5 DATE,
+    freetime6 DATE,
     valid_id NUMBER (5, 0) NOT NULL,
     create_time_unix NUMBER (20, 0) NOT NULL,
     create_time DATE NOT NULL,
@@ -562,9 +580,9 @@ end;
 /
 --;
 CREATE INDEX index_ticket_user ON ticket (user_id);
+CREATE INDEX index_ticket_type ON ticket (type_id);
 CREATE INDEX index_ticket_queue_view ON ticket (ticket_state_id, ticket_lock_id, group_id);
 CREATE INDEX index_ticket_answered ON ticket (ticket_answered);
-DROP TABLE object_link CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table object_link
 -- ----------------------------------------------------------
@@ -575,7 +593,6 @@ CREATE TABLE object_link (
     object_link_b_object VARCHAR2 (200) NOT NULL,
     object_link_type VARCHAR2 (200) NOT NULL
 );
-DROP TABLE ticket_history CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_history
 -- ----------------------------------------------------------
@@ -585,6 +602,7 @@ CREATE TABLE ticket_history (
     history_type_id NUMBER (5, 0) NOT NULL,
     ticket_id NUMBER (20, 0) NOT NULL,
     article_id NUMBER (20, 0),
+    type_id NUMBER (5, 0) NOT NULL,
     queue_id NUMBER NOT NULL,
     owner_id NUMBER NOT NULL,
     priority_id NUMBER (5, 0) NOT NULL,
@@ -610,7 +628,6 @@ end;
 --;
 CREATE INDEX ticket_history_ticket_id ON ticket_history (ticket_id);
 CREATE INDEX ticket_history_create_time ON ticket_history (create_time);
-DROP TABLE ticket_history_type CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_history_type
 -- ----------------------------------------------------------
@@ -638,7 +655,6 @@ begin
 end;
 /
 --;
-DROP TABLE article_type CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article_type
 -- ----------------------------------------------------------
@@ -666,7 +682,6 @@ begin
 end;
 /
 --;
-DROP TABLE article_sender_type CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article_sender_type
 -- ----------------------------------------------------------
@@ -694,7 +709,6 @@ begin
 end;
 /
 --;
-DROP TABLE article_flag CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article_flag
 -- ----------------------------------------------------------
@@ -706,7 +720,6 @@ CREATE TABLE article_flag (
 );
 CREATE INDEX article_flag_create_by ON article_flag (create_by);
 CREATE INDEX article_flag_article_id ON article_flag (article_id);
-DROP TABLE article CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article
 -- ----------------------------------------------------------
@@ -752,7 +765,6 @@ end;
 --;
 CREATE INDEX article_ticket_id ON article (ticket_id);
 CREATE INDEX article_message_id ON article (a_message_id);
-DROP TABLE article_plain CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article_plain
 -- ----------------------------------------------------------
@@ -779,7 +791,6 @@ end;
 /
 --;
 CREATE INDEX article_plain_article_id ON article_plain (article_id);
-DROP TABLE article_attachment CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table article_attachment
 -- ----------------------------------------------------------
@@ -809,7 +820,6 @@ end;
 /
 --;
 CREATE INDEX article_attachment_article_id ON article_attachment (article_id);
-DROP TABLE standard_response CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table standard_response
 -- ----------------------------------------------------------
@@ -838,7 +848,6 @@ begin
 end;
 /
 --;
-DROP TABLE queue_standard_response CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table queue_standard_response
 -- ----------------------------------------------------------
@@ -850,12 +859,11 @@ CREATE TABLE queue_standard_response (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-DROP TABLE standard_attachment CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table standard_attachment
 -- ----------------------------------------------------------
 CREATE TABLE standard_attachment (
-    id NUMBER (5, 0) NOT NULL,
+    id NUMBER NOT NULL,
     name VARCHAR2 (150) NOT NULL,
     content_type VARCHAR2 (150) NOT NULL,
     content CLOB NOT NULL,
@@ -881,7 +889,6 @@ begin
 end;
 /
 --;
-DROP TABLE standard_response_attachment CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table standard_response_attachment
 -- ----------------------------------------------------------
@@ -894,20 +901,19 @@ CREATE TABLE standard_response_attachment (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-ALTER TABLE standard_response_attachment ADD CONSTRAINT standard_response_attach81_PK PRIMARY KEY (id);
-DROP SEQUENCE standard_response_attach81_seq;
-CREATE SEQUENCE standard_response_attach81_seq;
-CREATE OR REPLACE TRIGGER standard_response_attach81_s_t
+ALTER TABLE standard_response_attachment ADD CONSTRAINT standard_response_attach54_PK PRIMARY KEY (id);
+DROP SEQUENCE standard_response_attach54_seq;
+CREATE SEQUENCE standard_response_attach54_seq;
+CREATE OR REPLACE TRIGGER standard_response_attach54_s_t
 before insert on standard_response_attachment
 for each row
 begin
-    select standard_response_attach81_seq.nextval
+    select standard_response_attach54_seq.nextval
     into :new.id
     from dual;
 end;
 /
 --;
-DROP TABLE auto_response_type CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table auto_response_type
 -- ----------------------------------------------------------
@@ -935,12 +941,11 @@ begin
 end;
 /
 --;
-DROP TABLE auto_response CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table auto_response
 -- ----------------------------------------------------------
 CREATE TABLE auto_response (
-    id NUMBER (5, 0) NOT NULL,
+    id NUMBER NOT NULL,
     name VARCHAR2 (100) NOT NULL,
     text0 CLOB,
     text1 CLOB,
@@ -969,7 +974,6 @@ begin
 end;
 /
 --;
-DROP TABLE queue_auto_response CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table queue_auto_response
 -- ----------------------------------------------------------
@@ -995,7 +999,6 @@ begin
 end;
 /
 --;
-DROP TABLE time_accounting CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table time_accounting
 -- ----------------------------------------------------------
@@ -1022,8 +1025,7 @@ begin
 end;
 /
 --;
-CREATE INDEX index_time_accounting_ticket58 ON time_accounting (ticket_id);
-DROP TABLE ticket_watcher CASCADE CONSTRAINTS;
+CREATE INDEX index_time_accounting_ticket18 ON time_accounting (ticket_id);
 -- ----------------------------------------------------------
 --  create table ticket_watcher
 -- ----------------------------------------------------------
@@ -1035,8 +1037,77 @@ CREATE TABLE ticket_watcher (
     change_time DATE NOT NULL,
     change_by NUMBER NOT NULL
 );
-CREATE INDEX ticket_id ON ticket_watcher (ticket_id);
-DROP TABLE sessions CASCADE CONSTRAINTS;
+CREATE INDEX ticket_watcher_ticket_id ON ticket_watcher (ticket_id);
+-- ----------------------------------------------------------
+--  create table service
+-- ----------------------------------------------------------
+CREATE TABLE service (
+    id NUMBER NOT NULL,
+    name VARCHAR2 (200) NOT NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
+    comments VARCHAR2 (200),
+    create_time DATE NOT NULL,
+    create_by NUMBER NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER NOT NULL,
+    CONSTRAINT service_U_1 UNIQUE (name)
+);
+ALTER TABLE service ADD CONSTRAINT service_PK PRIMARY KEY (id);
+DROP SEQUENCE service_seq;
+CREATE SEQUENCE service_seq;
+CREATE OR REPLACE TRIGGER service_s_t
+before insert on service
+for each row
+begin
+    select service_seq.nextval
+    into :new.id
+    from dual;
+end;
+/
+--;
+-- ----------------------------------------------------------
+--  create table service_customer_user
+-- ----------------------------------------------------------
+CREATE TABLE service_customer_user (
+    customer_user_login VARCHAR2 (100) NOT NULL,
+    service_id NUMBER NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER NOT NULL
+);
+CREATE INDEX service_customer_user_custom41 ON service_customer_user (customer_user_login);
+CREATE INDEX service_customer_user_servic48 ON service_customer_user (service_id);
+-- ----------------------------------------------------------
+--  create table sla
+-- ----------------------------------------------------------
+CREATE TABLE sla (
+    id NUMBER NOT NULL,
+    service_id NUMBER NOT NULL,
+    name VARCHAR2 (200) NOT NULL,
+    calendar_name VARCHAR2 (100),
+    first_response_time NUMBER NOT NULL,
+    update_time NUMBER NOT NULL,
+    solution_time NUMBER NOT NULL,
+    valid_id NUMBER (5, 0) NOT NULL,
+    comments VARCHAR2 (200),
+    create_time DATE NOT NULL,
+    create_by NUMBER NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER NOT NULL,
+    CONSTRAINT sla_U_1 UNIQUE (name)
+);
+ALTER TABLE sla ADD CONSTRAINT sla_PK PRIMARY KEY (id);
+DROP SEQUENCE sla_seq;
+CREATE SEQUENCE sla_seq;
+CREATE OR REPLACE TRIGGER sla_s_t
+before insert on sla
+for each row
+begin
+    select sla_seq.nextval
+    into :new.id
+    from dual;
+end;
+/
+--;
 -- ----------------------------------------------------------
 --  create table sessions
 -- ----------------------------------------------------------
@@ -1045,7 +1116,6 @@ CREATE TABLE sessions (
     session_value CLOB NOT NULL
 );
 CREATE INDEX index_session_id ON sessions (session_id);
-DROP TABLE ticket_index CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_index
 -- ----------------------------------------------------------
@@ -1059,7 +1129,6 @@ CREATE TABLE ticket_index (
     create_time_unix NUMBER (20, 0) NOT NULL
 );
 CREATE INDEX index_ticket_index_ticket_id ON ticket_index (ticket_id);
-DROP TABLE ticket_lock_index CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table ticket_lock_index
 -- ----------------------------------------------------------
@@ -1067,7 +1136,6 @@ CREATE TABLE ticket_lock_index (
     ticket_id NUMBER (20, 0) NOT NULL
 );
 CREATE INDEX index_ticket_lock_ticket_id ON ticket_lock_index (ticket_id);
-DROP TABLE customer_user CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table customer_user
 -- ----------------------------------------------------------
@@ -1101,7 +1169,6 @@ begin
 end;
 /
 --;
-DROP TABLE customer_preferences CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table customer_preferences
 -- ----------------------------------------------------------
@@ -1110,8 +1177,27 @@ CREATE TABLE customer_preferences (
     preferences_key VARCHAR2 (150) NOT NULL,
     preferences_value VARCHAR2 (250)
 );
-CREATE INDEX index_customer_preferences_u17 ON customer_preferences (user_id);
-DROP TABLE ticket_loop_protection CASCADE CONSTRAINTS;
+CREATE INDEX index_customer_preferences_u54 ON customer_preferences (user_id);
+-- ----------------------------------------------------------
+--  create table customer_company
+-- ----------------------------------------------------------
+CREATE TABLE customer_company (
+    customer_id VARCHAR2 (100) NOT NULL,
+    name VARCHAR2 (100) NOT NULL,
+    street VARCHAR2 (200),
+    zip VARCHAR2 (200),
+    city VARCHAR2 (200),
+    country VARCHAR2 (200),
+    url VARCHAR2 (200),
+    comments VARCHAR2 (250),
+    valid_id NUMBER (5, 0) NOT NULL,
+    create_time DATE NOT NULL,
+    create_by NUMBER NOT NULL,
+    change_time DATE NOT NULL,
+    change_by NUMBER NOT NULL,
+    CONSTRAINT customer_company_U_1 UNIQUE (name),
+    CONSTRAINT customer_company_U_2 UNIQUE (customer_id)
+);
 -- ----------------------------------------------------------
 --  create table ticket_loop_protection
 -- ----------------------------------------------------------
@@ -1119,9 +1205,8 @@ CREATE TABLE ticket_loop_protection (
     sent_to VARCHAR2 (250) NOT NULL,
     sent_date VARCHAR2 (150) NOT NULL
 );
-CREATE INDEX index_ticket_loop_protection57 ON ticket_loop_protection (sent_to);
-CREATE INDEX index_ticket_loop_protection65 ON ticket_loop_protection (sent_date);
-DROP TABLE pop3_account CASCADE CONSTRAINTS;
+CREATE INDEX index_ticket_loop_protection52 ON ticket_loop_protection (sent_to);
+CREATE INDEX index_ticket_loop_protection41 ON ticket_loop_protection (sent_date);
 -- ----------------------------------------------------------
 --  create table pop3_account
 -- ----------------------------------------------------------
@@ -1152,7 +1237,6 @@ begin
 end;
 /
 --;
-DROP TABLE postmaster_filter CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table postmaster_filter
 -- ----------------------------------------------------------
@@ -1162,16 +1246,14 @@ CREATE TABLE postmaster_filter (
     f_key VARCHAR2 (200) NOT NULL,
     f_value VARCHAR2 (200) NOT NULL
 );
-DROP TABLE generic_agent_jobs CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table generic_agent_jobs
 -- ----------------------------------------------------------
 CREATE TABLE generic_agent_jobs (
     job_name VARCHAR2 (200) NOT NULL,
     job_key VARCHAR2 (200) NOT NULL,
-    job_value VARCHAR2 (200) NOT NULL
+    job_value VARCHAR2 (200)
 );
-DROP TABLE search_profile CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table search_profile
 -- ----------------------------------------------------------
@@ -1182,7 +1264,6 @@ CREATE TABLE search_profile (
     profile_key VARCHAR2 (200) NOT NULL,
     profile_value VARCHAR2 (200)
 );
-DROP TABLE process_id CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table process_id
 -- ----------------------------------------------------------
@@ -1192,7 +1273,6 @@ CREATE TABLE process_id (
     process_host VARCHAR2 (200) NOT NULL,
     process_create NUMBER NOT NULL
 );
-DROP TABLE web_upload_cache CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table web_upload_cache
 -- ----------------------------------------------------------
@@ -1204,7 +1284,6 @@ CREATE TABLE web_upload_cache (
     content CLOB NOT NULL,
     create_time_unix NUMBER (20, 0) NOT NULL
 );
-DROP TABLE notifications CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table notifications
 -- ----------------------------------------------------------
@@ -1233,7 +1312,6 @@ begin
 end;
 /
 --;
-DROP TABLE xml_storage CASCADE CONSTRAINTS;
 -- ----------------------------------------------------------
 --  create table xml_storage
 -- ----------------------------------------------------------
@@ -1243,10 +1321,8 @@ CREATE TABLE xml_storage (
     xml_content_key VARCHAR2 (250) NOT NULL,
     xml_content_value CLOB
 );
-CREATE INDEX xml_content_key ON xml_storage (xml_content_key);
-CREATE INDEX xml_type ON xml_storage (xml_type);
-CREATE INDEX xml_key ON xml_storage (xml_key);
-DROP TABLE package_repository CASCADE CONSTRAINTS;
+CREATE INDEX xml_storage_xml_content_key ON xml_storage (xml_content_key);
+CREATE INDEX xml_storage_key_type ON xml_storage (xml_key, xml_type);
 -- ----------------------------------------------------------
 --  create table package_repository
 -- ----------------------------------------------------------
